@@ -486,14 +486,14 @@ namespace Magick
 
     void            quantumOperator ( const ChannelType channel_,
                                       const MagickEvaluateOperator operator_,
-                                      Quantum rvalue_);
+                                      double rvalue_);
 
     void            quantumOperator ( const int x_,const int y_,
                                       const unsigned int columns_,
                                       const unsigned int rows_,
                                       const ChannelType channel_,
                                       const MagickEvaluateOperator operator_,
-                                      const Quantum rvalue_);
+                                      const double rvalue_);
 
     // Execute a named process module using an argc/argv syntax similar to
     // that accepted by a C 'main' routine. An exception is thrown if the
@@ -659,6 +659,10 @@ namespace Magick
     // transparent
     void            transparent ( const Color &color_ );
     
+    // Add matte image to image, for all the pixels that lies in between
+    // the given two color
+    void transparentChroma ( const Color &colorLow_, const Color &colorHigh_);
+
     // Trim edges that are the background color from the image
     void            trim ( void );
 
@@ -975,6 +979,10 @@ typedef struct _ImageChannelStatistics
    double standard_deviation;
    /* Variance */
    double variance;
+   /* Kurtosis */
+   double kurtosis;
+   /* Skewness */
+   double skewness;
  } ImageChannelStatistics;
                                                                                 
 typedef struct _ImageStatistics
@@ -1237,10 +1245,10 @@ typedef struct _ImageStatistics
                                         const unsigned int columns_,
                                         const unsigned int rows_ ) const;
 
-    // Obtain image pixel indexes (valid for PseudoClass images)
-    IndexPacket* getIndexes ( void ) const;
+    // Obtain mutable image pixel indexes (valid for PseudoClass images)
+    IndexPacket* getIndexes ( void );
 
-    // Obtain image pixel indexes (valid for PseudoClass images)
+    // Obtain immutable image pixel indexes (valid for PseudoClass images)
     const IndexPacket* getConstIndexes ( void ) const;
 
     // Transfers pixels from the image to the pixel cache as defined
