@@ -10,14 +10,14 @@
 %                            A   A    V    SSSSS                              %
 %                                                                             %
 %                                                                             %
-%                        Read/Write AVS X Image Format.                       %
+%                        Read/Write AVS X Image Format                        %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/colorspace.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -159,11 +160,6 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
-    if (SetImageExtent(image,0,0) == MagickFalse)
-      {
-        InheritException(exception,&image->exception);
-        return(DestroyImageList(image));
-      }
     length=(size_t) image->columns;
     pixels=(unsigned char *) AcquireQuantumMemory(length,4*sizeof(*pixels));
     if (pixels == (unsigned char *) NULL) 
@@ -175,7 +171,7 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if ((size_t) count != length)
         ThrowReaderException(CorruptImageError,"UnableToReadImageData");
       p=pixels;
-      q=SetImagePixels(image,0,y,image->columns,1);
+      q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
       if (q == (PixelPacket *) NULL)
         break;
       for (x=0; x < (long) image->columns; x++)
@@ -188,7 +184,7 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
           image->matte=MagickTrue;
         q++;
       }
-      if (SyncImagePixels(image) == MagickFalse)
+      if (SyncAuthenticPixels(image,exception) == MagickFalse)
         break;
       if ((image->previous == (Image *) NULL) &&
           (SetImageProgress(image,LoadImageTag,y,image->rows) == MagickFalse))
@@ -356,8 +352,8 @@ static MagickBooleanType WriteAVSImage(const ImageInfo *image_info,Image *image)
     */
     if (image->colorspace != RGBColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
-    (void) WriteBlobMSBLong(image,image->columns);
-    (void) WriteBlobMSBLong(image,image->rows);
+    (void) WriteBlobMSBLong(image,(unsigned int) image->columns);
+    (void) WriteBlobMSBLong(image,(unsigned int) image->rows);
     /*
       Allocate memory for pixels.
     */
@@ -370,7 +366,7 @@ static MagickBooleanType WriteAVSImage(const ImageInfo *image_info,Image *image)
     */
     for (y=0; y < (long) image->rows; y++)
     {
-      p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+      p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
       if (p == (PixelPacket *) NULL)
         break;
       q=pixels;
