@@ -10,14 +10,14 @@
 %                            DDDD   DDDD   SSSSS                              %
 %                                                                             %
 %                                                                             %
-%              Read Microsoft Direct Draw Surface Image Format.               %
+%              Read Microsoft Direct Draw Surface Image Format                %
 %                                                                             %
 %                              Software Design                                %
 %                             Bianca van Schaik                               %
 %                                March 2008                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/colorspace.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -494,6 +495,9 @@ static MagickBooleanType ReadDXT1(Image *image, DDSInfo *dds_info)
   DDSColors
     colors;
 
+  ExceptionInfo
+    *exception;
+
   long
     j,
     y;
@@ -515,13 +519,14 @@ static MagickBooleanType ReadDXT1(Image *image, DDSInfo *dds_info)
   unsigned long
     bits;
 
+  exception=(&image->exception);
   for (y = 0; y < (long) dds_info->height; y += 4)
   {
     for (x = 0; x < (long) dds_info->width; x += 4)
     {
       /* Get 4x4 patch of pixels to write on */
-      q = SetImagePixels(image, x, y, Min(4, dds_info->width - x),
-	                     Min(4, dds_info->height - y));
+      q = QueueAuthenticPixels(image, x, y, Min(4, dds_info->width - x),
+	                     Min(4, dds_info->height - y),exception);
       
       if (q == (PixelPacket *) NULL)
         return MagickFalse;
@@ -553,7 +558,7 @@ static MagickBooleanType ReadDXT1(Image *image, DDSInfo *dds_info)
         }
       }
       
-      if (SyncImagePixels(image) == MagickFalse)
+      if (SyncAuthenticPixels(image,exception) == MagickFalse)
         return MagickFalse;
     }
   }
@@ -568,6 +573,9 @@ static MagickBooleanType ReadDXT3(Image *image, DDSInfo *dds_info)
   DDSColors
     colors;
   
+  ExceptionInfo
+    *exception;
+
   long
     j,
     y;
@@ -592,13 +600,14 @@ static MagickBooleanType ReadDXT3(Image *image, DDSInfo *dds_info)
     c0,
     c1;
   
+  exception=(&image->exception);
   for (y = 0; y < (long) dds_info->height; y += 4)
   {
     for (x = 0; x < (long) dds_info->width; x += 4)
     {
       /* Get 4x4 patch of pixels to write on */
-      q = SetImagePixels(image, x, y, Min(4, dds_info->width - x),
-                         Min(4, dds_info->height - y));
+      q = QueueAuthenticPixels(image, x, y, Min(4, dds_info->width - x),
+                         Min(4, dds_info->height - y),exception);
       
       if (q == (PixelPacket *) NULL)
         return MagickFalse;
@@ -641,7 +650,7 @@ static MagickBooleanType ReadDXT3(Image *image, DDSInfo *dds_info)
         }
       }
       
-      if (SyncImagePixels(image) == MagickFalse)
+      if (SyncAuthenticPixels(image,exception) == MagickFalse)
         return MagickFalse;
     }
   }
@@ -656,6 +665,9 @@ static MagickBooleanType ReadDXT5(Image *image, DDSInfo *dds_info)
   DDSColors
     colors;
   
+  ExceptionInfo
+    *exception;
+
   long
     j,
     y;
@@ -684,13 +696,14 @@ static MagickBooleanType ReadDXT5(Image *image, DDSInfo *dds_info)
     c0,
     c1;
   
+  exception=(&image->exception);
   for (y = 0; y < (long) dds_info->height; y += 4)
   {
     for (x = 0; x < (long) dds_info->width; x += 4)
     {
       /* Get 4x4 patch of pixels to write on */
-      q = SetImagePixels(image, x, y, Min(4, dds_info->width - x),
-                         Min(4, dds_info->height - y));
+      q = QueueAuthenticPixels(image, x, y, Min(4, dds_info->width - x),
+                         Min(4, dds_info->height - y),exception);
       
       if (q == (PixelPacket *) NULL)
         return MagickFalse;
@@ -743,7 +756,7 @@ static MagickBooleanType ReadDXT5(Image *image, DDSInfo *dds_info)
         }
       }
       
-      if (SyncImagePixels(image) == MagickFalse)
+      if (SyncAuthenticPixels(image,exception) == MagickFalse)
         return MagickFalse;
     }
   }
@@ -755,15 +768,19 @@ static MagickBooleanType ReadDXT5(Image *image, DDSInfo *dds_info)
 
 static MagickBooleanType ReadUncompressedRGB(Image *image, DDSInfo *dds_info)
 {
+  ExceptionInfo
+    *exception;
+
   long
     x, y;
   
   PixelPacket
     *q;
   
+  exception=(&image->exception);
   for (y = 0; y < (long) dds_info->height; y++)
   {
-    q = SetImagePixels(image, 0, y, dds_info->width, 1);
+    q = QueueAuthenticPixels(image, 0, y, dds_info->width, 1,exception);
     
     if (q == (PixelPacket *) NULL)
       return MagickFalse;
@@ -776,7 +793,7 @@ static MagickBooleanType ReadUncompressedRGB(Image *image, DDSInfo *dds_info)
       q++;
     }
     
-    if (SyncImagePixels(image) == MagickFalse)
+    if (SyncAuthenticPixels(image,exception) == MagickFalse)
       return MagickFalse;
   }
   
@@ -787,15 +804,19 @@ static MagickBooleanType ReadUncompressedRGB(Image *image, DDSInfo *dds_info)
 
 static MagickBooleanType ReadUncompressedRGBA(Image *image, DDSInfo *dds_info)
 {
+  ExceptionInfo
+    *exception;
+
   long
     x, y;
   
   PixelPacket
     *q;
   
+  exception=(&image->exception);
   for (y = 0; y < (long) dds_info->height; y++)
   {
-    q = SetImagePixels(image, 0, y, dds_info->width, 1);
+    q = QueueAuthenticPixels(image, 0, y, dds_info->width, 1,exception);
     
     if (q == (PixelPacket *) NULL)
       return MagickFalse;
@@ -809,7 +830,7 @@ static MagickBooleanType ReadUncompressedRGBA(Image *image, DDSInfo *dds_info)
       q++;
     }
     
-    if (SyncImagePixels(image) == MagickFalse)
+    if (SyncAuthenticPixels(image,exception) == MagickFalse)
       return MagickFalse;
   }
   
