@@ -10,7 +10,7 @@
 %                            DDDD   P      X   X                              %
 %                                                                             %
 %                                                                             %
-%                     Read/Write SMTPE DPX Image Format.                      %
+%                     Read/Write SMTPE DPX Image Format                       %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/colorspace.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -111,14 +112,14 @@ typedef enum
 
 typedef struct _DPXFileInfo
 {
-  unsigned long
+  unsigned int
     magic,
     image_offset;
 
   char
     version[8];
 
-  unsigned long
+  unsigned int
     file_size,
     ditto_key,
     generic_size,
@@ -132,7 +133,7 @@ typedef struct _DPXFileInfo
     project[200],
     copyright[200];
 
-  unsigned long
+  unsigned int
     encrypt_key;
 
   char
@@ -149,9 +150,9 @@ typedef struct _DPXFilmInfo
     count[4],
     format[32];
 
-  unsigned long
+  unsigned int
     frame_position,
-    sequence_length,
+    sequence_extent,
     held_count;
 
   float
@@ -166,14 +167,14 @@ typedef struct _DPXFilmInfo
 
 typedef struct _DPXImageElement
 {
-  unsigned long
+  unsigned int
     data_sign,
     low_data;
 
   float
     low_quantity;
 
-  unsigned long
+  unsigned int
     high_data;
 
   float
@@ -189,7 +190,7 @@ typedef struct _DPXImageElement
     packing,
     encoding;
 
-  unsigned long
+  unsigned int
     data_offset,
     end_of_line_padding,
     end_of_image_padding;
@@ -204,7 +205,7 @@ typedef struct _DPXImageInfo
     orientation,
     number_elements;
 
-  unsigned long
+  unsigned int
     pixels_per_line,
     lines_per_element;
 
@@ -217,7 +218,7 @@ typedef struct _DPXImageInfo
 
 typedef struct _DPXOrientationInfo
 {
-  unsigned long
+  unsigned int
     x_offset,
     y_offset;
 
@@ -225,7 +226,7 @@ typedef struct _DPXOrientationInfo
     x_center,
     y_center;
 
-  unsigned long
+  unsigned int
     x_size,
     y_size;
 
@@ -238,7 +239,7 @@ typedef struct _DPXOrientationInfo
   unsigned short
     border[4];
 
-  unsigned long
+  unsigned int
     aspect_ratio[2];
 
   unsigned char
@@ -247,7 +248,7 @@ typedef struct _DPXOrientationInfo
 
 typedef struct _DPXTelevisionInfo
 {
-  unsigned long
+  unsigned int
     time_code,
     user_bits;
 
@@ -322,19 +323,19 @@ static MagickBooleanType
 %
 %  The format of the IsDPX method is:
 %
-%      MagickBooleanType IsDPX(const unsigned char *magick,const size_t length)
+%      MagickBooleanType IsDPX(const unsigned char *magick,const size_t extent)
 %
 %  A description of each parameter follows:
 %
 %    o magick: This string is generally the first few bytes of an image file
 %      or blob.
 %
-%    o length: Specifies the length of the magick string.
+%    o extent: Specifies the extent of the magick string.
 %
 */
-static MagickBooleanType IsDPX(const unsigned char *magick,const size_t length)
+static MagickBooleanType IsDPX(const unsigned char *magick,const size_t extent)
 {
-  if (length < 4)
+  if (extent < 4)
     return(MagickFalse);
   if (memcmp(magick,"SDPX",4) == 0)
     return(MagickTrue);
@@ -447,8 +448,9 @@ static inline MagickBooleanType IsFloatDefined(const float value)
       float_value;
   } quantum;
 
+  quantum.unsigned_value=0UL;
   quantum.float_value=value;
-  if (quantum.unsigned_value == 0U)
+  if (quantum.unsigned_value == 0UL)
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -557,9 +559,6 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   MagickOffsetType
     offset;
 
-  QuantumInfo
-    *quantum_info;
-
   QuantumType
     quantum_type;
 
@@ -573,11 +572,10 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     count;
 
   size_t
-    length;
+    extent;
 
   unsigned char
-    component_type,
-    *pixels;
+    component_type;
 
   unsigned long
     samples_per_pixel;
@@ -616,13 +614,13 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   offset+=4;
   offset+=ReadBlob(image,sizeof(dpx.file.version),(unsigned char *)
     dpx.file.version);
-  (void) SetImageProperty(image,"dpx:file.version",dpx.file.version);
+  (void) FormatImageProperty(image,"dpx:file.version","%.8s",dpx.file.version);
   dpx.file.file_size=ReadBlobLong(image);
   offset+=4;
   dpx.file.ditto_key=ReadBlobLong(image);
   offset+=4;
-  if (dpx.file.ditto_key != ~0UL)
-    (void) FormatImageProperty(image,"dpx:file.ditto.key","%lu",
+  if (dpx.file.ditto_key != ~0U)
+    (void) FormatImageProperty(image,"dpx:file.ditto.key","%u",
       dpx.file.ditto_key);
   dpx.file.generic_size=ReadBlobLong(image);
   offset+=4;
@@ -632,13 +630,9 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   offset+=4;
   offset+=ReadBlob(image,sizeof(dpx.file.filename),(unsigned char *)
     dpx.file.filename);
-  (void) SetImageProperty(image,"dpx:file.filename",dpx.file.filename);
-  if (*dpx.file.filename != '\0')
-    {
-      (void) FormatImageProperty(image,"dpx:file.filename","%.100s",
-        dpx.file.filename);
-      (void) FormatImageProperty(image,"document","%.100s",dpx.file.filename);
-    }
+  (void) FormatImageProperty(image,"dpx:file.filename","%.100s",
+    dpx.file.filename);
+  (void) FormatImageProperty(image,"document","%.100s",dpx.file.filename);
   offset+=ReadBlob(image,sizeof(dpx.file.timestamp),(unsigned char *)
     dpx.file.timestamp);
   if (*dpx.file.timestamp != '\0')
@@ -671,8 +665,8 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
   dpx.file.encrypt_key=ReadBlobLong(image);
   offset+=4;
-  if (dpx.file.encrypt_key != ~0UL)
-    (void) FormatImageProperty(image,"dpx:file.encrypt_key","%lu",
+  if (dpx.file.encrypt_key != ~0U)
+    (void) FormatImageProperty(image,"dpx:file.encrypt_key","%u",
       dpx.file.encrypt_key);
   offset+=ReadBlob(image,sizeof(dpx.file.reserve),(unsigned char *)
     dpx.file.reserve);
@@ -743,20 +737,20 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     dpx.image.reserve);
   component_type=dpx.image.image_element[0].descriptor;
   image->depth=dpx.image.image_element[0].bit_size;
-  if (dpx.file.image_offset >= 1664UL)
+  if (dpx.file.image_offset >= 1664U)
     {
       /*
         Read DPX orientation header.
       */
       dpx.orientation.x_offset=ReadBlobLong(image);
       offset+=4;
-      if (dpx.orientation.x_offset != ~0UL)
-        (void) FormatImageProperty(image,"dpx:orientation.x_offset","%lu",
+      if (dpx.orientation.x_offset != ~0U)
+        (void) FormatImageProperty(image,"dpx:orientation.x_offset","%u",
           dpx.orientation.x_offset);
       dpx.orientation.y_offset=ReadBlobLong(image);
       offset+=4;
-      if (dpx.orientation.y_offset != ~0UL)
-        (void) FormatImageProperty(image,"dpx:orientation.y_offset","%lu",
+      if (dpx.orientation.y_offset != ~0U)
+        (void) FormatImageProperty(image,"dpx:orientation.y_offset","%u",
           dpx.orientation.y_offset);
       dpx.orientation.x_center=ReadBlobFloat(image);
       offset+=4;
@@ -770,13 +764,13 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
           dpx.orientation.y_center);
       dpx.orientation.x_size=ReadBlobLong(image);
       offset+=4;
-      if (dpx.orientation.x_size != ~0UL)
-        (void) FormatImageProperty(image,"dpx:orientation.x_size","%lu",
+      if (dpx.orientation.x_size != ~0U)
+        (void) FormatImageProperty(image,"dpx:orientation.x_size","%u",
           dpx.orientation.x_size);
       dpx.orientation.y_size=ReadBlobLong(image);
       offset+=4;
-      if (dpx.orientation.y_size != ~0UL)
-        (void) FormatImageProperty(image,"dpx:orientation.y_size","%lu",
+      if (dpx.orientation.y_size != ~0U)
+        (void) FormatImageProperty(image,"dpx:orientation.y_size","%u",
           dpx.orientation.y_size);
       offset+=ReadBlob(image,sizeof(dpx.orientation.filename),(unsigned char *)
         dpx.orientation.filename);
@@ -812,15 +806,15 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
         dpx.orientation.aspect_ratio[i]=ReadBlobLong(image);
         offset+=4;
       }
-      if ((dpx.orientation.aspect_ratio[0] != ~0UL) &&
-          (dpx.orientation.aspect_ratio[1] != ~0UL))
+      if ((dpx.orientation.aspect_ratio[0] != ~0U) &&
+          (dpx.orientation.aspect_ratio[1] != ~0U))
         (void) FormatImageProperty(image,"dpx:orientation.aspect_ratio",
-          "%lux%lu",dpx.orientation.aspect_ratio[0],
+          "%ux%u",dpx.orientation.aspect_ratio[0],
           dpx.orientation.aspect_ratio[1]);
       offset+=ReadBlob(image,sizeof(dpx.orientation.reserve),(unsigned char *)
         dpx.orientation.reserve);
     }
-  if (dpx.file.image_offset >= 1920UL)
+  if (dpx.file.image_offset >= 1920U)
     {
       /*
         Read DPX film header.
@@ -854,18 +848,18 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
           dpx.film.format);
       dpx.film.frame_position=ReadBlobLong(image);
       offset+=4;
-      if (dpx.film.frame_position != ~0UL)
-        (void) FormatImageProperty(image,"dpx:file.frame_position","%lu",
+      if (dpx.film.frame_position != ~0U)
+        (void) FormatImageProperty(image,"dpx:film.frame_position","%u",
           dpx.film.frame_position);
-      dpx.film.sequence_length=ReadBlobLong(image);
+      dpx.film.sequence_extent=ReadBlobLong(image);
       offset+=4;
-      if (dpx.film.sequence_length != ~0UL)
-        (void) FormatImageProperty(image,"dpx:file.sequence_length","%lu",
-          dpx.film.sequence_length);
+      if (dpx.film.sequence_extent != ~0U)
+        (void) FormatImageProperty(image,"dpx:film.sequence_extent","%u",
+          dpx.film.sequence_extent);
       dpx.film.held_count=ReadBlobLong(image);
       offset+=4;
-      if (dpx.film.held_count != ~0UL)
-        (void) FormatImageProperty(image,"dpx:file.held_count","%lu",
+      if (dpx.film.held_count != ~0U)
+        (void) FormatImageProperty(image,"dpx:film.held_count","%u",
           dpx.film.held_count);
       dpx.film.frame_rate=ReadBlobFloat(image);
       offset+=4;
@@ -890,7 +884,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       offset+=ReadBlob(image,sizeof(dpx.film.reserve),(unsigned char *)
         dpx.film.reserve);
     }
-  if (dpx.file.image_offset >= 2048UL)
+  if (dpx.file.image_offset >= 2048U)
     {
       /*
         Read DPX television header.
@@ -977,7 +971,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       offset+=ReadBlob(image,sizeof(dpx.television.reserve),(unsigned char *)
         dpx.television.reserve);
     }
-  if (dpx.file.image_offset > 2080UL)
+  if (dpx.file.image_offset > 2080U)
     {
       /*
         Read DPX user header.
@@ -985,8 +979,8 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       offset+=ReadBlob(image,sizeof(dpx.user.id),(unsigned char *) dpx.user.id);
       if (*dpx.user.id != '\0')
         (void) FormatImageProperty(image,"dpx:user.id","%.32s",dpx.user.id);
-      if ((dpx.file.user_size != ~0UL) &&
-          (dpx.file.user_size > sizeof(dpx.user.id)))
+      if ((dpx.file.user_size != ~0U) &&
+          ((size_t) dpx.file.user_size > sizeof(dpx.user.id)))
         {
           StringInfo
             *profile;
@@ -1011,15 +1005,6 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Convert DPX raster image to pixel packets.
   */
-  if (SetImageExtent(image,0,0) == MagickFalse)
-    {
-      InheritException(exception,&image->exception);
-      return(DestroyImageList(image));
-    }
-  quantum_info=AcquireQuantumInfo(image_info,image);
-  quantum_info->quantum=32;
-  quantum_info->pack=dpx.image.image_element[0].packing == 0 ? MagickTrue :
-    MagickFalse;
   samples_per_pixel=1;
   quantum_type=GrayQuantum;
   switch (component_type)
@@ -1027,6 +1012,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     case CbYCrY422ComponentType:
     {
       samples_per_pixel=2;
+      quantum_type=CbYCrYQuantum;
       break;
     }
     case CbYACrYA4224ComponentType:
@@ -1050,6 +1036,8 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   }
   switch (component_type)
   {
+    case CbYCrY422ComponentType:
+    case CbYACrYA4224ComponentType:
     case CbYCr444ComponentType:
     {
       image->colorspace=Rec709YCbCrColorspace;
@@ -1063,34 +1051,47 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     default:
     {
       image->colorspace=RGBColorspace;
+      if (dpx.image.image_element[0].transfer == LogarithmicColorimetric)
+        image->colorspace=LogColorspace;
       if (dpx.image.image_element[0].transfer == PrintingDensityColorimetric)
         image->colorspace=LogColorspace;
       break;
     }
   }
-  if (image->colorspace != UndefinedColorspace)
-    image->colorspace=image->colorspace;
-  length=GetBytesPerRow(image->columns,samples_per_pixel,image->depth,
+  extent=GetBytesPerRow(image->columns,samples_per_pixel,image->depth,
     dpx.image.image_element[0].packing == 0 ? MagickFalse : MagickTrue);
-  pixels=GetQuantumPixels(quantum_info);
-  if ((quantum_type == GrayQuantum) && (quantum_info->pack == MagickFalse) &&
-      (image->depth == 10) && (image->endian == MSBEndian))
+  if ((quantum_type == GrayQuantum) &&
+      (dpx.image.image_element[0].packing != 0) && (image->depth == 10) &&
+      (image->endian == MSBEndian))
     {
       QuantumAny
-        scale;
+        range;
+
+      QuantumInfo
+        *quantum_info;
 
       register long
         x;
 
+      unsigned char
+        *pixels;
+
       unsigned long
         pixel;
 
-      pixel=0UL;
+      quantum_info=AcquireQuantumInfo(image_info,image);
+      if (quantum_info == (QuantumInfo *) NULL)
+        ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+      SetQuantumQuantum(quantum_info,32);
+      SetQuantumPack(quantum_info,dpx.image.image_element[0].packing == 0 ?
+        MagickTrue : MagickFalse);
+      pixels=GetQuantumPixels(quantum_info);
+      pixel=0U;
       i=0;
-      scale=GetQuantumScale(image->depth);
+      range=GetQuantumRange(image->depth);
       for (y=0; y < (long) image->rows; y++)
       {
-        q=SetImagePixels(image,0,y,image->columns,1);
+        q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
         if (q == (PixelPacket *) NULL)
           break;
         for (x=0; x < (long) image->columns; x++)
@@ -1100,19 +1101,17 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
             case 0:
             {
               pixel=ReadBlobMSBLong(image);
-              q->red=ScaleAnyToQuantum((pixel >> 0) & 0x3ff,image->depth,scale);
+              q->red=ScaleAnyToQuantum((pixel >> 0) & 0x3ff,range);
               break;
             }
             case 1:
             {
-              q->red=ScaleAnyToQuantum((pixel >> 10) & 0x3ff,image->depth,
-                scale);
+              q->red=ScaleAnyToQuantum((pixel >> 10) & 0x3ff,range);
               break;
             }
             case 2:
             {
-              q->red=ScaleAnyToQuantum((pixel >> 20) & 0x3ff,image->depth,
-                scale);
+              q->red=ScaleAnyToQuantum((pixel >> 20) & 0x3ff,range);
               break;
             }
           }
@@ -1120,34 +1119,101 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
           q->blue=q->red;
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
+        if (SyncAuthenticPixels(image,exception) == MagickFalse)
           break;
         status=SetImageProgress(image,LoadImageTag,y,image->rows);
         if (status == MagickFalse)
           break;
       }
+      quantum_info=DestroyQuantumInfo(quantum_info);
     }
   else
-    for (y=0; y < (long) image->rows; y++)
     {
+      long
+        row;
+
+      QuantumInfo
+        *quantum_info;
+
+      ViewInfo
+        *image_view;
+
       /*
         DPX any-bit pixel format.
       */
-      q=SetImagePixels(image,0,y,image->columns,1);
-      if (q == (PixelPacket *) NULL)
-        break;
-      count=ReadBlob(image,length,pixels);
-      if ((size_t) count != length)
-        break;
-      (void) ImportQuantumPixels(image,quantum_info,quantum_type,pixels);
-      if (SyncImagePixels(image) == MagickFalse)
-        break;
-      status=SetImageProgress(image,LoadImageTag,y,image->rows);
+      status=MagickTrue;
+      row=0;
+      quantum_info=AcquireQuantumInfo(image_info,image);
+      if (quantum_info == (QuantumInfo *) NULL)
+        ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+      SetQuantumQuantum(quantum_info,32);
+      SetQuantumPack(quantum_info,dpx.image.image_element[0].packing == 0 ?
+        MagickTrue : MagickFalse);
+      image_view=AcquireCacheView(image);
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,1) shared(row,status,quantum_type)
+#endif
+      for (y=0; y < (long) image->rows; y++)
+      {
+        long
+          offset;
+
+        MagickBooleanType
+          sync;
+
+        register PixelPacket
+          *q;
+
+        ssize_t
+          count;
+
+        size_t
+          length;
+
+        unsigned char
+          *pixels;
+
+        if (status == MagickFalse)
+          continue;
+        pixels=GetQuantumPixels(quantum_info);
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp critical (MagickCore_ReadDPXImage)
+#endif
+        {
+          count=ReadBlob(image,extent,pixels);
+          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+              (image->previous == (Image *) NULL))
+            {
+              MagickBooleanType
+                proceed;
+
+              proceed=SetImageProgress(image,LoadImageTag,row,image->rows);
+              if (proceed == MagickFalse)
+                status=MagickFalse;
+            }
+          offset=row++;
+        }
+        if (count != (ssize_t) extent)
+          status=MagickFalse;
+        q=QueueCacheViewAuthenticPixels(image_view,0,offset,image->columns,
+          1,exception);
+        if (q == (PixelPacket *) NULL)
+          {
+            status=MagickFalse;
+            continue;
+          }
+        length=ImportQuantumPixels(image,image_view,quantum_info,quantum_type,
+          pixels,exception);
+        sync=SyncCacheViewAuthenticPixels(image_view,exception);
+        if (sync == MagickFalse)
+          status=MagickFalse;
+      }
+      image_view=DestroyCacheView(image_view);
+      quantum_info=DestroyQuantumInfo(quantum_info);
       if (status == MagickFalse)
-        break;
+        ThrowReaderException(CorruptImageError,"UnableToReadImageData");
     }
   SetQuantumImageType(image,quantum_type);
-  quantum_info=DestroyQuantumInfo(quantum_info);
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
@@ -1262,7 +1328,7 @@ static inline const char *GetDPXProperty(const ImageInfo *image_info,
   return(GetImageProperty(image,property));
 }
 
-static unsigned long DecodeSMPTEBits(const char *key)
+static unsigned int DecodeSMPTEBits(const char *key)
 {
   char
     buffer[2];
@@ -1270,7 +1336,7 @@ static unsigned long DecodeSMPTEBits(const char *key)
   register long
     i;
 
-  unsigned long
+  unsigned int
     shift,
     value;
 
@@ -1285,7 +1351,7 @@ static unsigned long DecodeSMPTEBits(const char *key)
         continue;
       }
     buffer[0]=(*key++);
-    value|=(unsigned long) ((strtol(buffer,(char **) NULL,10)) << shift);
+    value|=(unsigned int) ((strtol(buffer,(char **) NULL,10)) << shift);
     shift-=4;
   }
   return(value);
@@ -1330,7 +1396,7 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
     i;
 
   size_t
-    length;
+    extent;
 
   ssize_t
     count;
@@ -1358,37 +1424,37 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   */
   (void) ResetMagickMemory(&dpx,0,sizeof(dpx));
   offset=0;
-  dpx.file.magic=0x53445058UL;
+  dpx.file.magic=0x53445058U;
   offset+=WriteBlobLong(image,dpx.file.magic);
-  dpx.file.image_offset=0x2000UL;
+  dpx.file.image_offset=0x2000U;
   profile=GetImageProfile(image,"dpx:user.data");
   if (profile != (StringInfo *) NULL)
     {
-      dpx.file.image_offset+=(unsigned long) GetStringInfoLength(profile);
+      dpx.file.image_offset+=(unsigned int) GetStringInfoLength(profile);
       dpx.file.image_offset=(((dpx.file.image_offset+0x2000-1)/0x2000)*0x2000);
     }
   offset+=WriteBlobLong(image,dpx.file.image_offset);
-  (void) CopyMagickString(dpx.file.version,"V2.0",MaxTextExtent);
+  (void) strncpy(dpx.file.version,"V2.0",sizeof(dpx.file.version));
   offset+=WriteBlob(image,8,(unsigned char *) &dpx.file.version);
-  dpx.file.file_size=4UL*image->columns*image->rows+dpx.file.image_offset;
+  dpx.file.file_size=(unsigned int) (4U*image->columns*image->rows+
+    dpx.file.image_offset);
   offset+=WriteBlobLong(image,dpx.file.file_size);
-  dpx.file.ditto_key=1UL;  /* new frame */
+  dpx.file.ditto_key=1U;  /* new frame */
   offset+=WriteBlobLong(image,dpx.file.ditto_key);
-  dpx.file.generic_size=0x00000680UL;
+  dpx.file.generic_size=0x00000680U;
   offset+=WriteBlobLong(image,dpx.file.generic_size);
-  dpx.file.industry_size=0x00000180UL;
+  dpx.file.industry_size=0x00000180U;
   offset+=WriteBlobLong(image,dpx.file.industry_size);
   dpx.file.user_size=0;
   if (profile != (StringInfo *) NULL)
     {
-      dpx.file.user_size+=(unsigned long) GetStringInfoLength(profile);
+      dpx.file.user_size+=(unsigned int) GetStringInfoLength(profile);
       dpx.file.user_size=(((dpx.file.user_size+0x2000-1)/0x2000)*0x2000);
     }
   offset+=WriteBlobLong(image,dpx.file.user_size);
-  (void) CopyMagickString(dpx.file.filename,"V2.0",sizeof(dpx.file.filename));
   value=GetDPXProperty(image_info,image,"dpx:file.filename");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.file.filename,value,sizeof(dpx.file.filename));
+    (void) strncpy(dpx.file.filename,value,sizeof(dpx.file.filename));
   offset+=WriteBlob(image,sizeof(dpx.file.filename),(unsigned char *)
     dpx.file.filename);
   seconds=time((time_t *) NULL);
@@ -1396,25 +1462,25 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
     dpx.file.timestamp);
   offset+=WriteBlob(image,sizeof(dpx.file.timestamp),(unsigned char *)
     dpx.file.timestamp);
-  (void) CopyMagickString(dpx.file.creator,GetMagickVersion((unsigned long *)
-    NULL),sizeof(dpx.file.creator));
+  (void) strncpy(dpx.file.creator,GetMagickVersion((unsigned long *) NULL),
+    sizeof(dpx.file.creator));
   value=GetDPXProperty(image_info,image,"dpx:file.creator");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.file.creator,value,sizeof(dpx.file.creator));
+    (void) strncpy(dpx.file.creator,value,sizeof(dpx.file.creator));
   offset+=WriteBlob(image,sizeof(dpx.file.creator),(unsigned char *)
     dpx.file.creator);
   value=GetDPXProperty(image_info,image,"dpx:file.project");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.file.project,value,sizeof(dpx.file.project));
+    (void) strncpy(dpx.file.project,value,sizeof(dpx.file.project));
   offset+=WriteBlob(image,sizeof(dpx.file.project),(unsigned char *)
     dpx.file.project);
   value=GetDPXProperty(image_info,image,"dpx:file.copyright");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.file.copyright,value,
+    (void) strncpy(dpx.file.copyright,value,
       sizeof(dpx.file.copyright));
   offset+=WriteBlob(image,sizeof(dpx.file.copyright),(unsigned char *)
     dpx.file.copyright);
-  dpx.file.encrypt_key=(~0UL);
+  dpx.file.encrypt_key=(~0U);
   offset+=WriteBlobLong(image,dpx.file.encrypt_key);
   offset+=WriteBlob(image,sizeof(dpx.file.reserve),(unsigned char *)
     dpx.file.reserve);
@@ -1425,17 +1491,17 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   offset+=WriteBlobShort(image,dpx.image.orientation);
   dpx.image.number_elements=1;
   offset+=WriteBlobShort(image,dpx.image.number_elements);
-  offset+=WriteBlobLong(image,image->columns);
-  offset+=WriteBlobLong(image,image->rows);
+  offset+=WriteBlobLong(image,(unsigned int) image->columns);
+  offset+=WriteBlobLong(image,(unsigned int) image->rows);
   for (i=0; i < 8; i++)
   {
-    dpx.image.image_element[i].data_sign=0UL;
+    dpx.image.image_element[i].data_sign=0U;
     offset+=WriteBlobLong(image,dpx.image.image_element[i].data_sign);
-    dpx.image.image_element[i].low_data=0UL;
+    dpx.image.image_element[i].low_data=0U;
     offset+=WriteBlobLong(image,dpx.image.image_element[i].low_data);
     dpx.image.image_element[i].low_quantity=0.0f;
     offset+=WriteBlobFloat(image,dpx.image.image_element[i].low_quantity);
-    dpx.image.image_element[i].high_data=0UL;
+    dpx.image.image_element[i].high_data=0U;
     offset+=WriteBlobLong(image,dpx.image.image_element[i].high_data);
     dpx.image.image_element[i].high_quantity=0.0f;
     offset+=WriteBlobFloat(image,dpx.image.image_element[i].high_quantity);
@@ -1459,11 +1525,11 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
     offset+=WriteBlobShort(image,dpx.image.image_element[i].packing);
     dpx.image.image_element[i].encoding=0;
     offset+=WriteBlobShort(image,dpx.image.image_element[i].encoding);
-    dpx.image.image_element[i].data_offset=0UL;
+    dpx.image.image_element[i].data_offset=0U;
     if (i == 0)
       dpx.image.image_element[i].data_offset=dpx.file.image_offset;
     offset+=WriteBlobLong(image,dpx.image.image_element[i].data_offset);
-    dpx.image.image_element[i].end_of_line_padding=0UL;
+    dpx.image.image_element[i].end_of_line_padding=0U;
     offset+=WriteBlobLong(image,dpx.image.image_element[i].end_of_line_padding);
     offset+=WriteBlobLong(image,
       dpx.image.image_element[i].end_of_image_padding);
@@ -1488,15 +1554,15 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
       (void) DeleteImageProperty(image,"dpx:orientation.x_size");
       (void) DeleteImageProperty(image,"dpx:orientation.y_size");
     }
-  dpx.orientation.x_offset=0UL;
+  dpx.orientation.x_offset=0U;
   value=GetDPXProperty(image_info,image,"dpx:orientation.x_offset");
   if (value != (const char *) NULL)
-    dpx.orientation.x_offset=(unsigned long) atol(value);
+    dpx.orientation.x_offset=(unsigned int) atoi(value);
   offset+=WriteBlobLong(image,dpx.orientation.x_offset);
-  dpx.orientation.y_offset=0UL;
+  dpx.orientation.y_offset=0U;
   value=GetDPXProperty(image_info,image,"dpx:orientation.y_offset");
   if (value != (const char *) NULL)
-    dpx.orientation.y_offset=(unsigned long) atol(value);
+    dpx.orientation.y_offset=(unsigned int) atoi(value);
   offset+=WriteBlobLong(image,dpx.orientation.y_offset);
   dpx.orientation.x_center=0.0f;
   value=GetDPXProperty(image_info,image,"dpx:orientation.x_center");
@@ -1508,19 +1574,19 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   if (value != (const char *) NULL)
     dpx.orientation.y_center=atof(value);
   offset+=WriteBlobFloat(image,dpx.orientation.y_center);
-  dpx.orientation.x_size=0UL;
+  dpx.orientation.x_size=0U;
   value=GetDPXProperty(image_info,image,"dpx:orientation.x_size");
   if (value != (const char *) NULL)
-    dpx.orientation.x_size=(unsigned long) atol(value);
+    dpx.orientation.x_size=(unsigned int) atoi(value);
   offset+=WriteBlobLong(image,dpx.orientation.x_size);
-  dpx.orientation.y_size=0UL;
+  dpx.orientation.y_size=0U;
   value=GetDPXProperty(image_info,image,"dpx:orientation.y_size");
   if (value != (const char *) NULL)
-    dpx.orientation.y_size=(unsigned long) atol(value);
+    dpx.orientation.y_size=(unsigned int) atoi(value);
   offset+=WriteBlobLong(image,dpx.orientation.y_size);
   value=GetDPXProperty(image_info,image,"dpx:orientation.filename");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.orientation.filename,value,
+    (void) strncpy(dpx.orientation.filename,value,
       sizeof(dpx.orientation.filename));
   offset+=WriteBlob(image,sizeof(dpx.orientation.filename),(unsigned char *)
     dpx.orientation.filename);
@@ -1528,7 +1594,7 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
     dpx.orientation.timestamp);
   value=GetDPXProperty(image_info,image,"dpx:orientation.device");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.orientation.device,value,
+    (void) strncpy(dpx.orientation.device,value,
       sizeof(dpx.orientation.device));
   offset+=WriteBlob(image,sizeof(dpx.orientation.device),(unsigned char *)
     dpx.orientation.device);
@@ -1550,15 +1616,15 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   for (i=0; i < 4; i++)
     offset+=WriteBlobShort(image,dpx.orientation.border[i]);
   for (i=0; i < 2; i++)
-    dpx.orientation.aspect_ratio[i]=0UL;
+    dpx.orientation.aspect_ratio[i]=0U;
   value=GetDPXProperty(image_info,image,"dpx:orientation.aspect_ratio");
   if (value != (const char *) NULL)
     {
       flags=ParseGeometry(value,&geometry_info);
       if ((flags & SigmaValue) == 0)
         geometry_info.sigma=geometry_info.rho;
-      dpx.orientation.aspect_ratio[0]=(unsigned long) (geometry_info.rho+0.5);
-      dpx.orientation.aspect_ratio[1]=(unsigned long) (geometry_info.sigma+0.5);
+      dpx.orientation.aspect_ratio[0]=(unsigned int) (geometry_info.rho+0.5);
+      dpx.orientation.aspect_ratio[1]=(unsigned int) (geometry_info.sigma+0.5);
     }
   for (i=0; i < 2; i++)
     offset+=WriteBlobLong(image,dpx.orientation.aspect_ratio[i]);
@@ -1570,51 +1636,52 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   *dpx.film.id='\0';
   value=GetDPXProperty(image_info,image,"dpx:film.id");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.film.id,value,sizeof(dpx.film.id));
+    (void) strncpy(dpx.film.id,value,sizeof(dpx.film.id));
   offset+=WriteBlob(image,sizeof(dpx.film.id),(unsigned char *) dpx.film.id);
   *dpx.film.type='\0';
   value=GetDPXProperty(image_info,image,"dpx:film.type");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.film.type,value,sizeof(dpx.film.type));
-  offset+=WriteBlob(image,sizeof(dpx.film.type),(unsigned char *) dpx.film.type);
+    (void) strncpy(dpx.film.type,value,sizeof(dpx.film.type));
+  offset+=WriteBlob(image,sizeof(dpx.film.type),(unsigned char *)
+    dpx.film.type);
   *dpx.film.offset='\0';
   value=GetDPXProperty(image_info,image,"dpx:film.offset");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.film.offset,value,sizeof(dpx.film.offset));
+    (void) strncpy(dpx.film.offset,value,sizeof(dpx.film.offset));
   offset+=WriteBlob(image,sizeof(dpx.film.offset),(unsigned char *)
     dpx.film.offset);
   *dpx.film.prefix='\0';
   value=GetDPXProperty(image_info,image,"dpx:film.prefix");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.film.prefix,value,sizeof(dpx.film.prefix));
+    (void) strncpy(dpx.film.prefix,value,sizeof(dpx.film.prefix));
   offset+=WriteBlob(image,sizeof(dpx.film.prefix),(unsigned char *)
     dpx.film.prefix);
   *dpx.film.count='\0';
   value=GetDPXProperty(image_info,image,"dpx:film.count");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.film.count,value,sizeof(dpx.film.count));
+    (void) strncpy(dpx.film.count,value,sizeof(dpx.film.count));
   offset+=WriteBlob(image,sizeof(dpx.film.count),(unsigned char *)
     dpx.film.count);
   *dpx.film.format='\0';
   value=GetDPXProperty(image_info,image,"dpx:film.format");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.film.format,value,sizeof(dpx.film.format));
+    (void) strncpy(dpx.film.format,value,sizeof(dpx.film.format));
   offset+=WriteBlob(image,sizeof(dpx.film.format),(unsigned char *)
     dpx.film.format);
-  dpx.film.frame_position=0UL;
+  dpx.film.frame_position=0U;
   value=GetDPXProperty(image_info,image,"dpx:film.frame_position");
   if (value != (const char *) NULL)
-    dpx.film.frame_position=(unsigned long) atol(value);
+    dpx.film.frame_position=(unsigned int) atoi(value);
   offset+=WriteBlobLong(image,dpx.film.frame_position);
-  dpx.film.sequence_length=0UL;
-  value=GetDPXProperty(image_info,image,"dpx:film.sequence_length");
+  dpx.film.sequence_extent=0U;
+  value=GetDPXProperty(image_info,image,"dpx:film.sequence_extent");
   if (value != (const char *) NULL)
-    dpx.film.sequence_length=(unsigned long) atol(value);
-  offset+=WriteBlobLong(image,dpx.film.sequence_length);
-  dpx.film.held_count=0UL;
+    dpx.film.sequence_extent=(unsigned int) atoi(value);
+  offset+=WriteBlobLong(image,dpx.film.sequence_extent);
+  dpx.film.held_count=0U;
   value=GetDPXProperty(image_info,image,"dpx:film.held_count");
   if (value != (const char *) NULL)
-    dpx.film.held_count=(unsigned long) atol(value);
+    dpx.film.held_count=(unsigned int) atoi(value);
   offset+=WriteBlobLong(image,dpx.film.held_count);
   dpx.film.frame_rate=0.0f;
   value=GetDPXProperty(image_info,image,"dpx:film.frame_rate");
@@ -1629,12 +1696,12 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   *dpx.film.frame_id='\0';
   value=GetDPXProperty(image_info,image,"dpx:film.frame_id");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.film.frame_id,value,sizeof(dpx.film.frame_id));
+    (void) strncpy(dpx.film.frame_id,value,sizeof(dpx.film.frame_id));
   offset+=WriteBlob(image,sizeof(dpx.film.frame_id),(unsigned char *)
     dpx.film.frame_id);
   value=GetDPXProperty(image_info,image,"dpx:film.slate");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.film.slate,value,sizeof(dpx.film.slate));
+    (void) strncpy(dpx.film.slate,value,sizeof(dpx.film.slate));
   offset+=WriteBlob(image,sizeof(dpx.film.slate),(unsigned char *)
     dpx.film.slate);
   offset+=WriteBlob(image,sizeof(dpx.film.reserve),(unsigned char *)
@@ -1726,7 +1793,7 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   */
   value=GetDPXProperty(image_info,image,"dpx:user.id");
   if (value != (const char *) NULL)
-    (void) CopyMagickString(dpx.user.id,value,sizeof(dpx.user.id));
+    (void) strncpy(dpx.user.id,value,sizeof(dpx.user.id));
   offset+=WriteBlob(image,sizeof(dpx.user.id),(unsigned char *) dpx.user.id);
   if (profile != (StringInfo *) NULL)
     offset+=WriteBlob(image,GetStringInfoLength(profile),
@@ -1741,21 +1808,22 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   quantum_info->pack=dpx.image.image_element[0].packing == 0 ? MagickTrue :
     MagickFalse;
   quantum_type=RGBQuantum;
-  length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
+  extent=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
   if (0)
     {
       quantum_type=GrayQuantum;
-      length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
+      extent=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
     }
   pixels=GetQuantumPixels(quantum_info);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+    p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    (void) ExportQuantumPixels(image,quantum_info,quantum_type,pixels);
-    count=WriteBlob(image,length,pixels);
-    if (count != (ssize_t) length)
+    (void) ExportQuantumPixels(image,(const ViewInfo *) NULL,quantum_info,
+      quantum_type,pixels,&image->exception);
+    count=WriteBlob(image,extent,pixels);
+    if (count != (ssize_t) extent)
       break;
     status=SetImageProgress(image,SaveImageTag,y,image->rows);
     if (status == MagickFalse)
