@@ -10,14 +10,14 @@
 %                         GGG   R  R   A   A    Y                             %
 %                                                                             %
 %                                                                             %
-%                    Read/Write RAW Gray Image Format.                        %
+%                    Read/Write RAW Gray Image Format                         %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/colorspace.h"
 #include "magick/constitute.h"
 #include "magick/exception.h"
@@ -166,6 +167,8 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
   (void) SetImageVirtualPixelMethod(canvas_image,BlackVirtualPixelMethod);
   quantum_type=GrayQuantum;
   quantum_info=AcquireQuantumInfo(image_info,canvas_image);
+  if (quantum_info == (QuantumInfo *) NULL)
+    ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   pixels=GetQuantumPixels(quantum_info);
   if (image_info->number_scenes != 0)
     while (image->scene < image_info->scene)
@@ -190,28 +193,27 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
-    if ((SetImageExtent(image,0,0) == MagickFalse) ||
-        (SetImageExtent(canvas_image,0,0) == MagickFalse))
-      break;
     length=GetQuantumExtent(canvas_image,quantum_info,quantum_type);
     count=ReadBlob(image,length,pixels);
     if (count != (ssize_t) length)
       break;
     for (y=0; y < (long) image->extract_info.height; y++)
     {
-      q=GetImagePixels(canvas_image,0,0,canvas_image->columns,1);
+      q=GetAuthenticPixels(canvas_image,0,0,canvas_image->columns,1,exception);
       if (q == (PixelPacket *) NULL)
         break;
-      length=ImportQuantumPixels(canvas_image,quantum_info,quantum_type,pixels);
-      if (SyncImagePixels(canvas_image) == MagickFalse)
+      length=ImportQuantumPixels(canvas_image,(ViewInfo *) NULL,quantum_info,
+        quantum_type,pixels,exception);
+      if (SyncAuthenticPixels(canvas_image,exception) == MagickFalse)
         break;
       count=ReadBlob(image,length,pixels);
       if (((y-image->extract_info.y) >= 0) && 
           ((y-image->extract_info.y) < (long) image->rows))
         {
-          p=AcquireImagePixels(canvas_image,canvas_image->extract_info.x,0,
+          p=GetVirtualPixels(canvas_image,canvas_image->extract_info.x,0,
             image->columns,1,exception);
-          q=SetImagePixels(image,0,y-image->extract_info.y,image->columns,1);
+          q=QueueAuthenticPixels(image,0,y-image->extract_info.y,image->columns,
+            1,exception);
           if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
             break;
           for (x=0; x < (long) image->columns; x++)
@@ -222,7 +224,7 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
             p++;
             q++;
           }
-          if (SyncImagePixels(image) == MagickFalse)
+          if (SyncAuthenticPixels(image,exception) == MagickFalse)
             break;
         }
       if (image->previous == (Image *) NULL)
@@ -297,6 +299,7 @@ ModuleExport unsigned long RegisterGRAYImage(void)
   entry->encoder=(EncodeImageHandler *) WriteGRAYImage;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
+  entry->format_type=ExplicitFormatType;
   entry->description=ConstantString("Raw gray samples");
   entry->module=ConstantString("GRAY");
   (void) RegisterMagickInfo(entry);
@@ -405,13 +408,16 @@ static MagickBooleanType WriteGRAYImage(const ImageInfo *image_info,
       (void) SetImageColorspace(image,RGBColorspace);
     quantum_type=GrayQuantum;
     quantum_info=AcquireQuantumInfo(image_info,image);
+    if (quantum_info == (QuantumInfo *) NULL)
+      ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     pixels=GetQuantumPixels(quantum_info);
     for (y=0; y < (long) image->rows; y++)
     {
-      p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+      p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
       if (p == (const PixelPacket *) NULL)
         break;
-      length=ExportQuantumPixels(image,quantum_info,quantum_type,pixels);
+      length=ExportQuantumPixels(image,(const ViewInfo *) NULL,quantum_info,
+        quantum_type,pixels,&image->exception);
       count=WriteBlob(image,length,pixels);
       if (count != (ssize_t) length)
         break;
