@@ -44,6 +44,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
@@ -396,11 +397,6 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
         image->storage_class=PseudoClass;
         image->depth=8;
       }
-    if (SetImageExtent(image,0,0) == MagickFalse)
-      {
-        InheritException(exception,&image->exception);
-        return(DestroyImageList(image));
-      }
     one_row=(unsigned char *) AcquireQuantumMemory(bytes_per_row,
       sizeof(*one_row));
     if (one_row == (unsigned char *) NULL)
@@ -457,10 +453,10 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
             }
         }
       ptr=one_row;
-      q=SetImagePixels(image,0,y,image->columns,1);
+      q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
       if (q == (PixelPacket *) NULL)
         break;
-      indexes=GetIndexes(image);
+      indexes=GetAuthenticIndexQueue(image);
       if (bits_per_pixel == 16)
         {
           if (image->columns > (2*bytes_per_row))
@@ -494,7 +490,7 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
                 bit=8-bits_per_pixel;
               }
           }
-          if (SyncImagePixels(image) == MagickFalse)
+          if (SyncAuthenticPixels(image,exception) == MagickFalse)
             break;
         }
         if (image->previous == (Image *) NULL)
@@ -810,11 +806,11 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
           affinity_image=ConstituteImage(256,1,"RGB",CharPixel,&PalmPalette,
             &exception);
           (void) SetImageColorspace(affinity_image,affinity_image->colorspace);
-          (void) AffinityImage(quantize_info,image,affinity_image);
+          (void) RemapImage(quantize_info,image,affinity_image);
           for (y=0; y < (long) image->rows; y++)
           {
-            p=GetImagePixels(image,0,y,image->columns,1);
-            indexes=GetIndexes(image);
+            p=GetAuthenticPixels(image,0,y,image->columns,1,&exception);
+            indexes=GetAuthenticIndexQueue(image);
             for (x=0; x < (long) image->columns; x++)
               indexes[x]=(IndexPacket) FindColor(&image->colormap[(long)
                 indexes[x]]);
@@ -837,10 +833,10 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
     {
       ptr=one_row;
       (void) ResetMagickMemory(ptr,0,bytes_per_row);
-      p=GetImagePixels(image,0,y,image->columns,1);
+      p=GetAuthenticPixels(image,0,y,image->columns,1,&exception);
       if (p == (PixelPacket *) NULL)
         break;
-      indexes=GetIndexes(image);
+      indexes=GetAuthenticIndexQueue(image);
       if (bits_per_pixel == 16)
         {
           for (x=0; x < (int) image->columns; x++)
