@@ -533,7 +533,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image=DestroyImage(image);
       return((Image *) NULL);
     }
-  status=write(file," ",1);
+  (void) write(file," ",1);
   file=close(file)-1;
   /*
     Render Postscript with the Ghostscript delegate.
@@ -1161,10 +1161,6 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     resolution.y=geometry_info.sigma;
     if ((flags & SigmaValue) == 0)
       resolution.y=resolution.x;
-    if (image->x_resolution != 0.0)
-      resolution.x=image->x_resolution;
-    if (image->y_resolution != 0.0)
-      resolution.y=image->y_resolution;
     if (image_info->density != (char *) NULL)
       {
         flags=ParseGeometry(image_info->density,&geometry_info);
