@@ -251,9 +251,6 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   QuantumType
     quantum_type;
 
-  register const unsigned char
-    *p;
-
   register long
     x;
 
@@ -612,7 +609,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             continue;
           pixels=GetQuantumPixels(quantum_info);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-          #pragma omp critical
+          #pragma omp critical (MagickCore_ReadPNMImage)
 #endif
           {
             count=ReadBlob(image,extent,pixels);
@@ -655,12 +652,12 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       case '5':
       {
         QuantumAny
-          scale;
+          range;
 
         /*
           Convert PGM raw image to pixel packets.
         */
-        scale=GetQuantumScale(image->depth);
+        range=GetQuantumRange(image->depth);
         quantum_type=GrayQuantum;
         extent=(image->depth <= 8 ? 1 : 2)*image->columns;
         quantum_info=AcquireQuantumInfo(image_info,image);
@@ -697,7 +694,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             continue;
           pixels=GetQuantumPixels(quantum_info);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-          #pragma omp critical
+          #pragma omp critical (MagickCore_ReadPNMImage)
 #endif
           {
             count=ReadBlob(image,extent,pixels);
@@ -735,7 +732,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 for (x=0; x < (long) image->columns; x++)
                 {
                   p=PushCharPixel(p,&pixel);
-                  q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+                  q->red=ScaleAnyToQuantum(pixel,range);
                   q->green=q->red;
                   q->blue=q->red;
                   q++;
@@ -749,7 +746,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 for (x=0; x < (long) image->columns; x++)
                 {
                   p=PushShortPixel(MSBEndian,p,&pixel);
-                  q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+                  q->red=ScaleAnyToQuantum(pixel,range);
                   q->green=q->red;
                   q->blue=q->red;
                   q++;
@@ -772,7 +769,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           type;
 
         QuantumAny
-          scale;
+          range;
 
         /*
           Convert PNM raster image to pixel packets.
@@ -780,7 +777,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         type=BilevelType;
         quantum_type=RGBQuantum;
         extent=3*(image->depth <= 8 ? 1 : 2)*image->columns;
-        scale=GetQuantumScale(image->depth);
+        range=GetQuantumRange(image->depth);
         quantum_info=AcquireQuantumInfo(image_info,image);
         if (quantum_info == (QuantumInfo *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -796,6 +793,9 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           MagickBooleanType
             sync;
 
+          register const unsigned char
+            *p;
+
           register long
             x;
 
@@ -815,7 +815,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             continue;
           pixels=GetQuantumPixels(quantum_info);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-          #pragma omp critical
+          #pragma omp critical (MagickCore_ReadPNMImage)
 #endif
           {
             count=ReadBlob(image,extent,pixels);
@@ -840,6 +840,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
               status=MagickFalse;
               continue;
             }
+          p=pixels;
           if ((image->depth == 8) || (image->depth == 16))
             {
               length=ImportQuantumPixels(image,image_view,quantum_info,
@@ -860,11 +861,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 for (x=0; x < (long) image->columns; x++)
                 {
                   p=PushCharPixel(p,&pixel);
-                  r->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+                  r->red=ScaleAnyToQuantum(pixel,range);
                   p=PushCharPixel(p,&pixel);
-                  r->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+                  r->green=ScaleAnyToQuantum(pixel,range);
                   p=PushCharPixel(p,&pixel);
-                  r->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+                  r->blue=ScaleAnyToQuantum(pixel,range);
                   r++;
                 }
               }
@@ -880,11 +881,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 for (x=0; x < (long) image->columns; x++)
                 {
                   p=PushShortPixel(MSBEndian,p,&pixel);
-                  r->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+                  r->red=ScaleAnyToQuantum(pixel,range);
                   p=PushShortPixel(MSBEndian,p,&pixel);
-                  r->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+                  r->green=ScaleAnyToQuantum(pixel,range);
                   p=PushShortPixel(MSBEndian,p,&pixel);
-                  r->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+                  r->blue=ScaleAnyToQuantum(pixel,range);
                   r++;
                 }
               }
@@ -919,12 +920,12 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           *indexes;
 
         QuantumAny
-          scale;
+          range;
 
         /*
           Convert PAM raster image to pixel packets.
         */
-        scale=GetQuantumScale(image->depth);
+        range=GetQuantumRange(image->depth);
         switch (quantum_type)
         {
           case GrayQuantum:
@@ -979,7 +980,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             continue;
           pixels=GetQuantumPixels(quantum_info);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-          #pragma omp critical
+          #pragma omp critical (MagickCore_ReadPNMImage)
 #endif
           {
             count=ReadBlob(image,extent,pixels);
@@ -1023,14 +1024,13 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     for (x=0; x < (long) image->columns; x++)
                     {
                       p=PushCharPixel(p,&pixel);
-                      q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->red=ScaleAnyToQuantum(pixel,range);
                       q->green=q->red;
                       q->blue=q->red;
                       if (image->matte != MagickFalse)
                         {
                           p=PushCharPixel(p,&pixel);
-                          q->opacity=ScaleAnyToQuantum(pixel,image->depth,
-                            scale);
+                          q->opacity=ScaleAnyToQuantum(pixel,range);
                         }
                       q++;
                     }
@@ -1043,14 +1043,13 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     for (x=0; x < (long) image->columns; x++)
                     {
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->red=ScaleAnyToQuantum(pixel,range);
                       q->green=q->red;
                       q->blue=q->red;
                       if (image->matte != MagickFalse)
                         {
                           p=PushShortPixel(MSBEndian,p,&pixel);
-                          q->opacity=ScaleAnyToQuantum(pixel,image->depth,
-                            scale);
+                          q->opacity=ScaleAnyToQuantum(pixel,range);
                         }
                       q++;
                     }
@@ -1068,18 +1067,17 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     for (x=0; x < (long) image->columns; x++)
                     {
                       p=PushCharPixel(p,&pixel);
-                      q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->red=ScaleAnyToQuantum(pixel,range);
                       p=PushCharPixel(p,&pixel);
-                      q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->green=ScaleAnyToQuantum(pixel,range);
                       p=PushCharPixel(p,&pixel);
-                      q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->blue=ScaleAnyToQuantum(pixel,range);
                       p=PushCharPixel(p,&pixel);
-                      indexes[x]=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      indexes[x]=ScaleAnyToQuantum(pixel,range);
                       if (image->matte != MagickFalse)
                         {
                           p=PushCharPixel(p,&pixel);
-                          q->opacity=ScaleAnyToQuantum(pixel,image->depth,
-                            scale);
+                          q->opacity=ScaleAnyToQuantum(pixel,range);
                         }
                       q++;
                     }
@@ -1092,18 +1090,17 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     for (x=0; x < (long) image->columns; x++)
                     {
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->red=ScaleAnyToQuantum(pixel,range);
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->green=ScaleAnyToQuantum(pixel,range);
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->blue=ScaleAnyToQuantum(pixel,range);
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      indexes[x]=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      indexes[x]=ScaleAnyToQuantum(pixel,range);
                       if (image->matte != MagickFalse)
                         {
                           p=PushShortPixel(MSBEndian,p,&pixel);
-                          q->opacity=ScaleAnyToQuantum(pixel,image->depth,
-                            scale);
+                          q->opacity=ScaleAnyToQuantum(pixel,range);
                         }
                       q++;
                     }
@@ -1120,16 +1117,15 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     for (x=0; x < (long) image->columns; x++)
                     {
                       p=PushCharPixel(p,&pixel);
-                      q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->red=ScaleAnyToQuantum(pixel,range);
                       p=PushCharPixel(p,&pixel);
-                      q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->green=ScaleAnyToQuantum(pixel,range);
                       p=PushCharPixel(p,&pixel);
-                      q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->blue=ScaleAnyToQuantum(pixel,range);
                       if (image->matte != MagickFalse)
                         {
                           p=PushCharPixel(p,&pixel);
-                          q->opacity=ScaleAnyToQuantum(pixel,image->depth,
-                            scale);
+                          q->opacity=ScaleAnyToQuantum(pixel,range);
                         }
                       q++;
                     }
@@ -1142,16 +1138,15 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     for (x=0; x < (long) image->columns; x++)
                     {
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->red=ScaleAnyToQuantum(pixel,range);
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->green=ScaleAnyToQuantum(pixel,range);
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+                      q->blue=ScaleAnyToQuantum(pixel,range);
                       if (image->matte != MagickFalse)
                         {
                           p=PushShortPixel(MSBEndian,p,&pixel);
-                          q->opacity=ScaleAnyToQuantum(pixel,image->depth,
-                            scale);
+                          q->opacity=ScaleAnyToQuantum(pixel,range);
                         }
                       q++;
                     }
@@ -1219,7 +1214,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             continue;
           pixels=GetQuantumPixels(quantum_info);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-          #pragma omp critical
+          #pragma omp critical (MagickCore_ReadPNMImage)
 #endif
           {
             count=ReadBlob(image,extent,pixels);
@@ -1827,7 +1822,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
       case '5':
       {
         QuantumAny
-          scale;
+          range;
 
         /*
           Convert image to a PGM image.
@@ -1843,7 +1838,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         quantum_info->min_is_white=MagickTrue;
         pixels=GetQuantumPixels(quantum_info);
         extent=GetQuantumExtent(image,quantum_info,GrayQuantum);
-        scale=GetQuantumScale(image->depth);
+        range=GetQuantumRange(image->depth);
         for (y=0; y < (long) image->rows; y++)
         {
           p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
@@ -1859,14 +1854,13 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                 for (x=0; x < (long) image->columns; x++)
                 {
                   if (IsGrayPixel(p) == MagickFalse)
-                    pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),
-                      image->depth,scale);
+                    pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),range);
                   else
                     {
                       if (image->depth == 8)
                         pixel=ScaleQuantumToChar(p->red);
                       else
-                        pixel=ScaleQuantumToAny(p->red,image->depth,scale);
+                        pixel=ScaleQuantumToAny(p->red,range);
                     }
                   q=PopCharPixel((unsigned char) pixel,q);
                   p++;
@@ -1875,14 +1869,13 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                 for (x=0; x < (long) image->columns; x++)
                 {
                   if (IsGrayPixel(p) == MagickFalse)
-                    pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),
-                      image->depth,scale);
+                    pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),range);
                   else
                     {
                       if (image->depth == 16)
                         pixel=ScaleQuantumToShort(p->red);
                       else
-                        pixel=ScaleQuantumToAny(p->red,image->depth,scale);
+                        pixel=ScaleQuantumToAny(p->red,range);
                     }
                   q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                   p++;
@@ -1905,7 +1898,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
       case '6':
       {
         QuantumAny
-          scale;
+          range;
 
         /*
           Convert image to a PNM image.
@@ -1920,7 +1913,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
         pixels=GetQuantumPixels(quantum_info);
         extent=GetQuantumExtent(image,quantum_info,quantum_type);
-        scale=GetQuantumScale(image->depth);
+        range=GetQuantumRange(image->depth);
         for (y=0; y < (long) image->rows; y++)
         {
           p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
@@ -1935,16 +1928,16 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
               if (image->depth <= 8)
                 for (x=0; x < (long) image->columns; x++)
                 {
-                  pixel=ScaleQuantumToAny(p->red,image->depth,scale);
+                  pixel=ScaleQuantumToAny(p->red,range);
                   q=PopCharPixel((unsigned char) pixel,q);
-                  pixel=ScaleQuantumToAny(p->green,image->depth,scale);
+                  pixel=ScaleQuantumToAny(p->green,range);
                   q=PopCharPixel((unsigned char) pixel,q);
-                  pixel=ScaleQuantumToAny(p->blue,image->depth,scale);
+                  pixel=ScaleQuantumToAny(p->blue,range);
                   q=PopCharPixel((unsigned char) pixel,q);
                   if (image->matte != MagickFalse)
                     {
                       pixel=ScaleQuantumToAny((Quantum) (QuantumRange-
-                        p->opacity),image->depth,scale);
+                        p->opacity),range);
                       q=PopCharPixel((unsigned char) pixel,q);
                     }
                   p++;
@@ -1952,16 +1945,16 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
               else
                 for (x=0; x < (long) image->columns; x++)
                 {
-                  pixel=ScaleQuantumToAny(p->red,image->depth,scale);
+                  pixel=ScaleQuantumToAny(p->red,range);
                   q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                  pixel=ScaleQuantumToAny(p->green,image->depth,scale);
+                  pixel=ScaleQuantumToAny(p->green,range);
                   q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                  pixel=ScaleQuantumToAny(p->blue,image->depth,scale);
+                  pixel=ScaleQuantumToAny(p->blue,range);
                   q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                   if (image->matte != MagickFalse)
                     {
                       pixel=ScaleQuantumToAny((Quantum) (QuantumRange-
-                        p->opacity),image->depth,scale);
+                        p->opacity),range);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                     }
                   p++;
@@ -1984,7 +1977,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
       case '7':
       {
         QuantumAny
-          scale;
+          range;
 
         /*
           Convert image to a PAM.
@@ -2001,7 +1994,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
               ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
           }
         pixels=GetQuantumPixels(quantum_info);
-        scale=GetQuantumScale(image->depth);
+        range=GetQuantumRange(image->depth);
         for (y=0; y < (long) image->rows; y++)
         {
           p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
@@ -2022,13 +2015,12 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   if (image->depth <= 8)
                     for (x=0; x < (long) image->columns; x++)
                     {
-                      pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),
-                        image->depth,scale);
+                      pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),range);
                       q=PopCharPixel((unsigned char) pixel,q);
                       if (image->matte != MagickFalse)
                         {
                           pixel=(unsigned char) ScaleQuantumToAny(p->opacity,
-                            image->depth,scale);
+                            range);
                           q=PopCharPixel((unsigned char) pixel,q);
                         }
                       p++;
@@ -2036,13 +2028,12 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   else
                     for (x=0; x < (long) image->columns; x++)
                     {
-                      pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),
-                        image->depth,scale);
+                      pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),range);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                       if (image->matte != MagickFalse)
                         {
                           pixel=(unsigned char) ScaleQuantumToAny(p->opacity,
-                            image->depth,scale);
+                            range);
                           q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                         }
                       p++;
@@ -2055,18 +2046,18 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   if (image->depth <= 8)
                     for (x=0; x < (long) image->columns; x++)
                     {
-                      pixel=ScaleQuantumToAny(p->red,image->depth,scale);
+                      pixel=ScaleQuantumToAny(p->red,range);
                       q=PopCharPixel((unsigned char) pixel,q);
-                      pixel=ScaleQuantumToAny(p->green,image->depth,scale);
+                      pixel=ScaleQuantumToAny(p->green,range);
                       q=PopCharPixel((unsigned char) pixel,q);
-                      pixel=ScaleQuantumToAny(p->blue,image->depth,scale);
+                      pixel=ScaleQuantumToAny(p->blue,range);
                       q=PopCharPixel((unsigned char) pixel,q);
-                      pixel=ScaleQuantumToAny(indexes[x],image->depth,scale);
+                      pixel=ScaleQuantumToAny(indexes[x],range);
                       q=PopCharPixel((unsigned char) pixel,q);
                       if (image->matte != MagickFalse)
                         {
                           pixel=ScaleQuantumToAny((Quantum) (QuantumRange-
-                            p->opacity),image->depth,scale);
+                            p->opacity),range);
                           q=PopCharPixel((unsigned char) pixel,q);
                         }
                       p++;
@@ -2074,18 +2065,18 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   else
                     for (x=0; x < (long) image->columns; x++)
                     {
-                      pixel=ScaleQuantumToAny(p->red,image->depth,scale);
+                      pixel=ScaleQuantumToAny(p->red,range);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                      pixel=ScaleQuantumToAny(p->green,image->depth,scale);
+                      pixel=ScaleQuantumToAny(p->green,range);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                      pixel=ScaleQuantumToAny(p->blue,image->depth,scale);
+                      pixel=ScaleQuantumToAny(p->blue,range);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                      pixel=ScaleQuantumToAny(indexes[x],image->depth,scale);
+                      pixel=ScaleQuantumToAny(indexes[x],range);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                       if (image->matte != MagickFalse)
                         {
                           pixel=ScaleQuantumToAny((Quantum) (QuantumRange-
-                            p->opacity),image->depth,scale);
+                            p->opacity),range);
                           q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                         }
                       p++;
@@ -2097,16 +2088,16 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   if (image->depth <= 8)
                     for (x=0; x < (long) image->columns; x++)
                     {
-                      pixel=ScaleQuantumToAny(p->red,image->depth,scale);
+                      pixel=ScaleQuantumToAny(p->red,range);
                       q=PopCharPixel((unsigned char) pixel,q);
-                      pixel=ScaleQuantumToAny(p->green,image->depth,scale);
+                      pixel=ScaleQuantumToAny(p->green,range);
                       q=PopCharPixel((unsigned char) pixel,q);
-                      pixel=ScaleQuantumToAny(p->blue,image->depth,scale);
+                      pixel=ScaleQuantumToAny(p->blue,range);
                       q=PopCharPixel((unsigned char) pixel,q);
                       if (image->matte != MagickFalse)
                         {
                           pixel=ScaleQuantumToAny((Quantum) (QuantumRange-
-                            p->opacity),image->depth,scale);
+                            p->opacity),range);
                           q=PopCharPixel((unsigned char) pixel,q);
                         }
                       p++;
@@ -2114,16 +2105,16 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   else
                     for (x=0; x < (long) image->columns; x++)
                     {
-                      pixel=ScaleQuantumToAny(p->red,image->depth,scale);
+                      pixel=ScaleQuantumToAny(p->red,range);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                      pixel=ScaleQuantumToAny(p->green,image->depth,scale);
+                      pixel=ScaleQuantumToAny(p->green,range);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                      pixel=ScaleQuantumToAny(p->blue,image->depth,scale);
+                      pixel=ScaleQuantumToAny(p->blue,range);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                       if (image->matte != MagickFalse)
                         {
                           pixel=ScaleQuantumToAny((Quantum) (QuantumRange-
-                            p->opacity),image->depth,scale);
+                            p->opacity),range);
                           q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                         }
                       p++;
