@@ -10,14 +10,14 @@
 %                               P      SSSSS                                  %
 %                                                                             %
 %                                                                             %
-%                         Read/Write Postscript Format.                       %
+%                         Read/Write Postscript Format                        %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
@@ -477,7 +478,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     */
     *p++=(char) c;
     if ((strchr("\n\r%",c) == (char *) NULL) &&
-        ((size_t) (p-command) < MaxTextExtent))
+        ((size_t) (p-command) < (MaxTextExtent-1)))
       continue;
     *p='\0';
     p=command;
@@ -556,7 +557,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
           GetStringInfoDatum(profile)[i]=(unsigned char) c;
           *p++=(char) c;
           if ((strchr("\n\r%",c) == (char *) NULL) &&
-              ((size_t) (p-command) < MaxTextExtent))
+              ((size_t) (p-command) < (MaxTextExtent-1)))
             continue;
           *p='\0';
           p=command;
@@ -572,7 +573,12 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     */
     length=strlen(DocumentProcessColors);
     if (LocaleNCompare(DocumentProcessColors,command,length) == 0)
-      cmyk=MagickTrue;
+      {
+        if ((GlobExpression(command,"*Cyan*",MagickTrue) != MagickFalse) ||
+            (GlobExpression(command,"*Magenta*",MagickTrue) != MagickFalse) ||
+            (GlobExpression(command,"*Yellow*",MagickTrue) != MagickFalse))
+          cmyk=MagickTrue;
+      }
     if (LocaleNCompare(CMYKCustomColor,command,strlen(CMYKCustomColor)) == 0)
       cmyk=MagickTrue;
     length=strlen(DocumentCustomColors);
@@ -655,10 +661,10 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) CopyMagickString(command,"/setpagedevice {pop} bind 1 index where {"
     "dup wcheck {3 1 roll put} {pop def} ifelse} {def} ifelse\n"
     "<</UseCIEColor true>>setpagedevice\n",MaxTextExtent);
-  (void) write(file,command,(unsigned int) strlen(command));
+  length=write(file,command,(unsigned int) strlen(command));
   (void) FormatMagickString(translate_geometry,MaxTextExtent,
     "%g %g translate\n",-bounds.x1,-bounds.y1);
-  (void) write(file,translate_geometry,strlen(translate_geometry));
+  length=write(file,translate_geometry,strlen(translate_geometry));
   file=close(file)-1;
   /*
     Render Postscript with the Ghostscript delegate.
@@ -964,7 +970,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
       q=PopHexPixel(hex_digits,ScaleQuantumToChar(pixel.green),q); \
       q=PopHexPixel(hex_digits,ScaleQuantumToChar(pixel.blue),q); \
     } \
-  q=PopHexPixel(hex_digits,MagickMin(length,0xff),q); \
+  q=PopHexPixel(hex_digits,(const unsigned long) MagickMin(length,0xff),q); \
 }
 
   static const char
@@ -1298,12 +1304,12 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
     media_info,
     page_info;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
-  register IndexPacket
-    *indexes;
-
   register long
     i,
     x;
@@ -1359,10 +1365,6 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
     resolution.y=geometry_info.sigma;
     if ((flags & SigmaValue) == 0)
       resolution.y=resolution.x;
-    if (image->x_resolution != 0.0)
-      resolution.x=image->x_resolution;
-    if (image->y_resolution != 0.0)
-      resolution.y=image->y_resolution;
     if (image_info->density != (char *) NULL)
       {
         flags=ParseGeometry(image_info->density,&geometry_info);
@@ -1397,7 +1399,8 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
     scale.y=(double) (geometry.height*delta.y)/resolution.y;
     geometry.height=(unsigned long) (scale.y+0.5);
     (void) ParseAbsoluteGeometry(page_geometry,&media_info);
-    (void) ParseGravityGeometry(image,page_geometry,&page_info);
+    (void) ParseGravityGeometry(image,page_geometry,&page_info,
+      &image->exception);
     if (image->gravity != UndefinedGravity)
       {
         geometry.x=(-page_info.x);
@@ -1538,11 +1541,11 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
             q=pixels;
             for (y=0; y < (long) image->rows; y++)
             {
-              p=AcquireImagePixels(preview_image,0,y,preview_image->columns,1,
+              p=GetVirtualPixels(preview_image,0,y,preview_image->columns,1,
                 &preview_image->exception);
               if (p == (const PixelPacket *) NULL)
                 break;
-              indexes=GetIndexes(preview_image);
+              indexes=GetVirtualIndexQueue(preview_image);
               bit=0;
               byte=0;
               for (x=0; x < (long) preview_image->columns; x++)
@@ -1677,7 +1680,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
             q=pixels;
             for (y=0; y < (long) image->rows; y++)
             {
-              p=AcquireImagePixels(image,0,y,image->columns,1,
+              p=GetVirtualPixels(image,0,y,image->columns,1,
                 &image->exception);
               if (p == (const PixelPacket *) NULL)
                 break;
@@ -1724,11 +1727,11 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
             q=pixels;
             for (y=0; y < (long) image->rows; y++)
             {
-              p=AcquireImagePixels(image,0,y,image->columns,1,
+              p=GetVirtualPixels(image,0,y,image->columns,1,
                 &image->exception);
               if (p == (const PixelPacket *) NULL)
                 break;
-              indexes=GetIndexes(image);
+              indexes=GetVirtualIndexQueue(image);
               bit=0;
               byte=0;
               for (x=0; x < (long) image->columns; x++)
@@ -1798,7 +1801,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
               q=pixels;
               for (y=0; y < (long) image->rows; y++)
               {
-                p=AcquireImagePixels(image,0,y,image->columns,1,
+                p=GetVirtualPixels(image,0,y,image->columns,1,
                   &image->exception);
                 if (p == (const PixelPacket *) NULL)
                   break;
@@ -1858,7 +1861,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
               q=pixels;
               for (y=0; y < (long) image->rows; y++)
               {
-                p=AcquireImagePixels(image,0,y,image->columns,1,
+                p=GetVirtualPixels(image,0,y,image->columns,1,
                   &image->exception);
                 if (p == (const PixelPacket *) NULL)
                   break;
@@ -1935,11 +1938,11 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
               q=pixels;
               for (y=0; y < (long) image->rows; y++)
               {
-                p=AcquireImagePixels(image,0,y,image->columns,1,
+                p=GetVirtualPixels(image,0,y,image->columns,1,
                   &image->exception);
                 if (p == (const PixelPacket *) NULL)
                   break;
-                indexes=GetIndexes(image);
+                indexes=GetVirtualIndexQueue(image);
                 index=(*indexes);
                 length=255;
                 for (x=0; x < (long) image->columns; x++)
@@ -1952,7 +1955,8 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
                       if (x > 0)
                         {
                           q=PopHexPixel(hex_digits,index,q);
-                          q=PopHexPixel(hex_digits,MagickMin(length,0xff),q);
+                          q=PopHexPixel(hex_digits,(unsigned long)
+                            MagickMin(length,0xff),q);
                           i++;
                           if ((q-pixels+6) >= 80)
                             {
@@ -1968,7 +1972,8 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
                   p++;
                 }
                 q=PopHexPixel(hex_digits,index,q);
-                q=PopHexPixel(hex_digits,MagickMin(length,0xff),q);
+                q=PopHexPixel(hex_digits,(unsigned long)
+                  MagickMin(length,0xff),q);
                 if (image->previous == (Image *) NULL)
                   {
                     status=SetImageProgress(image,SaveImageTag,y,image->rows);
@@ -1992,11 +1997,11 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
               q=pixels;
               for (y=0; y < (long) image->rows; y++)
               {
-                p=AcquireImagePixels(image,0,y,image->columns,1,
+                p=GetVirtualPixels(image,0,y,image->columns,1,
                   &image->exception);
                 if (p == (const PixelPacket *) NULL)
                   break;
-                indexes=GetIndexes(image);
+                indexes=GetVirtualIndexQueue(image);
                 for (x=0; x < (long) image->columns; x++)
                 {
                   q=PopHexPixel(hex_digits,indexes[x],q);
