@@ -891,10 +891,6 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
     resolution.y=geometry_info.sigma;
     if ((flags & SigmaValue) == 0)
       resolution.y=resolution.x;
-    if (image->x_resolution != 0.0)
-      resolution.x=image->x_resolution;
-    if (image->y_resolution != 0.0)
-      resolution.y=image->y_resolution;
     if (image_info->density != (char *) NULL)
       {
         flags=ParseGeometry(image_info->density,&geometry_info);
