@@ -838,7 +838,7 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
         /*
           No interlacing:  RGBRGBRGBRGBRGBRGB...
         */
-        register PixelPacket
+        PixelPacket
           px;
 
         for (y=0; y < (long) image->rows; y++)
@@ -850,7 +850,7 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
             break;
           for (x=0; x < (long)image->columns; x++)
           {
-            px=*q;
+            px=(*q);
             qx[0]=&(q->red);
             qx[1]=&(q->green);
             qx[2]=&(q->blue);
