@@ -10,14 +10,14 @@
 %                            SSSSS   GGG   IIIII                              %
 %                                                                             %
 %                                                                             %
-%                      Read/Write Irix RGB Image Format.                      %
+%                      Read/Write Irix RGB Image Format                       %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
@@ -371,11 +372,6 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse)  && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
-    if (SetImageExtent(image,0,0) == MagickFalse)
-      {
-        InheritException(exception,&image->exception);
-        return(DestroyImageList(image));
-      }
     /*
       Allocate SGI pixels.
     */
@@ -554,7 +550,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
             for (y=0; y < (long) image->rows; y++)
             {
               p=iris_pixels+(image->rows-y-1)*8*image->columns;
-              q=SetImagePixels(image,0,y,image->columns,1);
+              q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
               if (q == (PixelPacket *) NULL)
                 break;
               for (x=0; x < (long) image->columns; x++)
@@ -572,7 +568,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 p+=8;
                 q++;
               }
-              if (SyncImagePixels(image) == MagickFalse)
+              if (SyncAuthenticPixels(image,exception) == MagickFalse)
                 break;
               if (image->previous == (Image *) NULL)
                 {
@@ -586,7 +582,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
           for (y=0; y < (long) image->rows; y++)
           {
             p=iris_pixels+(image->rows-y-1)*4*image->columns;
-            q=SetImagePixels(image,0,y,image->columns,1);
+            q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
             if (q == (PixelPacket *) NULL)
               break;
             for (x=0; x < (long) image->columns; x++)
@@ -600,7 +596,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               p+=4;
               q++;
             }
-            if (SyncImagePixels(image) == MagickFalse)
+            if (SyncAuthenticPixels(image,exception) == MagickFalse)
               break;
             if (image->previous == (Image *) NULL)
               {
@@ -625,10 +621,10 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
             for (y=0; y < (long) image->rows; y++)
             {
               p=iris_pixels+(image->rows-y-1)*8*image->columns;
-              q=SetImagePixels(image,0,y,image->columns,1);
+              q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
               if (q == (PixelPacket *) NULL)
                 break;
-              indexes=GetIndexes(image);
+              indexes=GetAuthenticIndexQueue(image);
               for (x=0; x < (long) image->columns; x++)
               {
                 quantum=(*p << 8);
@@ -637,7 +633,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 p+=8;
                 q++;
               }
-              if (SyncImagePixels(image) == MagickFalse)
+              if (SyncAuthenticPixels(image,exception) == MagickFalse)
                 break;
               if (image->previous == (Image *) NULL)
                 {
@@ -651,17 +647,17 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
           for (y=0; y < (long) image->rows; y++)
           {
             p=iris_pixels+(image->rows-y-1)*4*image->columns;
-            q=SetImagePixels(image,0,y,image->columns,1);
+            q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
             if (q == (PixelPacket *) NULL)
               break;
-            indexes=GetIndexes(image);
+            indexes=GetAuthenticIndexQueue(image);
             for (x=0; x < (long) image->columns; x++)
             {
               indexes[x]=(IndexPacket) (*p);
               p+=4;
               q++;
             }
-            if (SyncImagePixels(image) == MagickFalse)
+            if (SyncAuthenticPixels(image,exception) == MagickFalse)
               break;
             if (image->previous == (Image *) NULL)
               {
@@ -911,7 +907,9 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
       (void) SetImageColorspace(image,RGBColorspace);
     (void) ResetMagickMemory(&iris_info,0,sizeof(iris_info));
     iris_info.magic=0x01DA;
-    compression=image_info->compression;
+    compression=image->compression;
+    if (image_info->compression != UndefinedCompression)
+      compression=image_info->compression;
     if (image->depth > 8)
       compression=NoCompression;
     if (compression == NoCompression)
@@ -975,7 +973,7 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
     */
     for (y=0; y < (long) image->rows; y++)
     {
-      p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+      p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
       if (p == (const PixelPacket *) NULL)
         break;
       if (image->depth <= 8)
