@@ -384,7 +384,7 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     status;
 
   QuantumAny
-    scale;
+    range;
 
   register long
     i;
@@ -441,7 +441,7 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->colorspace=(ColorspaceType) type;
   (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
   (void) SetImageBackgroundColor(image);
-  scale=GetQuantumScale(image->depth);
+  range=GetQuantumRange(image->depth);
   while (ReadBlobString(image,text) != (char *) NULL)
   {
     if (image->colorspace == CMYKColorspace)
@@ -465,17 +465,17 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     q=GetAuthenticPixels(image,x,y,1,1,exception);
     if (q == (PixelPacket *) NULL)
       continue;
-    q->red=ScaleAnyToQuantum(pixel.red,image->depth,scale);
-    q->green=ScaleAnyToQuantum(pixel.green,image->depth,scale);
-    q->blue=ScaleAnyToQuantum(pixel.blue,image->depth,scale);
+    q->red=ScaleAnyToQuantum(pixel.red,range);
+    q->green=ScaleAnyToQuantum(pixel.green,range);
+    q->blue=ScaleAnyToQuantum(pixel.blue,range);
     if (image->colorspace == CMYKColorspace)
       {
         indexes=GetAuthenticIndexQueue(image);
-        *indexes=ScaleAnyToQuantum(pixel.index,image->depth,scale);
+        *indexes=ScaleAnyToQuantum(pixel.index,range);
       }
     if (image->matte != MagickFalse)
       q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel.opacity,
-        image->depth,scale));
+        range));
     if (SyncAuthenticPixels(image,exception) == MagickFalse)
       break;
   }
