@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
@@ -150,7 +151,6 @@ ModuleExport void UnregisterUILImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
 {
@@ -162,6 +162,9 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
     name[MaxTextExtent],
     symbol[MaxTextExtent];
 
+  ExceptionInfo
+    *exception;
+
   int
     j;
 
@@ -179,12 +182,12 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
   MagickSizeType
     number_pixels;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
-  register IndexPacket
-    *indexes;
-
   register long
     i,
     x;
@@ -211,6 +214,7 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
     return(status);
   if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
+  exception=(&image->exception);
   transparent=MagickFalse;
   i=0;
   p=(const PixelPacket *) NULL;
@@ -239,7 +243,7 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
             ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
           for (y=0; y < (long) image->rows; y++)
           {
-            p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+            p=GetVirtualPixels(image,0,y,image->columns,1,exception);
             if (p == (const PixelPacket *) NULL)
               break;
             for (x=0; x < (long) image->columns; x++)
@@ -255,18 +259,24 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
         }
       (void) SetImageType(image,PaletteType);
       colors=image->colors;
-      if (transparent)
+      if (transparent != MagickFalse)
         {
+          register IndexPacket
+            *indexes;
+
+          register PixelPacket
+            *q;
+
           colors++;
           for (y=0; y < (long) image->rows; y++)
           {
-            p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
-            if (p == (const PixelPacket *) NULL)
+            q=GetAuthenticPixels(image,0,y,image->columns,1,exception);
+            if (q == (PixelPacket *) NULL)
               break;
-            indexes=GetIndexes(image);
+            indexes=GetAuthenticIndexQueue(image);
             for (x=0; x < (long) image->columns; x++)
             {
-              if (matte_image[i])
+              if (matte_image[i] != 0)
                 indexes[x]=(IndexPacket) image->colors;
               p++;
             }
@@ -336,10 +346,10 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobString(image,buffer);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+    p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    indexes=GetIndexes(image);
+    indexes=GetVirtualIndexQueue(image);
     (void) WriteBlobString(image,"    \"");
     for (x=0; x < (long) image->columns; x++)
     {
@@ -358,14 +368,9 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
     (void) FormatMagickString(buffer,MaxTextExtent,"\"%s\n",
       (y == (long) (image->rows-1) ? ");" : ","));
     (void) WriteBlobString(image,buffer);
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(SaveImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    status=SetImageProgress(image,SaveImageTag,y,image->rows);
+    if (status == MagickFalse)
+      break;
   }
   (void) CloseBlob(image);
   return(MagickTrue);
