@@ -18,7 +18,7 @@
 %                                March 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -101,17 +101,20 @@
 extern "C" {
 #endif
 
-static void GetFTPData(void *userdata,const char *data,int length)
+static void GetFTPData(void *userdata,const char *data,int size)
 {
   FILE
     *file;
 
+  size_t
+    length;
+
   file=(FILE *) userdata;
   if (file == (FILE *) NULL)
     return;
-  if (length <= 0)
+  if (size <= 0)
     return;
-  (void) fwrite(data,length,1,file);
+  length=fwrite(data,size,1,file);
 }
 
 #if defined(__cplusplus) || defined(c_plusplus)
@@ -200,8 +203,11 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
         (const char *) NULL,&type,(const char *) NULL,0);
       if (context != (void *) NULL)
         {
+          int
+            status;
+
           while ((bytes=xmlNanoHTTPRead(context,buffer,MaxBufferExtent)) > 0)
-            (void) fwrite(buffer,bytes,1,file);
+            status=fwrite(buffer,bytes,1,file);
           xmlNanoHTTPClose(context);
           xmlFree(type);
           xmlNanoHTTPCleanup();
