@@ -10,14 +10,14 @@
 %                         UUU     Y      V      Y                             %
 %                                                                             %
 %                                                                             %
-%            Read/Write 16bit/pixel Interleaved YUV Image Format.             %
+%            Read/Write 16bit/pixel Interleaved YUV Image Format              %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/color.h"
 #include "magick/colorspace.h"
 #include "magick/exception.h"
@@ -151,17 +152,12 @@ static Image *ReadUYVYImage(const ImageInfo *image_info,
       (void) CloseBlob(image);
       return(GetFirstImageInList(image));
     }
-  if (SetImageExtent(image,0,0) == MagickFalse)
-    {
-      InheritException(exception,&image->exception);
-      return(DestroyImageList(image));
-    }
   /*
     Accumulate UYVY, then unpack into two pixels.
   */
   for (y=0; y < (long) image->rows; y++)
   {
-    q=SetImagePixels(image,0,y,image->columns,1);
+    q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
     if (q == (PixelPacket *) NULL)
       break;
     for (x=0; x < (long) (image->columns >> 1); x++)
@@ -179,7 +175,7 @@ static Image *ReadUYVYImage(const ImageInfo *image_info,
       q->blue=ScaleCharToQuantum(v);
       q++;
     }
-    if (SyncImagePixels(image) == MagickFalse)
+    if (SyncAuthenticPixels(image,exception) == MagickFalse)
       break;
     status=SetImageProgress(image,LoadImageTag,y,image->rows);
     if (status == MagickFalse)
@@ -342,7 +338,7 @@ static MagickBooleanType WriteUYVYImage(const ImageInfo *image_info,
   (void) ResetMagickMemory(&pixel,0,sizeof(MagickPixelPacket));
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireImagePixels(uyvy_image,0,y,image->columns,1,&image->exception);
+    p=GetVirtualPixels(uyvy_image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
     for (x=0; x < (long) image->columns; x++)
