@@ -10,14 +10,14 @@
 %                            X   X   CCCC  F                                  %
 %                                                                             %
 %                                                                             %
-%                        Read GIMP XCF Image Format.                          %
+%                        Read GIMP XCF Image Format                           %
 %                                                                             %
 %                              Software Design                                %
 %                              Leonard Rosenthol                              %
 %                               November 2001                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/color.h"
 #include "magick/composite.h"
 #include "magick/exception.h"
@@ -331,6 +332,9 @@ static char *ReadBlobStringWithLongSize(Image *image,char *string,size_t max)
 static MagickBooleanType load_tile(Image *image,Image *tile_image,
   XCFDocInfo *inDocInfo,XCFLayerInfo *inLayerInfo,size_t data_length)
 {
+  ExceptionInfo
+    *exception;
+
   long
     y;
 
@@ -360,9 +364,10 @@ static MagickBooleanType load_tile(Image *image,Image *tile_image,
   if (count != (ssize_t) data_length)
     ThrowBinaryException(CorruptImageError,"NotEnoughPixelData",
       image->filename);
+  exception=(&image->exception);
   for (y=0; y < (long) tile_image->rows; y++)
   {
-    q=SetImagePixels(tile_image,0,y,tile_image->columns,1);
+    q=QueueAuthenticPixels(tile_image,0,y,tile_image->columns,1,exception);
     if (q == (PixelPacket *) NULL)
       break;
     if (inDocInfo->image_type == GIMP_GRAY)
@@ -391,7 +396,7 @@ static MagickBooleanType load_tile(Image *image,Image *tile_image,
             q++;
           }
         }
-     if (SyncImagePixels(tile_image) == MagickFalse)
+     if (SyncAuthenticPixels(tile_image,exception) == MagickFalse)
        break;
   }
   xcfodata=(XCFPixelPacket *) RelinquishMagickMemory(xcfodata);
@@ -401,6 +406,9 @@ static MagickBooleanType load_tile(Image *image,Image *tile_image,
 static MagickBooleanType load_tile_rle(Image *image,Image *tile_image,
   XCFDocInfo *inDocInfo,XCFLayerInfo *inLayerInfo,size_t data_length)
 {
+  ExceptionInfo
+    *exception;
+
   long
     i,
     j;
@@ -433,9 +441,10 @@ static MagickBooleanType load_tile_rle(Image *image,Image *tile_image,
   xcfodata=xcfdata;
   count=ReadBlob(image, (size_t) data_length, xcfdata);
   xcfdatalimit = xcfodata+count-1;
+  exception=(&image->exception);
   for (i=0; i < (long) bytes_per_pixel; i++)
   {
-    q=GetImagePixels(tile_image,0,0,tile_image->columns,tile_image->rows);
+    q=GetAuthenticPixels(tile_image,0,0,tile_image->columns,tile_image->rows,exception);
     size=(MagickOffsetType) tile_image->rows*tile_image->columns;
     while (size > 0)
     {
@@ -559,7 +568,7 @@ static MagickBooleanType load_tile_rle(Image *image,Image *tile_image,
             }
           }
       }
-      if (SyncImagePixels(tile_image) == MagickFalse)
+      if (SyncAuthenticPixels(tile_image,exception) == MagickFalse)
         break;
     }
   xcfodata=(unsigned char *) RelinquishMagickMemory(xcfodata);
@@ -1032,11 +1041,6 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     else
       if (image_type == GIMP_INDEXED)
         ThrowReaderException(CoderError,"ColormapTypeNotSupported");
-  if (SetImageExtent(image,0,0) == MagickFalse)
-    {
-      InheritException(exception,&image->exception);
-      return(DestroyImageList(image));
-    }
   (void) SetImageBackgroundColor(image);
   image->matte=MagickTrue;
   /*
