@@ -10,14 +10,14 @@
 %                            X   X  P      M   M                              %
 %                                                                             %
 %                                                                             %
-%                  Read/Write X Windows system Pixmap Format.                 %
+%                  Read/Write X Windows system Pixmap Format                  %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
@@ -388,20 +389,15 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       /*
         Read image pixels.
       */
-      if (SetImageExtent(image,0,0) == MagickFalse)
-        {
-          InheritException(exception,&image->exception);
-          return(DestroyImageList(image));
-        }
       for (y=0; y < (long) image->rows; y++)
       {
         p=NextXPMLine(p);
         if (p == (char *) NULL)
           break;
-        r=SetImagePixels(image,0,y,image->columns,1);
+        r=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
         if (r == (PixelPacket *) NULL)
           break;
-        indexes=GetIndexes(image);
+        indexes=GetAuthenticIndexQueue(image);
         for (x=0; x < (long) image->columns; x++)
         {
           (void) CopyXPMColor(key,p,(size_t) width);
@@ -412,7 +408,7 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           r++;
           p+=width;
         }
-        if (SyncImagePixels(image) == MagickFalse)
+        if (SyncAuthenticPixels(image,exception) == MagickFalse)
           break;
       }
       if (y < (long) image->rows)
@@ -580,6 +576,9 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
     name[MaxTextExtent],
     symbol[MaxTextExtent];
 
+  ExceptionInfo
+    *exception;
+
   Image
     *affinity_image,
     *picon;
@@ -605,12 +604,12 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
   RectangleInfo
     geometry;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
-  register IndexPacket
-    *indexes;
-
   register long
     i,
     x;
@@ -655,10 +654,11 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
   if ((picon == (Image *) NULL) || (affinity_image == (Image *) NULL))
     return(MagickFalse);
   quantize_info=AcquireQuantizeInfo(image_info);
-  status=AffinityImage(quantize_info,picon,affinity_image);
+  status=RemapImage(quantize_info,picon,affinity_image);
   quantize_info=DestroyQuantizeInfo(quantize_info);
   affinity_image=DestroyImage(affinity_image);
   transparent=MagickFalse;
+  exception=(&image->exception);
   if (picon->storage_class == PseudoClass)
     {
       CompressImageColormap(picon);
@@ -677,7 +677,7 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
           */
           for (y=0; y < (long) picon->rows; y++)
           {
-            q=GetImagePixels(picon,0,y,picon->columns,1);
+            q=GetAuthenticPixels(picon,0,y,picon->columns,1,exception);
             if (q == (PixelPacket *) NULL)
               break;
             for (x=0; x < (long) picon->columns; x++)
@@ -688,7 +688,7 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
                 q->opacity=OpaqueOpacity;
               q++;
             }
-            if (SyncImagePixels(picon) == MagickFalse)
+            if (SyncAuthenticPixels(picon,exception) == MagickFalse)
               break;
           }
         }
@@ -697,6 +697,9 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
   colors=picon->colors;
   if (transparent != MagickFalse)
     {
+      register IndexPacket
+        *indexes;
+
       colors++;
       picon->colormap=(PixelPacket *) ResizeQuantumMemory((void **)
         picon->colormap,(size_t) colors,sizeof(*picon->colormap));
@@ -704,17 +707,17 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
         ThrowWriterException(ResourceLimitError,"MemoryAllocationError");
       for (y=0; y < (long) picon->rows; y++)
       {
-        q=GetImagePixels(picon,0,y,picon->columns,1);
+        q=GetAuthenticPixels(picon,0,y,picon->columns,1,exception);
         if (q == (PixelPacket *) NULL)
           break;
-        indexes=GetIndexes(picon);
+        indexes=GetAuthenticIndexQueue(picon);
         for (x=0; x < (long) picon->columns; x++)
         {
           if (q->opacity == (Quantum) TransparentOpacity)
             indexes[x]=(IndexPacket) picon->colors;
           q++;
         }
-        if (SyncImagePixels(picon) == MagickFalse)
+        if (SyncAuthenticPixels(picon,exception) == MagickFalse)
           break;
       }
     }
@@ -774,10 +777,10 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
   (void) WriteBlobString(image,"/* pixels */\n");
   for (y=0; y < (long) picon->rows; y++)
   {
-    p=AcquireImagePixels(picon,0,y,picon->columns,1,&picon->exception);
+    p=GetVirtualPixels(picon,0,y,picon->columns,1,&picon->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    indexes=GetIndexes(picon);
+    indexes=GetVirtualIndexQueue(picon);
     (void) WriteBlobString(image,"\"");
     for (x=0; x < (long) picon->columns; x++)
     {
@@ -856,12 +859,12 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
   MagickPixelPacket
     pixel;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
-  register IndexPacket
-    *indexes;
-
   register long
     i,
     x;
@@ -1002,10 +1005,10 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobString(image,"/* pixels */\n");
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+    p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    indexes=GetIndexes(image);
+    indexes=GetVirtualIndexQueue(image);
     (void) WriteBlobString(image,"\"");
     for (x=0; x < (long) image->columns; x++)
     {
