@@ -10,14 +10,14 @@
 %          CCCC   OOO   N   N  F      IIIII   GGG    UUU   R  R   EEEEE       %
 %                                                                             %
 %                                                                             %
-%                     ImageMagick Image Configure Methods                     %
+%                      MagickCore Image Configure Methods                     %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -193,7 +193,7 @@ MagickExport LinkedListInfo *DestroyConfigureOptions(LinkedListInfo *options)
 %
 %    o name: the configure name.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport const ConfigureInfo *GetConfigureInfo(const char *name,
@@ -257,7 +257,7 @@ MagickExport const ConfigureInfo *GetConfigureInfo(const char *name,
 %    o number_options:  This integer returns the number of configure options in
 %    the list.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -353,7 +353,7 @@ MagickExport const ConfigureInfo **GetConfigureInfoList(const char *pattern,
 %
 %    o number_options:  This integer returns the number of options in the list.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -490,7 +490,7 @@ MagickExport char *GetConfigureOption(const char *option)
 %
 %    o filename: the configure file name.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport LinkedListInfo *GetConfigureOptions(const char *filename,
@@ -579,7 +579,7 @@ MagickExport LinkedListInfo *GetConfigureOptions(const char *filename,
 %
 %    o filename: the configure file name.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
@@ -740,7 +740,8 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
     char
       module_path[MaxTextExtent];
 
-    if (NTGetModulePath("CORE_RL_magick_.dll",module_path) != MagickFalse)
+    if ((NTGetModulePath("CORE_RL_magick_.dll",module_path) != MagickFalse) ||
+        (NTGetModulePath("CORE_DB_magick_.dll",module_path) != MagickFalse))
       {
         char
           *element;
@@ -825,7 +826,7 @@ MagickExport const char *GetConfigureValue(const ConfigureInfo *configure_info)
 %
 %  A description of each parameter follows.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 static MagickBooleanType InitializeConfigureList(ExceptionInfo *exception)
@@ -866,7 +867,7 @@ static MagickBooleanType InitializeConfigureList(ExceptionInfo *exception)
 %
 %    o file:  An pointer to a FILE.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport MagickBooleanType ListConfigureInfo(FILE *file,
@@ -955,33 +956,30 @@ MagickExport MagickBooleanType ListConfigureInfo(FILE *file,
 %
 %    o depth: depth of <include /> statements.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 static MagickBooleanType LoadConfigureList(const char *xml,const char *filename,
   const unsigned long depth,ExceptionInfo *exception)
 {
-  const char
-    *attribute;
+  char
+    keyword[MaxTextExtent],
+    *token;
 
   ConfigureInfo
-    *configure_info = (ConfigureInfo *) NULL;
+    *configure_info;
+
+  const char
+    *q;
 
   MagickBooleanType
     status;
 
-  XMLTreeInfo
-    *configure,
-    *configure_map,
-    *include;
-
   /*
     Load the configure map file.
   */
   (void) LogMagickEvent(ConfigureEvent,GetMagickModule(),
-    "Loading configure map \"%s\" ...",filename);
-  if (xml == (const char *) NULL)
-    return(MagickFalse);
+    "Loading configure file \"%s\" ...",filename);
   if (configure_list == (LinkedListInfo *) NULL)
     {
       configure_list=NewLinkedList(0);
@@ -992,75 +990,151 @@ static MagickBooleanType LoadConfigureList(const char *xml,const char *filename,
           return(MagickFalse);
         }
     }
-  configure_map=NewXMLTree(xml,exception);
-  if (configure_map == (XMLTreeInfo *) NULL)
-    return(MagickFalse);
   status=MagickTrue;
-  include=GetXMLTreeChild(configure_map,"include");
-  while (include != (XMLTreeInfo *) NULL)
+  configure_info=(ConfigureInfo *) NULL;
+  if (xml == (char *) NULL)
+    token=AcquireString(ConfigureMap);
+  else
+    token=AcquireString((char *) xml);
+  for (q=(char *) xml; *q != '\0'; )
   {
     /*
-      Process include element.
+      Interpret XML.
     */
-    attribute=GetXMLTreeAttribute(include,"file");
-    if (attribute != (const char *) NULL)
+    GetMagickToken(q,&q,token);
+    if (*token == '\0')
+      break;
+    (void) CopyMagickString(keyword,token,MaxTextExtent);
+    if (LocaleNCompare(keyword,"<!DOCTYPE",9) == 0)
       {
-        if (depth > 200)
-          (void) ThrowMagickException(exception,GetMagickModule(),
-            ConfigureError,"IncludeElementNestedTooDeeply","`%s'",filename);
-        else
-          {
-            char
-              path[MaxTextExtent],
-              *xml;
-
-            GetPathComponent(filename,HeadPath,path);
-            if (*path != '\0')
-              (void) ConcatenateMagickString(path,DirectorySeparator,
-                MaxTextExtent);
-            (void) ConcatenateMagickString(path,attribute,MaxTextExtent);
-            xml=FileToString(path,~0,exception);
-            if (xml != (char *) NULL)
-              {
-                status=LoadConfigureList(xml,path,depth+1,exception);
-                xml=DestroyString(xml);
-              }
-          }
+        /*
+          Doctype element.
+        */
+        while ((LocaleNCompare(q,"]>",2) != 0) && (*q != '\0'))
+          GetMagickToken(q,&q,token);
+        continue;
       }
-    include=GetNextXMLTreeTag(include);
-  }
-  configure=GetXMLTreeChild(configure_map,"configure");
-  while (configure != (XMLTreeInfo *) NULL)
-  {
-    const char
-      *attribute;
+    if (LocaleNCompare(keyword,"<!--",4) == 0)
+      {
+        /*
+          Comment element.
+        */
+        while ((LocaleNCompare(q,"->",2) != 0) && (*q != '\0'))
+          GetMagickToken(q,&q,token);
+        continue;
+      }
+    if (LocaleCompare(keyword,"<include") == 0)
+      {
+        /*
+          Include element.
+        */
+        while (((*token != '/') && (*(token+1) != '>')) && (*q != '\0'))
+        {
+          (void) CopyMagickString(keyword,token,MaxTextExtent);
+          GetMagickToken(q,&q,token);
+          if (*token != '=')
+            continue;
+          GetMagickToken(q,&q,token);
+          if (LocaleCompare(keyword,"file") == 0)
+            {
+              if (depth > 200)
+                (void) ThrowMagickException(exception,GetMagickModule(),
+                  ConfigureError,"IncludeElementNestedTooDeeply","`%s'",token);
+              else
+                {
+                  char
+                    path[MaxTextExtent],
+                    *xml;
 
-    /*
-      Process configure element.
-    */
-    configure_info=(ConfigureInfo *) AcquireMagickMemory(
-      sizeof(*configure_info));
+                  GetPathComponent(filename,HeadPath,path);
+                  if (*path != '\0')
+                    (void) ConcatenateMagickString(path,DirectorySeparator,
+                      MaxTextExtent);
+                  if (*token == *DirectorySeparator)
+                    (void) CopyMagickString(path,token,MaxTextExtent);
+                  else
+                    (void) ConcatenateMagickString(path,token,MaxTextExtent);
+                  xml=FileToString(path,~0,exception);
+                  if (xml != (char *) NULL)
+                    {
+                      status=LoadConfigureList(xml,path,depth+1,exception);
+                      xml=(char *) RelinquishMagickMemory(xml);
+                    }
+                }
+            }
+        }
+        continue;
+      }
+    if (LocaleCompare(keyword,"<configure") == 0)
+      {
+        /*
+          Configure element.
+        */
+        configure_info=(ConfigureInfo *) AcquireMagickMemory(
+          sizeof(*configure_info));
+        if (configure_info == (ConfigureInfo *) NULL)
+          ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
+        (void) ResetMagickMemory(configure_info,0,sizeof(*configure_info));
+        configure_info->path=ConstantString(filename);
+        configure_info->signature=MagickSignature;
+        continue;
+      }
     if (configure_info == (ConfigureInfo *) NULL)
-      ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
-    (void) ResetMagickMemory(configure_info,0,sizeof(*configure_info));
-    configure_info->path=ConstantString(filename);
-    configure_info->signature=MagickSignature;
-    attribute=GetXMLTreeAttribute(configure,"name");
-    if (attribute != (const char *) NULL)
-      configure_info->name=ConstantString(attribute);
-    attribute=GetXMLTreeAttribute(configure,"stealth");
-    if (attribute != (const char *) NULL)
-      configure_info->stealth=IsMagickTrue(attribute);
-    attribute=GetXMLTreeAttribute(configure,"value");
-    if (attribute != (const char *) NULL)
-      configure_info->value=ConstantString(attribute);
-    status=AppendValueToLinkedList(configure_list,configure_info);
-    if (status == MagickFalse)
-      (void) ThrowMagickException(exception,GetMagickModule(),
-        ResourceLimitError,"MemoryAllocationFailed","`%s'",filename);
-    configure=GetNextXMLTreeTag(configure);
+      continue;
+    if (LocaleCompare(keyword,"/>") == 0)
+      {
+        status=AppendValueToLinkedList(configure_list,configure_info);
+        if (status == MagickFalse)
+          (void) ThrowMagickException(exception,GetMagickModule(),
+            ResourceLimitError,"MemoryAllocationFailed","`%s'",
+            configure_info->name);
+        configure_info=(ConfigureInfo *) NULL;
+      }
+    /*
+      Parse configure element.
+    */
+    GetMagickToken(q,(const char **) NULL,token);
+    if (*token != '=')
+      continue;
+    GetMagickToken(q,&q,token);
+    GetMagickToken(q,&q,token);
+    switch (*keyword)
+    {
+      case 'N':
+      case 'n':
+      {
+        if (LocaleCompare((char *) keyword,"name") == 0)
+          {
+            configure_info->name=ConstantString(token);
+            break;
+          }
+        break;
+      }
+      case 'S':
+      case 's':
+      {
+        if (LocaleCompare((char *) keyword,"stealth") == 0)
+          {
+            configure_info->stealth=IsMagickTrue(token);
+            break;
+          }
+        break;
+      }
+      case 'V':
+      case 'v':
+      {
+        if (LocaleCompare((char *) keyword,"value") == 0)
+          {
+            configure_info->value=ConstantString(token);
+            break;
+          }
+        break;
+      }
+      default:
+        break;
+    }
   }
-  configure_map=DestroyXMLTree(configure_map);
+  token=(char *) RelinquishMagickMemory(token);
   return(status);
 }
 
@@ -1087,7 +1161,7 @@ static MagickBooleanType LoadConfigureList(const char *xml,const char *filename,
 %
 %    o filename: the font file name.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 static MagickBooleanType LoadConfigureLists(const char *filename,
