@@ -10,14 +10,14 @@
 %     CCCC   OOO   N   N  SSSSS    T    IIIII    T     UUU     T    EEEEE     %
 %                                                                             %
 %                                                                             %
-%                       Methods to Consitute an Image                         %
+%                  MagickCore Methods to Consitute an Image                   %
 %                                                                             %
 %                             Software Design                                 %
 %                               John Cristy                                   %
 %                               October 1998                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -73,12 +73,6 @@
 static SemaphoreInfo
   *constitute_semaphore = (SemaphoreInfo *) NULL;
 
-/*
-  Forward declarations.
-*/
-static Image
-  *ReadImages(const ImageInfo *,ExceptionInfo *);
-
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -125,7 +119,7 @@ static Image
 %      map and type.  You must preallocate this array where the expected
 %      length varies depending on the values of width, height, map, and type.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport Image *ConstituteImage(const unsigned long columns,
@@ -212,7 +206,7 @@ MagickExport void DestroyConstitute(void)
 %    o image_info: Ping the image defined by the file or filename members of
 %      this structure.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -263,6 +257,126 @@ MagickExport Image *PingImage(const ImageInfo *image_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   P i n g I m a g e s                                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  PingImages() pings one or more images and returns them as an image list.
+%
+%  The format of the PingImage method is:
+%
+%      Image *PingImages(const ImageInfo *image_info,ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o image_info: the image info.
+%
+%    o exception: return any errors or warnings in this structure.
+%
+*/
+MagickExport Image *PingImages(const ImageInfo *image_info,
+  ExceptionInfo *exception)
+{
+  char
+    filename[MaxTextExtent];
+
+  Image
+    *image,
+    *images;
+
+  ImageInfo
+    *read_info;
+
+  /*
+    Ping image list from a file.
+  */
+  assert(image_info != (ImageInfo *) NULL);
+  assert(image_info->signature == MagickSignature);
+  if (image_info->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
+  assert(exception != (ExceptionInfo *) NULL);
+  if (*image_info->filename == '@')
+    {
+      char
+        *command,
+        **image_list;
+
+      int
+        number_images;
+
+      register long
+        i;
+
+      /*
+        A file with a list of image filenames to read.
+      */
+      command=FileToString(image_info->filename+1,~0,exception);
+      if (command == (char *) NULL)
+        return((Image *) NULL);
+      StripString(command);
+      image_list=StringToArgv(command,&number_images);
+      command=DestroyString(command);
+      read_info=CloneImageInfo(image_info);
+      images=NewImageList();
+      for (i=1; i < number_images; i++)
+      {
+        (void) CopyMagickString(read_info->filename,image_list[i],
+          MaxTextExtent);
+        image=PingImage(read_info,exception);
+        if (image == (Image *) NULL)
+          continue;
+        AppendImageToList(&images,image);
+      }
+      read_info=DestroyImageInfo(read_info);
+      for (i=0; i < number_images; i++)
+        image_list[i]=DestroyString(image_list[i]);
+      image_list=(char **) RelinquishMagickMemory(image_list);
+      return(images);
+    }
+  (void) InterpretImageFilename(image_info,(Image *) NULL,image_info->filename,
+    (int) image_info->scene,filename);
+  if (LocaleCompare(filename,image_info->filename) != 0)
+    {
+      ExceptionInfo
+        *sans;
+
+      long
+        extent,
+        scene;
+
+      /*
+        Images of the form image-%d.png[1-5].
+      */
+      read_info=CloneImageInfo(image_info);
+      sans=AcquireExceptionInfo();
+      (void) SetImageInfo(read_info,MagickFalse,sans);
+      sans=DestroyExceptionInfo(sans);
+      (void) CopyMagickString(filename,read_info->filename,MaxTextExtent);
+      images=NewImageList();
+      extent=(long) (read_info->scene+read_info->number_scenes);
+      for (scene=(long) read_info->scene; scene < (long) extent; scene++)
+      {
+        (void) InterpretImageFilename(image_info,(Image *) NULL,filename,(int)
+          scene,read_info->filename);
+        image=PingImage(read_info,exception);
+        if (image == (Image *) NULL)
+          continue;
+        AppendImageToList(&images,image);
+      }
+      read_info=DestroyImageInfo(read_info);
+      return(images);
+    }
+  return(PingImage(image_info,exception));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   R e a d I m a g e                                                         %
 %                                                                             %
 %                                                                             %
@@ -283,7 +397,7 @@ MagickExport Image *PingImage(const ImageInfo *image_info,
 %    o image_info: Read the image defined by the file or filename members of
 %      this structure.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport Image *ReadImage(const ImageInfo *image_info,
@@ -317,7 +431,8 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
     *read_info;
 
   MagickStatusType
-    flags;
+    flags,
+    thread_support;
 
   /*
     Determine image type from filename prefix or suffix (e.g. image.jpg).
@@ -329,8 +444,6 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
-  if (*image_info->filename == '@')
-    return(ReadImages(image_info,exception));
   read_info=CloneImageInfo(image_info);
   (void) CopyMagickString(magick_filename,read_info->filename,MaxTextExtent);
   (void) SetImageInfo(read_info,MagickFalse,exception);
@@ -397,10 +510,11 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
   if ((magick_info != (const MagickInfo *) NULL) &&
       (GetImageDecoder(magick_info) != (DecodeImageHandler *) NULL))
     {
-      if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
+      thread_support=GetMagickThreadSupport(magick_info);      
+      if ((thread_support & DecoderThreadSupport) == 0)
         AcquireSemaphoreInfo(&constitute_semaphore);
       image=GetImageDecoder(magick_info)(read_info,exception);
-      if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
+      if ((thread_support & DecoderThreadSupport) == 0)
         RelinquishSemaphoreInfo(constitute_semaphore);
     }
   else
@@ -452,10 +566,11 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
           read_info=DestroyImageInfo(read_info);
           return((Image *) NULL);
         }
-      if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
+      thread_support=GetMagickThreadSupport(magick_info);      
+      if ((thread_support & DecoderThreadSupport) == 0)
         AcquireSemaphoreInfo(&constitute_semaphore);
       image=(Image *) (GetImageDecoder(magick_info))(read_info,exception);
-      if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
+      if ((thread_support & DecoderThreadSupport) == 0)
         RelinquishSemaphoreInfo(constitute_semaphore);
     }
   if (read_info->temporary != MagickFalse)
@@ -610,7 +725,8 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
                   Image
                     *size_image;
 
-                  flags=ParseSizeGeometry(next,read_info->extract,&geometry);
+                  flags=ParseRegionGeometry(next,read_info->extract,&geometry,
+                    exception);
                   size_image=ResizeImage(next,geometry.width,geometry.height,
                     next->filter,next->blur,exception);
                   if (size_image != (Image *) NULL)
@@ -653,14 +769,13 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-+   R e a d I m a g e s                                                       %
+%   R e a d I m a g e s                                                       %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ReadImages() reads a list of image names from a file and then returns the
-%  images as a linked list.
+%  ReadImages() reads one or more images and returns them as an image list.
 %
 %  The format of the ReadImage method is:
 %
@@ -668,37 +783,24 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o image: Method ReadImage returns a pointer to the image after
-%      reading.  A null image is returned if there is a memory shortage or
-%      if the image cannot be read.
+%    o image_info: the image info.
 %
-%    o image_info: the list of filenames are defined in the filename member of
-%      this structure.
-%
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
-static Image *ReadImages(const ImageInfo *image_info,ExceptionInfo *exception)
+MagickExport Image *ReadImages(const ImageInfo *image_info,
+  ExceptionInfo *exception)
 {
   char
-    *command,
-    **images;
+    filename[MaxTextExtent];
 
   Image
-    *image;
+    *image,
+    *images;
 
   ImageInfo
     *read_info;
 
-  int
-    number_images;
-
-  register Image
-    *next;
-
-  register long
-    i;
-
   /*
     Read image list from a file.
   */
@@ -708,30 +810,78 @@ static Image *ReadImages(const ImageInfo *image_info,ExceptionInfo *exception)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
-  command=FileToString(image_info->filename+1,~0,exception);
-  if (command == (char *) NULL)
-    return((Image *) NULL);
-  StripString(command);
-  images=StringToArgv(command,&number_images);
-  command=DestroyString(command);
-  /*
-    Read the images into a linked list.
-  */
-  read_info=CloneImageInfo(image_info);
-  image=NewImageList();
-  for (i=1; i < number_images; i++)
-  {
-    (void) CopyMagickString(read_info->filename,images[i],MaxTextExtent);
-    next=ReadImage(read_info,exception);
-    if (next == (Image *) NULL)
-      continue;
-    AppendImageToList(&image,next);
-  }
-  read_info=DestroyImageInfo(read_info);
-  for (i=1; i < number_images; i++)
-    images[i]=DestroyString(images[i]);
-  images=(char **) RelinquishMagickMemory(images);
-  return(image);
+  if (*image_info->filename == '@')
+    {
+      char
+        *command,
+        **image_list;
+
+      int
+        number_images;
+
+      register long
+        i;
+
+      /*
+        A file with a list of image filenames to read.
+      */
+      command=FileToString(image_info->filename+1,~0,exception);
+      if (command == (char *) NULL)
+        return((Image *) NULL);
+      StripString(command);
+      image_list=StringToArgv(command,&number_images);
+      command=DestroyString(command);
+      read_info=CloneImageInfo(image_info);
+      images=NewImageList();
+      for (i=1; i < number_images; i++)
+      {
+        (void) CopyMagickString(read_info->filename,image_list[i],
+          MaxTextExtent);
+        image=ReadImage(read_info,exception);
+        if (image == (Image *) NULL)
+          continue;
+        AppendImageToList(&images,image);
+      }
+      read_info=DestroyImageInfo(read_info);
+      for (i=0; i < number_images; i++)
+        image_list[i]=DestroyString(image_list[i]);
+      image_list=(char **) RelinquishMagickMemory(image_list);
+      return(images);
+    }
+  (void) InterpretImageFilename(image_info,(Image *) NULL,image_info->filename,
+    (int) image_info->scene,filename);
+  if (LocaleCompare(filename,image_info->filename) != 0)
+    {
+      ExceptionInfo
+        *sans;
+
+      long
+        extent,
+        scene;
+
+      /*
+        Images of the form image-%d.png[1-5].
+      */
+      read_info=CloneImageInfo(image_info);
+      sans=AcquireExceptionInfo();
+      (void) SetImageInfo(read_info,MagickFalse,sans);
+      sans=DestroyExceptionInfo(sans);
+      (void) CopyMagickString(filename,read_info->filename,MaxTextExtent);
+      images=NewImageList();
+      extent=(long) (read_info->scene+read_info->number_scenes);
+      for (scene=(long) read_info->scene; scene < (long) extent; scene++)
+      {
+        (void) InterpretImageFilename(image_info,(Image *) NULL,filename,(int)
+          scene,read_info->filename);
+        image=ReadImage(read_info,exception);
+        if (image == (Image *) NULL)
+          continue;
+        AppendImageToList(&images,image);
+      }
+      read_info=DestroyImageInfo(read_info);
+      return(images);
+    }
+  return(ReadImage(image_info,exception));
 }
 
 /*
@@ -761,7 +911,7 @@ static Image *ReadImages(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %    o content: the image encoded in Base64.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport Image *ReadInlineImage(const ImageInfo *image_info,
@@ -785,12 +935,12 @@ MagickExport Image *ReadInlineImage(const ImageInfo *image_info,
   image=NewImageList();
   for (p=content; (*p != ',') && (*p != '\0'); p++) ;
   if (*p == '\0')
-    ThrowReaderException(CorruptImageWarning,"CorruptImage");
+    ThrowReaderException(CorruptImageError,"CorruptImage");
   p++;
   length=0;
   blob=Base64Decode(p,&length);
   if (length == 0)
-    ThrowReaderException(CorruptImageWarning,"CorruptImage");
+    ThrowReaderException(CorruptImageError,"CorruptImage");
   read_info=CloneImageInfo(image_info);
   (void) SetImageInfoProgressMonitor(read_info,(MagickProgressMonitor) NULL,
     (void *) NULL);
@@ -850,6 +1000,9 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
     status,
     temporary;
 
+  MagickStatusType
+    thread_support;
+
   /*
     Determine image type from filename prefix or suffix (e.g. image.jpg).
   */
@@ -952,10 +1105,11 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
       /*
         Call appropriate image writer based on image type.
       */
-      if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
+      thread_support=GetMagickThreadSupport(magick_info);      
+      if ((thread_support & EncoderThreadSupport) == 0)
         AcquireSemaphoreInfo(&constitute_semaphore);
       status=GetImageEncoder(magick_info)(write_info,image);
-      if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
+      if ((thread_support & EncoderThreadSupport) == 0)
         RelinquishSemaphoreInfo(constitute_semaphore);
     }
   else
@@ -996,10 +1150,11 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
               /*
                 Call appropriate image writer based on image type.
               */
-              if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
+              thread_support=GetMagickThreadSupport(magick_info);      
+              if ((thread_support & EncoderThreadSupport) == 0)
                 AcquireSemaphoreInfo(&constitute_semaphore);
               status=GetImageEncoder(magick_info)(write_info,image);
-              if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
+              if ((thread_support & EncoderThreadSupport) == 0)
                 RelinquishSemaphoreInfo(constitute_semaphore);
             }
         }
@@ -1054,7 +1209,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
 %
 %    o filename: the image filename.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport MagickBooleanType WriteImages(const ImageInfo *image_info,
