@@ -9,14 +9,14 @@
 %           DDDD   EEEEE  LLLLL  EEEEE   GGG   A   A    T    EEEEE            %
 %                                                                             %
 %                                                                             %
-%                   Methods to Read/Write/Invoke Delegates                    %
+%             MagickCore Methods to Read/Write/Invoke Delegates               %
 %                                                                             %
 %                             Software Design                                 %
 %                               John Cristy                                   %
 %                               October 1998                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -225,7 +225,7 @@ MagickExport void DestroyDelegateList(void)
 %    o encode: Specifies the encode delegate we are searching for as a
 %      character string.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport char *GetDelegateCommand(const ImageInfo *image_info,Image *image,
@@ -331,7 +331,7 @@ MagickExport const char *GetDelegateCommands(const DelegateInfo *delegate_info)
 %    o encode: Specifies the encode delegate we are searching for as a
 %      character string.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport const DelegateInfo *GetDelegateInfo(const char *decode,
@@ -415,7 +415,7 @@ MagickExport const DelegateInfo *GetDelegateInfo(const char *decode,
 %    o number_delegates:  This integer returns the number of delegates in the
 %      list.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -521,7 +521,7 @@ MagickExport const DelegateInfo **GetDelegateInfoList(const char *pattern,
 %    o number_delegates:  This integer returns the number of delegates
 %      in the list.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -672,7 +672,7 @@ MagickExport MagickBooleanType GetDelegateThreadSupport(
 %
 %  A description of each parameter follows.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 static MagickBooleanType InitializeDelegateList(ExceptionInfo *exception)
@@ -718,7 +718,7 @@ static MagickBooleanType InitializeDelegateList(ExceptionInfo *exception)
 %
 %    o image: the image.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -775,9 +775,9 @@ static MagickBooleanType CopyDelegateFile(const char *source,
       (void) close(destination_file);
       return(MagickFalse);
     }
-  quantum=(size_t) MagickMaxBufferSize;
+  quantum=(size_t) MagickMaxBufferExtent;
   if ((fstat(source_file,&attributes) == 0) && (attributes.st_size != 0))
-    quantum=MagickMin((size_t) attributes.st_size,MagickMaxBufferSize);
+    quantum=MagickMin((size_t) attributes.st_size,MagickMaxBufferExtent);
   buffer=(unsigned char *) AcquireQuantumMemory(quantum,sizeof(*buffer));
   if (buffer == (unsigned char *) NULL)
     {
@@ -1052,7 +1052,7 @@ MagickExport MagickBooleanType InvokeDelegate(ImageInfo *image_info,
 %
 %    o file:  An pointer to a FILE.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport MagickBooleanType ListDelegateInfo(FILE *file,
@@ -1092,7 +1092,7 @@ MagickExport MagickBooleanType ListDelegateInfo(FILE *file,
       {
         if (delegate_info[i]->path != (char *) NULL)
           (void) fprintf(file,"\nPath: %s\n\n",delegate_info[i]->path);
-        (void) fprintf(file,"Delegate             Command\n");
+        (void) fprintf(file,"Delegate                Command\n");
         (void) fprintf(file,"-------------------------------------------------"
           "------------------------------\n");
       }
@@ -1105,7 +1105,7 @@ MagickExport MagickBooleanType ListDelegateInfo(FILE *file,
     commands=StringToList(delegate_info[i]->commands);
     if (commands == (char **) NULL)
       continue;
-    (void) fprintf(file,"%8s%c=%c%s  ",delegate_info[i]->decode ?
+    (void) fprintf(file,"%11s%c=%c%s  ",delegate_info[i]->decode ?
       delegate_info[i]->decode : "",delegate_info[i]->mode <= 0 ? '<' : ' ',
       delegate_info[i]->mode >= 0 ? '>' : ' ',delegate);
     StripString(commands[0]);
@@ -1152,31 +1152,30 @@ MagickExport MagickBooleanType ListDelegateInfo(FILE *file,
 %
 %    o depth: depth of <include /> statements.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 static MagickBooleanType LoadDelegateList(const char *xml,const char *filename,
   const unsigned long depth,ExceptionInfo *exception)
 {
+  char
+    keyword[MaxTextExtent],
+    *token;
+
   const char
-    *attribute;
+    *q;
 
   DelegateInfo
-    *delegate_info = (DelegateInfo *) NULL;
+    *delegate_info;
 
   MagickBooleanType
     status;
 
-  XMLTreeInfo
-    *delegate,
-    *delegate_map,
-    *include;
-
   /*
     Load the delegate map file.
   */
   (void) LogMagickEvent(ConfigureEvent,GetMagickModule(),
-    "Loading delegate map \"%s\" ...",filename);
+    "Loading delegate configuration file \"%s\" ...",filename);
   if (xml == (const char *) NULL)
     return(MagickFalse);
   if (delegate_list == (LinkedListInfo *) NULL)
@@ -1189,116 +1188,207 @@ static MagickBooleanType LoadDelegateList(const char *xml,const char *filename,
           return(MagickFalse);
         }
     }
-  delegate_map=NewXMLTree(xml,exception);
-  if (delegate_map == (XMLTreeInfo *) NULL)
-    return(MagickFalse);
   status=MagickTrue;
-  include=GetXMLTreeChild(delegate_map,"include");
-  while (include != (XMLTreeInfo *) NULL)
+  delegate_info=(DelegateInfo *) NULL;
+  token=AcquireString(xml);
+  for (q=(char *) xml; *q != '\0'; )
   {
     /*
-      Process include element.
+      Interpret XML.
     */
-    attribute=GetXMLTreeAttribute(include,"file");
-    if (attribute != (const char *) NULL)
+    GetMagickToken(q,&q,token);
+    if (*token == '\0')
+      break;
+    (void) CopyMagickString(keyword,token,MaxTextExtent);
+    if (LocaleNCompare(keyword,"<!DOCTYPE",9) == 0)
       {
-        if (depth > 200)
-          (void) ThrowMagickException(exception,GetMagickModule(),
-            DelegateError,"IncludeElementNestedTooDeeply","`%s'",filename);
-        else
-          {
-            char
-              path[MaxTextExtent],
-              *xml;
-
-            GetPathComponent(filename,HeadPath,path);
-            if (*path != '\0')
-              (void) ConcatenateMagickString(path,DirectorySeparator,
-                MaxTextExtent);
-            (void) ConcatenateMagickString(path,attribute,MaxTextExtent);
-            xml=FileToString(path,~0,exception);
-            if (xml != (char *) NULL)
-              {
-                status=LoadDelegateList(xml,path,depth+1,exception);
-                xml=DestroyString(xml);
-              }
-          }
+        /*
+          Doctype element.
+        */
+        while ((LocaleNCompare(q,"]>",2) != 0) && (*q != '\0'))
+          GetMagickToken(q,&q,token);
+        continue;
       }
-    include=GetNextXMLTreeTag(include);
-  }
-  delegate=GetXMLTreeChild(delegate_map,"delegate");
-  while (delegate != (XMLTreeInfo *) NULL)
-  {
-    const char
-      *attribute;
+    if (LocaleNCompare(keyword,"<!--",4) == 0)
+      {
+        /*
+          Comment element.
+        */
+        while ((LocaleNCompare(q,"->",2) != 0) && (*q != '\0'))
+          GetMagickToken(q,&q,token);
+        continue;
+      }
+    if (LocaleCompare(keyword,"<include") == 0)
+      {
+        /*
+          Include element.
+        */
+        while (((*token != '/') && (*(token+1) != '>')) && (*q != '\0'))
+        {
+          (void) CopyMagickString(keyword,token,MaxTextExtent);
+          GetMagickToken(q,&q,token);
+          if (*token != '=')
+            continue;
+          GetMagickToken(q,&q,token);
+          if (LocaleCompare(keyword,"file") == 0)
+            {
+              if (depth > 200)
+                (void) ThrowMagickException(exception,GetMagickModule(),
+                  ConfigureError,"IncludeElementNestedTooDeeply","`%s'",token);
+              else
+                {
+                  char
+                    path[MaxTextExtent],
+                    *xml;
 
-    /*
-      Process delegate element.
-    */
-    delegate_info=(DelegateInfo *) AcquireMagickMemory(sizeof(*delegate_info));
+                  GetPathComponent(filename,HeadPath,path);
+                  if (*path != '\0')
+                    (void) ConcatenateMagickString(path,DirectorySeparator,
+                      MaxTextExtent);
+                  if (*token == *DirectorySeparator)
+                    (void) CopyMagickString(path,token,MaxTextExtent);
+                  else
+                    (void) ConcatenateMagickString(path,token,MaxTextExtent);
+                  xml=FileToString(path,~0,exception);
+                  if (xml != (char *) NULL)
+                    {
+                      status=LoadDelegateList(xml,path,depth+1,exception);
+                      xml=(char *) RelinquishMagickMemory(xml);
+                    }
+                }
+            }
+        }
+        continue;
+      }
+    if (LocaleCompare(keyword,"<delegate") == 0)
+      {
+        /*
+          Delegate element.
+        */
+        delegate_info=(DelegateInfo *) AcquireMagickMemory(
+          sizeof(*delegate_info));
+        if (delegate_info == (DelegateInfo *) NULL)
+          ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
+        (void) ResetMagickMemory(delegate_info,0,sizeof(*delegate_info));
+        delegate_info->path=ConstantString(filename);
+        delegate_info->signature=MagickSignature;
+        continue;
+      }
     if (delegate_info == (DelegateInfo *) NULL)
-      ThrowFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed");
-    (void) ResetMagickMemory(delegate_info,0,sizeof(*delegate_info));
-    delegate_info->path=ConstantString(filename);
-    delegate_info->signature=MagickSignature;
-    attribute=GetXMLTreeAttribute(delegate,"command");
-    if (attribute != (const char *) NULL)
+      continue;
+    if (LocaleCompare(keyword,"/>") == 0)
       {
-        char
-          *commands;
-
-        commands=ConstantString(attribute);
-#if defined(__WINDOWS__)
-        if (strchr(commands,'@') != (char *) NULL)
+        status=AppendValueToLinkedList(delegate_list,delegate_info);
+        if (status == MagickFalse)
+          (void) ThrowMagickException(exception,GetMagickModule(),
+            ResourceLimitError,"MemoryAllocationFailed","`%s'",
+            delegate_info->commands);
+        delegate_info=(DelegateInfo *) NULL;
+      }
+    GetMagickToken(q,(const char **) NULL,token);
+    if (*token != '=')
+      continue;
+    GetMagickToken(q,&q,token);
+    GetMagickToken(q,&q,token);
+    switch (*keyword)
+    {
+      case 'C':
+      case 'c':
+      {
+        if (LocaleCompare((char *) keyword,"command") == 0)
           {
             char
-              path[MaxTextExtent];
+              *commands;
 
-            NTGhostscriptEXE(path,MaxTextExtent);
-            SubstituteString((char **) &commands,"@PSDelegate@",path);
-            SubstituteString((char **) &commands,"\\","/");
-          }
+            commands=AcquireString(token);
+#if defined(__WINDOWS__)
+            if (strchr(commands,'@') != (char *) NULL)
+              {
+                char
+                  path[MaxTextExtent];
+
+                NTGhostscriptEXE(path,MaxTextExtent);
+                (void) SubstituteString((char **) &commands,"@PSDelegate@",
+                  path);
+                (void) SubstituteString((char **) &commands,"\\","/");
+              }
 #endif
-        delegate_info->commands=commands;
+            (void) SubstituteString((char **) &commands,"&amp;","\"");
+            (void) SubstituteString((char **) &commands,"&quot;","\"");
+            (void) SubstituteString((char **) &commands,"&gt;",">");
+            (void) SubstituteString((char **) &commands,"&lt;","<");
+            delegate_info->commands=commands;
+            break;
+          }
+        break;
       }
-    attribute=GetXMLTreeAttribute(delegate,"decode");
-    if (attribute != (const char *) NULL)
+      case 'D':
+      case 'd':
       {
-        delegate_info->decode=ConstantString(attribute);
-        delegate_info->mode=1;
+        if (LocaleCompare((char *) keyword,"decode") == 0)
+          {
+            delegate_info->decode=ConstantString(token);
+            delegate_info->mode=1;
+            break;
+          }
+        break;
       }
-    attribute=GetXMLTreeAttribute(delegate,"encode");
-    if (attribute != (const char *) NULL)
+      case 'E':
+      case 'e':
       {
-        delegate_info->encode=ConstantString(attribute);
-        delegate_info->mode=(-1);
+        if (LocaleCompare((char *) keyword,"encode") == 0)
+          {
+            delegate_info->encode=ConstantString(token);
+            delegate_info->mode=(-1);
+            break;
+          }
+        break;
       }
-    attribute=GetXMLTreeAttribute(delegate,"mode");
-    if (attribute != (const char *) NULL)
+      case 'M':
+      case 'm':
       {
-        delegate_info->mode=1;
-        if (LocaleCompare(attribute,"bi") == 0)
-          delegate_info->mode=0;
-        if (LocaleCompare(attribute,"encode") == 0)
-          delegate_info->mode=(-1);
+        if (LocaleCompare((char *) keyword,"mode") == 0)
+          {
+            delegate_info->mode=1;
+            if (LocaleCompare(token,"bi") == 0)
+              delegate_info->mode=0;
+            else
+              if (LocaleCompare(token,"encode") == 0)
+                delegate_info->mode=(-1);
+            break;
+          }
+        break;
       }
-    attribute=GetXMLTreeAttribute(delegate,"spawn");
-    if (attribute != (const char *) NULL)
-      delegate_info->spawn=IsMagickTrue(attribute);
-    attribute=GetXMLTreeAttribute(delegate,"stealth");
-    if (attribute != (const char *) NULL)
-      delegate_info->stealth=IsMagickTrue(attribute);
-    attribute=GetXMLTreeAttribute(delegate,"thread-support");
-    if (attribute != (const char *) NULL)
-      delegate_info->thread_support=IsMagickTrue(attribute);
-    status=AppendValueToLinkedList(delegate_list,delegate_info);
-    if (status == MagickFalse)
-      (void) ThrowMagickException(exception,GetMagickModule(),
-        ResourceLimitError,"MemoryAllocationFailed","`%s'",filename);
-    delegate=GetNextXMLTreeTag(delegate);
+      case 'S':
+      case 's':
+      {
+        if (LocaleCompare((char *) keyword,"spawn") == 0)
+          {
+            delegate_info->spawn=IsMagickTrue(token);
+            break;
+          }
+        if (LocaleCompare((char *) keyword,"stealth") == 0)
+          {
+            delegate_info->stealth=IsMagickTrue(token);
+            break;
+          }
+        break;
+      }
+      case 'T':
+      case 't':
+      {
+        if (LocaleCompare((char *) keyword,"thread-support") == 0)
+          {
+            delegate_info->thread_support=IsMagickTrue(token);
+            break;
+          }
+        break;
+      }
+      default:
+        break;
+    }
   }
-  delegate_map=DestroyXMLTree(delegate_map);
+  token=(char *) RelinquishMagickMemory(token);
   return(status);
 }
 
@@ -1325,7 +1415,7 @@ static MagickBooleanType LoadDelegateList(const char *xml,const char *filename,
 %
 %    o filename: the font file name.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 static MagickBooleanType LoadDelegateLists(const char *filename,
