@@ -10,7 +10,7 @@
 %               DDDD   IIIII  SSSSS    T     OOO   R  R     T                 %
 %                                                                             %
 %                                                                             %
-%                     ImageMagick Image Distortion Methods.                   %
+%                     MagickCore Image Distortion Methods                     %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
@@ -18,7 +18,7 @@
 %                                 June 2007                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 */
 #include "magick/studio.h"
 #include "magick/artifact.h"
+#include "magick/cache.h"
 #include "magick/cache-view.h"
 #include "magick/colorspace-private.h"
 #include "magick/composite-private.h"
@@ -58,6 +59,7 @@
 #include "magick/pixel.h"
 #include "magick/pixel-private.h"
 #include "magick/resample.h"
+#include "magick/resample-private.h"
 #include "magick/registry.h"
 #include "magick/semaphore.h"
 #include "magick/string_.h"
@@ -268,7 +270,7 @@ static double poly_basis_dy(long n, double x, double y)
 %
 %  The format of the GenerateCoefficients() method is:
 %
-%    Image *GenerateCoefficients(const Image *image, DistortImageMethod method,
+%    Image *GenerateCoefficients(const Image *image,DistortImageMethod method,
 %        const unsigned long number_arguments,const double *arguments,
 %        unsigned long number_values, ExceptionInfo *exception)
 %
@@ -290,7 +292,7 @@ static double poly_basis_dy(long n, double x, double y)
 %            Format: x,y,r,g,b    mapping x,y to color values r,g,b
 %            IN future, varible number of values may be given (1 to N)
 %
-%    o exception: Return any errors or warnings in this structure
+%    o exception: return any errors or warnings in this structure
 %
 %  Note that the returned array of double values must be freed by the
 %  calling method using RelinquishMagickMemory().  This however may change in
@@ -345,6 +347,7 @@ static double *GenerateCoefficients(const Image *image,
        ) )
     *method = AffineDistortion;
 
+  number_coeff=0;
   switch (*method) {
     case AffineDistortion:
     /* also BarycentricColorInterpolate: */
@@ -1242,73 +1245,35 @@ static double *GenerateCoefficients(const Image *image,
 %
 %    o method: the method of image distortion.
 %
+%        ArcDistortion always ignores source image offset, and always
+%        'bestfit' the destination image with the top left corner offset
+%        relative to the polar mapping center.
+%
+%        Bilinear has no simple inverse mapping so it does not allow 'bestfit'
+%        style of image distortion.
+%
+%        Affine, Perspective, and Bilinear, do least squares fitting of the
+%        distrotion when more than the minimum number of control point pairs
+%        are provided.
+%
+%        Perspective, and Bilinear, fall back to a Affine distortion when less
+%        than 4 control point pairs are provided.  While Affine distortions
+%        let you use any number of control point pairs, that is Zero pairs is
+%        a No-Op (viewport only) distortion, one pair is a translation and
+%        two pairs of control points do a scale-rotate-translate, without any
+%        shearing.
+%
 %    o number_arguments: the number of arguments given.
 %
 %    o arguments: an array of floating point arguments for this method.
 %
 %    o bestfit: Attempt to 'bestfit' the size of the resulting image.
-%         This also forces the resulting image to be a 'layered' virtual
-%         canvas image.  Can be overridden using 'distort:viewport' setting.
+%        This also forces the resulting image to be a 'layered' virtual
+%        canvas image.  Can be overridden using 'distort:viewport' setting.
 %
-%    o exception: Return any errors or warnings in this structure
-%
-% Specific Distortion notes...
-%
-%  ArcDistortion will always ignore source image offset, and always 'bestfit'
-%  the destination image with the top left corner offset relative to the polar
-%  mapping center.
-%
-%  Bilinear has no simple inverse mapping so will not allow 'bestfit' style
-%  of image distortion.
-%
-%  Affine, Perspective, and Bilinear, will do least squares fitting of the
-%  distrotion when more than the minimum number of control point pairs are
-%  provided.
-%
-%  Perspective, and Bilinear, will fall back to a Affine distortion when less
-%  that 4 control point pairs are provided. While Affine distortions will let
-%  you use any number of control point pairs, that is Zero pairs is a No-Op
-%  (viewport only) distrotion, one pair is a translation and two pairs of
-%  control points will do a scale-rotate-translate, without any shearing.
+%    o exception: return any errors or warnings in this structure
 %
 */
-
-static ResampleFilter **DestroyResampleFilterThreadSet(ResampleFilter **filter)
-{
-  register long
-    i;
-
-  assert(filter != (ResampleFilter **) NULL);
-  for (i=0; i < (long) GetCacheViewMaximumThreads(); i++)
-    if (filter[i] != (ResampleFilter *) NULL)
-      filter[i]=DestroyResampleFilter(filter[i]);
-  return((ResampleFilter **) RelinquishMagickMemory(filter));
-}
-
-static ResampleFilter **AcquireResampleFilterThreadSet(const Image *image,
-  ExceptionInfo *exception)
-{
-  register long
-    i;
-
-  ResampleFilter
-    **filter;
-
-  filter=(ResampleFilter **) AcquireQuantumMemory(GetCacheViewMaximumThreads(),
-    sizeof(*filter));
-  if (filter == (ResampleFilter **) NULL)
-    return((ResampleFilter **) NULL);
-  (void) ResetMagickMemory(filter,0,GetCacheViewMaximumThreads()*
-    sizeof(*filter));
-  for (i=0; i < (long) GetCacheViewMaximumThreads(); i++)
-  {
-    filter[i]=AcquireResampleFilter(image,exception);
-    if (filter[i] == (ResampleFilter *) NULL)
-      return(DestroyResampleFilterThreadSet(filter));
-  }
-  return(filter);
-}
-
 MagickExport Image *DistortImage(const Image *image,DistortImageMethod method,
   const unsigned long number_arguments,const double *arguments,
   MagickBooleanType bestfit,ExceptionInfo *exception)
@@ -1788,7 +1753,8 @@ MagickExport Image *DistortImage(const Image *image,DistortImageMethod method,
      */
     long
       j,
-      progress;
+      progress,
+      status;
 
     MagickPixelPacket
       zero;
@@ -1797,27 +1763,30 @@ MagickExport Image *DistortImage(const Image *image,DistortImageMethod method,
       **resample_filter;
 
     ViewInfo
-      **distort_view;
-
-    volatile MagickBooleanType
-      status;
+      *distort_view;
 
     status=MagickTrue;
     progress=0;
     GetMagickPixelPacket(distort_image,&zero);
-    resample_filter=AcquireResampleFilterThreadSet(image,exception);
-    distort_view=AcquireCacheViewThreadSet(distort_image);
-    #pragma omp parallel for schedule(static,64)
+    resample_filter=AcquireResampleFilterThreadSet(image,MagickFalse,exception);
+    distort_view=AcquireCacheView(distort_image);
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+#endif
     for (j=0; j < (long) distort_image->rows; j++)
     {
+      double
+        validity;  /* how mathematically valid is this the mapping */
+
+      MagickBooleanType
+        sync;
+
       MagickPixelPacket
         pixel,    /* pixel color to assign to distorted image */
         invalid;  /* the color to assign when distort result is invalid */
 
       PointInfo
         d,s;  /* transform destination image x,y  to source image x,y */
-      double
-        validity;  /* how mathematically valid is this the mapping */
 
       register IndexPacket
         *indexes;
@@ -1829,19 +1798,20 @@ MagickExport Image *DistortImage(const Image *image,DistortImageMethod method,
       register PixelPacket
         *q;
 
-      id=GetCacheViewThreadId();
-      q=SetCacheViewPixels(distort_view[id],0,j,distort_image->columns,1);
+      q=QueueCacheViewAuthenticPixels(distort_view,0,j,distort_image->columns,1,
+        exception);
       if (q == (PixelPacket *) NULL)
         {
           status=MagickFalse;
           continue;
         }
-      indexes=GetCacheViewIndexes(distort_view[id]);
+      indexes=GetCacheViewAuthenticIndexQueue(distort_view);
       pixel=zero;
 
       /* Define constant scaling vectors for Affine Distortions
         Other methods are either variable, or use interpolated lookup
       */
+      id=GetPixelCacheThreadId();
       switch (method)
       {
         case AffineDistortion:
@@ -2100,34 +2070,37 @@ MagickExport Image *DistortImage(const Image *image,DistortImageMethod method,
         }
         else {
           /* resample the source image to find its correct color */
-          pixel=ResamplePixelColor(resample_filter[id],s.x,s.y);
+          (void) ResamplePixelColor(resample_filter[id],s.x,s.y,&pixel);
           /* if validity between 0.0 and 1.0 mix result with invalid pixel */
           if ( validity < 1.0 ) {
             /* Do a blend of sample color and invalid pixel */
             /* should this be a 'Blend', or an 'Over' compose */
-            MagickPixelCompositeBlend(&pixel, validity,
-                &invalid, (1.0-validity), &pixel);
+            MagickPixelCompositeBlend(&pixel,validity,&invalid,(1.0-validity),
+              &pixel);
           }
           SetPixelPacket(distort_image,&pixel,q,indexes);
         }
         q++;
         indexes++;
       }
-      if (SyncCacheView(distort_view[id]) == MagickFalse)
+      sync=SyncCacheViewAuthenticPixels(distort_view,exception);
+      if (sync == MagickFalse)
         status=MagickFalse;
       if (image->progress_monitor != (MagickProgressMonitor) NULL)
         {
           MagickBooleanType
             proceed;
 
-          #pragma omp critical
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp critical (MagickCore_DistortImage)
+#endif
           proceed=SetImageProgress(image,DistortImageTag,progress++,
             image->rows);
           if (proceed == MagickFalse)
             status=MagickFalse;
         }
     }
-    distort_view=DestroyCacheViewThreadSet(distort_view);
+    distort_view=DestroyCacheView(distort_view);
     resample_filter=DestroyResampleFilterThreadSet(resample_filter);
 
     if (status == MagickFalse)
@@ -2159,9 +2132,9 @@ MagickExport Image *DistortImage(const Image *image,DistortImageMethod method,
 %  SparseColorImage(), given a set of coordinates, interpolates the colors
 %  found at those coordinates, across the whole image, using various methods.
 %
-%  The format of the SparseColor() method is:
+%  The format of the SparseColorImage() method is:
 %
-%      Image *SparseColor(const Image *image,const ChannelType channel,
+%      Image *SparseColorImage(const Image *image,const ChannelType channel,
 %        SparseColorMethod method,const unsigned long number_arguments,
 %        const double *arguments,ExceptionInfo *exception)
 %
@@ -2169,23 +2142,22 @@ MagickExport Image *DistortImage(const Image *image,DistortImageMethod method,
 %
 %    o image: the image to be filled in.
 %
-%    o channel: Specify which color values (in RGBKA sequence) are being set
-%               This also determines the number of color_values in above.
+%    o channel: Specify which color values (in RGBKA sequence) are being set.
+%        This also determines the number of color_values in above.
 %
 %    o method: the method to fill in the gradient between the control points.
 %
+%        The methods used for SparseColor() are often simular to methods
+%        used for DistortImage(), and even share the same code for determination
+%        of the function coefficents, though with more dimensions (or resulting
+%        values).
+%
 %    o number_arguments: the number of arguments given.
 %
-%    o arguments: array of floating point arguments for this method.
-%                  x,y,color_values,  ...
-%                 with color_values given as normalized values
+%    o arguments: array of floating point arguments for this method--
+%        x,y,color_values-- with color_values given as normalized values.
 %
-%    o exception: Return any errors or warnings in this structure
-%
-%  The methods used for SparseColor() are often simular to methods
-%  used for DistortImage(), and even share the same code for determination
-%  of the function coefficents, though with more dimensions (or resulting
-%  values).
+%    o exception: return any errors or warnings in this structure
 %
 */
 MagickExport Image *SparseColorImage(const Image *image,
@@ -2309,19 +2281,24 @@ MagickExport Image *SparseColorImage(const Image *image,
       j,
       progress;
 
-    ViewInfo
-      **sparse_view;
-
-    volatile MagickBooleanType
+    MagickBooleanType
       status;
 
+    ViewInfo
+      *sparse_view;
+
     status=MagickTrue;
     progress=0;
     GetMagickPixelPacket(sparse_image,&zero);
-    sparse_view=AcquireCacheViewThreadSet(sparse_image);
-    #pragma omp parallel for schedule(static,64)
+    sparse_view=AcquireCacheView(sparse_image);
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+#endif
     for (j=0; j < (long) sparse_image->rows; j++)
     {
+      MagickBooleanType
+        sync;
+
       MagickPixelPacket
         pixel;    /* pixel to assign to distorted image */
 
@@ -2329,21 +2306,20 @@ MagickExport Image *SparseColorImage(const Image *image,
         *indexes;
 
       register long
-        i,
-        id;
+        i;
 
       register PixelPacket
         *q;
 
-      id=GetCacheViewThreadId();
-      q=SetCacheViewPixels(sparse_view[id],0,j,sparse_image->columns,1);
+      q=QueueCacheViewAuthenticPixels(sparse_view,0,j,sparse_image->columns,
+        1,exception);
       if (q == (PixelPacket *) NULL)
         {
           status=MagickFalse;
           continue;
         }
 /* FUTURE: get pixel from source image - so channel can replace parts */
-      indexes=GetCacheViewIndexes(sparse_view[id]);
+      indexes=GetCacheViewAuthenticIndexQueue(sparse_view);
       pixel=zero;
       for (i=0; i < (long) sparse_image->columns; i++)
       {
@@ -2466,20 +2442,23 @@ MagickExport Image *SparseColorImage(const Image *image,
         q++;
         indexes++;
       }
-      if (SyncCacheView(sparse_view[id]) == MagickFalse)
+      sync=SyncCacheViewAuthenticPixels(sparse_view,exception);
+      if (sync == MagickFalse)
         status=MagickFalse;
       if (image->progress_monitor != (MagickProgressMonitor) NULL)
         {
           MagickBooleanType
             proceed;
 
-          #pragma omp critical
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp critical (MagickCore_SparseColorImage)
+#endif
           proceed=SetImageProgress(image,SparseColorTag,progress++,image->rows);
           if (proceed == MagickFalse)
             status=MagickFalse;
         }
     }
-    sparse_view=DestroyCacheViewThreadSet(sparse_view);
+    sparse_view=DestroyCacheView(sparse_view);
     if (status == MagickFalse)
       sparse_image=DestroyImage(sparse_image);
   }
