@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -40,10 +40,44 @@ typedef enum
   SubtractEvaluateOperator,
   XorEvaluateOperator,
   PowEvaluateOperator,
-  LogEvaluateOperator
+  LogEvaluateOperator,
+  ThresholdEvaluateOperator,
+  ThresholdBlackEvaluateOperator,
+  ThresholdWhiteEvaluateOperator,
+  GaussianNoiseEvaluateOperator,
+  ImpulseNoiseEvaluateOperator,
+  LaplacianNoiseEvaluateOperator,
+  MultiplicativeNoiseEvaluateOperator,
+  PoissonNoiseEvaluateOperator,
+  UniformNoiseEvaluateOperator,
+  CosineEvaluateOperator,
+  SineEvaluateOperator,
+  AddModulusEvaluateOperator
 } MagickEvaluateOperator;
 
+typedef enum
+{
+  UndefinedFunction,
+  PolynomialFunction,
+  SinusoidFunction
+} MagickFunction;
+
+typedef enum
+{
+  UndefinedNoise,
+  UniformNoise,
+  GaussianNoise,
+  MultiplicativeGaussianNoise,
+  ImpulseNoise,
+  LaplacianNoise,
+  PoissonNoise,
+  RandomNoise
+} NoiseType;
+
 extern MagickExport Image
+  *AddNoiseImage(const Image *,const NoiseType,ExceptionInfo *),
+  *AddNoiseImageChannel(const Image *,const ChannelType,const NoiseType,
+    ExceptionInfo *),
   *CharcoalImage(const Image *,const double,const double,ExceptionInfo *),
   *ColorizeImage(const Image *,const char *,const PixelPacket,ExceptionInfo *),
   *ConvolveImage(const Image *,const unsigned long,const double *,
@@ -64,6 +98,8 @@ extern MagickExport Image
     ExceptionInfo *),
   *SteganoImage(const Image *,const Image *,ExceptionInfo *),
   *StereoImage(const Image *,const Image *,ExceptionInfo *),
+  *StereoAnaglyphImage(const Image *,const Image *,const long,const long,
+     ExceptionInfo *),
   *SwirlImage(const Image *,double,ExceptionInfo *),
   *TintImage(const Image *,const char *,const PixelPacket,ExceptionInfo *),
   *VignetteImage(const Image *,const double,const double,const long,
@@ -75,6 +111,10 @@ extern MagickExport MagickBooleanType
     ExceptionInfo *),
   EvaluateImageChannel(Image *,const ChannelType,const MagickEvaluateOperator,
     const double,ExceptionInfo *),
+  FunctionImage(Image *,const MagickFunction,const unsigned long,const double *,
+    ExceptionInfo *),
+  FunctionImageChannel(Image *,const ChannelType,const MagickFunction,
+    const unsigned long,const double *,ExceptionInfo *),
   SolarizeImage(Image *,const double);
 
 #if defined(__cplusplus) || defined(c_plusplus)
