@@ -17,7 +17,7 @@
 %                                 August 1996                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -564,7 +564,7 @@ MagickExport void ConvertRGBToHWB(const Quantum red,const Quantum green,
 %
 %    o expansion: Method ExpandAffine returns the affine's expansion factor.
 %
-%    o affine: A pointer the the affine transform of type AffineMatrix.
+%    o affine: A pointer the affine transform of type AffineMatrix.
 %
 */
 MagickExport double ExpandAffine(const AffineMatrix *affine)
