@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -471,13 +471,6 @@ struct _ImageInfo
     *profile;
 };
 
-extern MagickExport const IndexPacket
-  *AcquireIndexes(const Image *);
-
-extern MagickExport const PixelPacket
-  *AcquireImagePixels(const Image *,const long,const long,const unsigned long,
-    const unsigned long,ExceptionInfo *);
-
 extern MagickExport ExceptionType
   CatchImageException(Image *);
 
@@ -504,19 +497,12 @@ extern MagickExport ImageInfo
 extern MagickExport ImageType
   GetImageType(Image *,ExceptionInfo *);
 
-extern MagickExport IndexPacket
-  *GetIndexes(const Image *);
-
-extern MagickExport long
-  InterpretImageFilename(char *,const size_t,const char *,int);
-
 extern MagickExport MagickBooleanType
   AcquireImageColormap(Image *,const unsigned long),
   ClipImage(Image *),
   ClipImagePath(Image *,const char *,const MagickBooleanType),
   CycleColormapImage(Image *,const long),
   GetImageAlphaChannel(const Image *),
-  GradientImage(Image *,const PixelPacket *,const PixelPacket *),
   IsTaintImage(const Image *),
   IsMagickConflict(const char *),
   IsHighDynamicRangeImage(const Image *,ExceptionInfo *),
@@ -538,22 +524,12 @@ extern MagickExport MagickBooleanType
   SortColormapByIntensity(Image *),
   StripImage(Image *),
   SyncImage(Image *),
-  SyncImagePixels(Image *),
+  SyncImageSettings(const ImageInfo *,Image *),
+  SyncImagesSettings(ImageInfo *,Image *),
   TextureImage(Image *,const Image *);
 
-extern MagickExport MagickPixelPacket
-  AcquireOneMagickPixel(const Image *,const long,const long,ExceptionInfo *);
-
-extern MagickExport PixelPacket
-  AcquireOnePixel(const Image *,const long,const long,ExceptionInfo *),
-  AcquireOneVirtualPixel(const Image *,const VirtualPixelMethod,const long,
-    const long,ExceptionInfo *),
-  *GetImagePixels(Image *,const long,const long,const unsigned long,
-    const unsigned long),
-  GetOnePixel(Image *,const long,const long),
-  *GetPixels(const Image *),
-  *SetImagePixels(Image *,const long,const long,const unsigned long,
-    const unsigned long);
+extern MagickExport size_t
+  InterpretImageFilename(const ImageInfo *,Image *,const char *,int,char *);
 
 extern MagickExport VirtualPixelMethod
   GetImageVirtualPixelMethod(const Image *),
