@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -25,19 +25,8 @@ extern "C" {
 #include <stdarg.h>
 #include "magick/exception.h"
 
-#if !defined(GetUnadornedModuleName)
-# if (((defined(__cplusplus) || defined(c_plusplus)) && defined(HAS_CPP__func__)) || \
-      (!(defined(__cplusplus) || defined(c_plusplus)) && defined(HAS_C__func__)))
-#  define GetUnadornedModuleName() (__func__)
-# elif defined(_VISUALC_) && defined(__FUNCTION__)
-#  define GetUnadornedModuleName() (__FUNCTION__)
-# else
-#  define GetUnadornedModuleName() ("unknown")
-# endif
-#endif
 #if !defined(GetMagickModule)
-# define GetMagickModule()  \
-  __FILE__,GetUnadornedModuleName(),(unsigned long) __LINE__
+# define GetMagickModule()  __FILE__,__func__,(unsigned long) __LINE__
 #endif
 
 #define MagickLogFilename  "log.xml"
