@@ -18,7 +18,7 @@
 %                             November 1998                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -414,7 +414,7 @@ MagickExport MagickBooleanType GetMagickEndianSupport(
 %
 %    o name: the image format we are looking for.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport const MagickInfo *GetMagickInfo(const char *name,
@@ -434,8 +434,11 @@ MagickExport const MagickInfo *GetMagickInfo(const char *name,
       if (LocaleCompare(name,"*") == 0)
         (void) OpenModules(exception);
 #endif
+      AcquireSemaphoreInfo(&magick_semaphore);
       ResetSplayTreeIterator(magick_list);
-      return((const MagickInfo *) GetNextValueInSplayTree(magick_list));
+      p=(const MagickInfo *) GetNextValueInSplayTree(magick_list);
+      RelinquishSemaphoreInfo(magick_semaphore);
+      return(p);
     }
   /*
     Find name in list.
@@ -493,7 +496,7 @@ MagickExport const MagickInfo *GetMagickInfo(const char *name,
 %
 %    o number_formats:  This integer returns the number of formats in the list.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -586,7 +589,7 @@ MagickExport const MagickInfo **GetMagickInfoList(const char *pattern,
 %
 %    o number_formats:  This integer returns the number of formats in the list.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -765,7 +768,7 @@ MagickExport MagickStatusType GetMagickThreadSupport(
 %
 %  A description of each parameter follows.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -886,14 +889,13 @@ MagickExport MagickBooleanType IsMagickConflict(const char *magick)
     return(MagickTrue);
 #if defined(macintosh)
   return(MACIsMagickConflict(magick));
-#endif
-#if defined(vms)
+#elif defined(vms)
   return(VMSIsMagickConflict(magick));
-#endif
-#if defined(__WINDOWS__)
+#elif defined(__WINDOWS__)
   return(NTIsMagickConflict(magick));
-#endif
+#else
   return(MagickFalse);
+#endif
 }
 
 /*
@@ -917,7 +919,7 @@ MagickExport MagickBooleanType IsMagickConflict(const char *magick)
 %
 %    o file: A file handle.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport MagickBooleanType ListMagickInfo(FILE *file,
@@ -1270,7 +1272,7 @@ MagickExport void MagickCoreTerminus(void)
   DestroyCoderList();
   DestroyMagickResources();
   DestroyImageRegistry();
-  DestroyCacheResources();
+  DestroyPixelCacheResources();
   DestroyRandomReservoir();
   DestroyLocaleList();
   DestroyLogList();
@@ -1406,7 +1408,6 @@ MagickExport MagickBooleanType UnregisterMagickInfo(const char *name)
     return(MagickFalse);
   if (GetNumberOfNodesInSplayTree(magick_list) == 0)
     return(MagickFalse);
-  status=MagickFalse;
   AcquireSemaphoreInfo(&magick_semaphore);
   ResetSplayTreeIterator(magick_list);
   p=(const MagickInfo *) GetNextValueInSplayTree(magick_list);
@@ -1416,6 +1417,7 @@ MagickExport MagickBooleanType UnregisterMagickInfo(const char *name)
       break;
     p=(const MagickInfo *) GetNextValueInSplayTree(magick_list);
   }
+  status=DeleteNodeByValueFromSplayTree(magick_list,p);
   RelinquishSemaphoreInfo(magick_semaphore);
-  return(DeleteNodeByValueFromSplayTree(magick_list,p));
+  return(status);
 }
