@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -37,11 +37,9 @@ extern "C" {
 #define PrependMagickMethod(method) \
   EvaluateMagickPrefix(MAGICKCORE_NAMESPACE_PREFIX,method)
 
-#define AcquireCacheNexus  PrependMagickMethod(AcquireCacheNexus)
 #define AcquireCacheViewIndexes  PrependMagickMethod(AcquireCacheViewIndexes)
 #define AcquireCacheViewPixels  PrependMagickMethod(AcquireCacheViewPixels)
 #define AcquireCacheView  PrependMagickMethod(AcquireCacheView)
-#define AcquireCacheViewThreadSet  PrependMagickMethod(AcquireCacheViewThreadSet)
 #define AcquireDrawInfo  PrependMagickMethod(AcquireDrawInfo)
 #define AcquireExceptionInfo  PrependMagickMethod(AcquireExceptionInfo)
 #define AcquireFxInfo  PrependMagickMethod(AcquireFxInfo)
@@ -55,12 +53,14 @@ extern "C" {
 #define AcquireMagickResource  PrependMagickMethod(AcquireMagickResource)
 #define AcquireMemory  PrependMagickMethod(AcquireMemory)
 #define AcquireNextImage  PrependMagickMethod(AcquireNextImage)
-#define AcquireNexusIndexes  PrependMagickMethod(AcquireNexusIndexes)
 #define AcquireOneCacheViewPixel  PrependMagickMethod(AcquireOneCacheViewPixel)
 #define AcquireOneCacheViewVirtualPixel  PrependMagickMethod(AcquireOneCacheViewVirtualPixel)
 #define AcquireOneMagickPixel  PrependMagickMethod(AcquireOneMagickPixel)
 #define AcquireOnePixel  PrependMagickMethod(AcquireOnePixel)
 #define AcquireOneVirtualPixel  PrependMagickMethod(AcquireOneVirtualPixel)
+#define AcquirePixelCacheInfo  PrependMagickMethod(AcquirePixelCacheInfo)
+#define AcquirePixelCacheNexus  PrependMagickMethod(AcquirePixelCacheNexus)
+#define AcquirePixels  PrependMagickMethod(AcquirePixels)
 #define AcquireQuantizeInfo  PrependMagickMethod(AcquireQuantizeInfo)
 #define AcquireQuantumInfo  PrependMagickMethod(AcquireQuantumInfo)
 #define AcquireQuantumMemory  PrependMagickMethod(AcquireQuantumMemory)
@@ -89,6 +89,8 @@ extern "C" {
 #define AddPathToXMLTree  PrependMagickMethod(AddPathToXMLTree)
 #define AddValueToSplayTree  PrependMagickMethod(AddValueToSplayTree)
 #define AffineTransformImage  PrependMagickMethod(AffineTransformImage)
+#define AffinityImage  PrependMagickMethod(AffinityImage)
+#define AffinityImages  PrependMagickMethod(AffinityImages)
 #define AllocateImageColormap  PrependMagickMethod(AllocateImageColormap)
 #define AllocateImage  PrependMagickMethod(AllocateImage)
 #define AllocateNextImage  PrependMagickMethod(AllocateNextImage)
@@ -111,6 +113,7 @@ extern "C" {
 #define Base64Encode  PrependMagickMethod(Base64Encode)
 #define BilevelImageChannel  PrependMagickMethod(BilevelImageChannel)
 #define BilevelImage  PrependMagickMethod(BilevelImage)
+#define BlackThresholdImageChannel  PrependMagickMethod(BlackThresholdImageChannel)
 #define BlackThresholdImage  PrependMagickMethod(BlackThresholdImage)
 #define BlobToFile  PrependMagickMethod(BlobToFile)
 #define BlobToImage  PrependMagickMethod(BlobToImage)
@@ -131,7 +134,6 @@ extern "C" {
 #define ClipImage  PrependMagickMethod(ClipImage)
 #define ClipPathImage  PrependMagickMethod(ClipPathImage)
 #define CloneBlobInfo  PrependMagickMethod(CloneBlobInfo)
-#define CloneCacheMethods  PrependMagickMethod(CloneCacheMethods)
 #define CloneCacheView  PrependMagickMethod(CloneCacheView)
 #define CloneDrawInfo  PrependMagickMethod(CloneDrawInfo)
 #define CloneImageArtifacts  PrependMagickMethod(CloneImageArtifacts)
@@ -145,6 +147,7 @@ extern "C" {
 #define CloneImages  PrependMagickMethod(CloneImages)
 #define CloneMemory  PrependMagickMethod(CloneMemory)
 #define CloneMontageInfo  PrependMagickMethod(CloneMontageInfo)
+#define ClonePixelCacheMethods  PrependMagickMethod(ClonePixelCacheMethods)
 #define CloneQuantizeInfo  PrependMagickMethod(CloneQuantizeInfo)
 #define CloneSplayTree  PrependMagickMethod(CloneSplayTree)
 #define CloneStringInfo  PrependMagickMethod(CloneStringInfo)
@@ -216,11 +219,7 @@ extern "C" {
 #define DeskewImage  PrependMagickMethod(DeskewImage)
 #define DespeckleImage  PrependMagickMethod(DespeckleImage)
 #define DestroyBlob  PrependMagickMethod(DestroyBlob)
-#define DestroyCacheInfo  PrependMagickMethod(DestroyCacheInfo)
-#define DestroyCacheNexus  PrependMagickMethod(DestroyCacheNexus)
-#define DestroyCacheResources  PrependMagickMethod(DestroyCacheResources)
 #define DestroyCacheView  PrependMagickMethod(DestroyCacheView)
-#define DestroyCacheViewThreadSet  PrependMagickMethod(DestroyCacheViewThreadSet)
 #define DestroyCoderList  PrependMagickMethod(DestroyCoderList)
 #define DestroyColorList  PrependMagickMethod(DestroyColorList)
 #define DestroyConfigureList  PrependMagickMethod(DestroyConfigureList)
@@ -254,6 +253,9 @@ extern "C" {
 #define DestroyMagicList  PrependMagickMethod(DestroyMagicList)
 #define DestroyMimeList  PrependMagickMethod(DestroyMimeList)
 #define DestroyMontageInfo  PrependMagickMethod(DestroyMontageInfo)
+#define DestroyPixelCacheInfo  PrependMagickMethod(DestroyPixelCacheInfo)
+#define DestroyPixelCacheNexus  PrependMagickMethod(DestroyPixelCacheNexus)
+#define DestroyPixelCacheResources  PrependMagickMethod(DestroyPixelCacheResources)
 #define DestroyQuantizeInfo  PrependMagickMethod(DestroyQuantizeInfo)
 #define DestroyQuantumInfo  PrependMagickMethod(DestroyQuantumInfo)
 #define DestroyRandomInfo  PrependMagickMethod(DestroyRandomInfo)
@@ -338,6 +340,10 @@ extern "C" {
 #define GaussianBlurImage  PrependMagickMethod(GaussianBlurImage)
 #define GaussJordanElimination  PrependMagickMethod(GaussJordanElimination)
 #define GetAffineMatrix  PrependMagickMethod(GetAffineMatrix)
+#define GetAuthenticIndexQueue  PrependMagickMethod(GetAuthenticIndexQueue)
+#define GetAuthenticPixelCacheNexus  PrependMagickMethod(GetAuthenticPixelCacheNexus)
+#define GetAuthenticPixelQueue  PrependMagickMethod(GetAuthenticPixelQueue)
+#define GetAuthenticPixels  PrependMagickMethod(GetAuthenticPixels)
 #define GetBlobError  PrependMagickMethod(GetBlobError)
 #define GetBlobFileHandle  PrependMagickMethod(GetBlobFileHandle)
 #define GetBlobInfo  PrependMagickMethod(GetBlobInfo)
@@ -345,18 +351,19 @@ extern "C" {
 #define GetBlobSize  PrependMagickMethod(GetBlobSize)
 #define GetBlobStreamData  PrependMagickMethod(GetBlobStreamData)
 #define GetBlobStreamHandler  PrependMagickMethod(GetBlobStreamHandler)
-#define GetCacheClass  PrependMagickMethod(GetCacheClass)
-#define GetCacheColorspace  PrependMagickMethod(GetCacheColorspace)
-#define GetCacheInfo  PrependMagickMethod(GetCacheInfo)
-#define GetCacheMethods  PrependMagickMethod(GetCacheMethods)
-#define GetCacheNexus  PrependMagickMethod(GetCacheNexus)
+#define GetCacheViewAuthenticIndexQueue  PrependMagickMethod(GetCacheViewAuthenticIndexQueue)
+#define GetCacheViewAuthenticPixelQueue  PrependMagickMethod(GetCacheViewAuthenticPixelQueue)
+#define GetCacheViewAuthenticPixels  PrependMagickMethod(GetCacheViewAuthenticPixels)
 #define GetCacheViewColorspace  PrependMagickMethod(GetCacheViewColorspace)
 #define GetCacheViewException  PrependMagickMethod(GetCacheViewException)
+#define GetCacheViewExtent  PrependMagickMethod(GetCacheViewExtent)
 #define GetCacheViewIndexes  PrependMagickMethod(GetCacheViewIndexes)
 #define GetCacheViewPixels  PrependMagickMethod(GetCacheViewPixels)
 #define GetCacheView  PrependMagickMethod(GetCacheView)
 #define GetCacheViewStorageClass  PrependMagickMethod(GetCacheViewStorageClass)
-#define GetCacheVirtualPixelMethod  PrependMagickMethod(GetCacheVirtualPixelMethod)
+#define GetCacheViewVirtualIndexQueue  PrependMagickMethod(GetCacheViewVirtualIndexQueue)
+#define GetCacheViewVirtualPixelQueue  PrependMagickMethod(GetCacheViewVirtualPixelQueue)
+#define GetCacheViewVirtualPixels  PrependMagickMethod(GetCacheViewVirtualPixels)
 #define GetClientName  PrependMagickMethod(GetClientName)
 #define GetClientPath  PrependMagickMethod(GetClientPath)
 #define GetCoderInfoList  PrependMagickMethod(GetCoderInfoList)
@@ -397,6 +404,7 @@ extern "C" {
 #define GetImageChannelDistortion  PrependMagickMethod(GetImageChannelDistortion)
 #define GetImageChannelDistortions  PrependMagickMethod(GetImageChannelDistortions)
 #define GetImageChannelExtrema  PrependMagickMethod(GetImageChannelExtrema)
+#define GetImageChannelKurtosis  PrependMagickMethod(GetImageChannelKurtosis)
 #define GetImageChannelMean  PrependMagickMethod(GetImageChannelMean)
 #define GetImageChannelRange  PrependMagickMethod(GetImageChannelRange)
 #define GetImageChannelStatistics  PrependMagickMethod(GetImageChannelStatistics)
@@ -408,6 +416,7 @@ extern "C" {
 #define GetImageDynamicThreshold  PrependMagickMethod(GetImageDynamicThreshold)
 #define GetImageEncoder  PrependMagickMethod(GetImageEncoder)
 #define GetImageException  PrependMagickMethod(GetImageException)
+#define GetImageExtent  PrependMagickMethod(GetImageExtent)
 #define GetImageExtrema  PrependMagickMethod(GetImageExtrema)
 #define GetImageFromList  PrependMagickMethod(GetImageFromList)
 #define GetImageFromMagickRegistry  PrependMagickMethod(GetImageFromMagickRegistry)
@@ -415,6 +424,7 @@ extern "C" {
 #define GetImageHistogram  PrependMagickMethod(GetImageHistogram)
 #define GetImageIndexInList  PrependMagickMethod(GetImageIndexInList)
 #define GetImageInfo  PrependMagickMethod(GetImageInfo)
+#define GetImageKurtosis  PrependMagickMethod(GetImageKurtosis)
 #define GetImageListIndex  PrependMagickMethod(GetImageListIndex)
 #define GetImageListLength  PrependMagickMethod(GetImageListLength)
 #define GetImageList  PrependMagickMethod(GetImageList)
@@ -423,6 +433,7 @@ extern "C" {
 #define GetImageMask  PrependMagickMethod(GetImageMask)
 #define GetImageMean  PrependMagickMethod(GetImageMean)
 #define GetImageOption  PrependMagickMethod(GetImageOption)
+#define GetImagePixelCache  PrependMagickMethod(GetImagePixelCache)
 #define GetImagePixels  PrependMagickMethod(GetImagePixels)
 #define GetImageProfile  PrependMagickMethod(GetImageProfile)
 #define GetImageProperty  PrependMagickMethod(GetImageProperty)
@@ -463,8 +474,10 @@ extern "C" {
 #define GetMagickOptions  PrependMagickMethod(GetMagickOptions)
 #define GetMagickPackageName  PrependMagickMethod(GetMagickPackageName)
 #define GetMagickPixelPacket  PrependMagickMethod(GetMagickPixelPacket)
+#define GetMagickProperty  PrependMagickMethod(GetMagickProperty)
 #define GetMagickQuantumDepth  PrependMagickMethod(GetMagickQuantumDepth)
 #define GetMagickQuantumRange  PrependMagickMethod(GetMagickQuantumRange)
+#define GetMagickRawSupport  PrependMagickMethod(GetMagickRawSupport)
 #define GetMagickRegistry  PrependMagickMethod(GetMagickRegistry)
 #define GetMagickReleaseDate  PrependMagickMethod(GetMagickReleaseDate)
 #define GetMagickResourceLimit  PrependMagickMethod(GetMagickResourceLimit)
@@ -497,23 +510,35 @@ extern "C" {
 #define GetNextValueInLinkedList  PrependMagickMethod(GetNextValueInLinkedList)
 #define GetNextValueInSplayTree  PrependMagickMethod(GetNextValueInSplayTree)
 #define GetNextXMLTreeTag  PrependMagickMethod(GetNextXMLTreeTag)
-#define GetNexusIndexes  PrependMagickMethod(GetNexusIndexes)
-#define GetNexusPixels  PrependMagickMethod(GetNexusPixels)
-#define GetNexus  PrependMagickMethod(GetNexus)
 #define GetNumberColors  PrependMagickMethod(GetNumberColors)
 #define GetNumberOfElementsInLinkedList  PrependMagickMethod(GetNumberOfElementsInLinkedList)
 #define GetNumberOfEntriesInHashmap  PrependMagickMethod(GetNumberOfEntriesInHashmap)
 #define GetNumberOfNodesInSplayTree  PrependMagickMethod(GetNumberOfNodesInSplayTree)
 #define GetNumberScenes  PrependMagickMethod(GetNumberScenes)
-#define GetOneCacheViewPixel  PrependMagickMethod(GetOneCacheViewPixel)
+#define GetOneAuthenticPixel  PrependMagickMethod(GetOneAuthenticPixel)
+#define GetOneCacheViewAuthenticPixel  PrependMagickMethod(GetOneCacheViewAuthenticPixel)
+#define GetOneCacheViewVirtualMethodPixel  PrependMagickMethod(GetOneCacheViewVirtualMethodPixel)
+#define GetOneCacheViewVirtualPixel  PrependMagickMethod(GetOneCacheViewVirtualPixel)
 #define GetOnePixel  PrependMagickMethod(GetOnePixel)
+#define GetOneVirtualMagickPixel  PrependMagickMethod(GetOneVirtualMagickPixel)
+#define GetOneVirtualMethodPixel  PrependMagickMethod(GetOneVirtualMethodPixel)
+#define GetOneVirtualPixel  PrependMagickMethod(GetOneVirtualPixel)
 #define GetOptimalKernelWidth1D  PrependMagickMethod(GetOptimalKernelWidth1D)
 #define GetOptimalKernelWidth2D  PrependMagickMethod(GetOptimalKernelWidth2D)
 #define GetOptimalKernelWidth  PrependMagickMethod(GetOptimalKernelWidth)
 #define GetPageGeometry  PrependMagickMethod(GetPageGeometry)
+#define GetPathAttributes  PrependMagickMethod(GetPathAttributes)
 #define GetPathComponent  PrependMagickMethod(GetPathComponent)
 #define GetPathComponents  PrependMagickMethod(GetPathComponents)
-#define GetPixelCacheExtent  PrependMagickMethod(GetPixelCacheExtent)
+#define GetPixelCacheColorspace  PrependMagickMethod(GetPixelCacheColorspace)
+#define GetPixelCacheMaximumThreads  PrependMagickMethod(GetPixelCacheMaximumThreads)
+#define GetPixelCacheMethods  PrependMagickMethod(GetPixelCacheMethods)
+#define GetPixelCacheNexusExtent  PrependMagickMethod(GetPixelCacheNexusExtent)
+#define GetPixelCacheNexusIndexes  PrependMagickMethod(GetPixelCacheNexusIndexes)
+#define GetPixelCacheNexusPixels  PrependMagickMethod(GetPixelCacheNexusPixels)
+#define GetPixelCacheStorageClass  PrependMagickMethod(GetPixelCacheStorageClass)
+#define GetPixelCacheThreadId  PrependMagickMethod(GetPixelCacheThreadId)
+#define GetPixelCacheVirtualMethod  PrependMagickMethod(GetPixelCacheVirtualMethod)
 #define GetPixels  PrependMagickMethod(GetPixels)
 #define GetPreviousImageInList  PrependMagickMethod(GetPreviousImageInList)
 #define GetPreviousImage  PrependMagickMethod(GetPreviousImage)
@@ -546,6 +571,12 @@ extern "C" {
 #define GetValueFromHashmap  PrependMagickMethod(GetValueFromHashmap)
 #define GetValueFromLinkedList  PrependMagickMethod(GetValueFromLinkedList)
 #define GetValueFromSplayTree  PrependMagickMethod(GetValueFromSplayTree)
+#define GetVirtualIndexesFromNexus  PrependMagickMethod(GetVirtualIndexesFromNexus)
+#define GetVirtualIndexQueue  PrependMagickMethod(GetVirtualIndexQueue)
+#define GetVirtualPixelQueue  PrependMagickMethod(GetVirtualPixelQueue)
+#define GetVirtualPixelsFromNexus  PrependMagickMethod(GetVirtualPixelsFromNexus)
+#define GetVirtualPixelsNexus  PrependMagickMethod(GetVirtualPixelsNexus)
+#define GetVirtualPixels  PrependMagickMethod(GetVirtualPixels)
 #define GetXMLTreeAttribute  PrependMagickMethod(GetXMLTreeAttribute)
 #define GetXMLTreeAttributes  PrependMagickMethod(GetXMLTreeAttributes)
 #define GetXMLTreeChild  PrependMagickMethod(GetXMLTreeChild)
@@ -591,7 +622,6 @@ extern "C" {
 #define InterpretImageProperties  PrependMagickMethod(InterpretImageProperties)
 #define InvokeDelegate  PrependMagickMethod(InvokeDelegate)
 #define InvokeDynamicImageFilter  PrependMagickMethod(InvokeDynamicImageFilter)
-#define IsAccessible  PrependMagickMethod(IsAccessible)
 #define IsBlobExempt  PrependMagickMethod(IsBlobExempt)
 #define IsBlobSeekable  PrependMagickMethod(IsBlobSeekable)
 #define IsBlobTemporary  PrependMagickMethod(IsBlobTemporary)
@@ -616,6 +646,7 @@ extern "C" {
 #define IsOpacitySimilar  PrependMagickMethod(IsOpacitySimilar)
 #define IsOpaqueImage  PrependMagickMethod(IsOpaqueImage)
 #define IsPaletteImage  PrependMagickMethod(IsPaletteImage)
+#define IsPathAccessible  PrependMagickMethod(IsPathAccessible)
 #define IsSceneGeometry  PrependMagickMethod(IsSceneGeometry)
 #define IsSubimage  PrependMagickMethod(IsSubimage)
 #define IsTaintImage  PrependMagickMethod(IsTaintImage)
@@ -645,6 +676,7 @@ extern "C" {
 #define ListThresholdMapFile  PrependMagickMethod(ListThresholdMapFile)
 #define ListThresholdMaps  PrependMagickMethod(ListThresholdMaps)
 #define ListTypeInfo  PrependMagickMethod(ListTypeInfo)
+#define LoadFontConfigFonts  PrependMagickMethod(LoadFontConfigFonts)
 #define LoadMimeLists  PrependMagickMethod(LoadMimeLists)
 #define LocaleCompare  PrependMagickMethod(LocaleCompare)
 #define LocaleLower  PrependMagickMethod(LocaleLower)
@@ -660,7 +692,6 @@ extern "C" {
 #define MagickFatalError  PrependMagickMethod(MagickFatalError)
 #define MagickIncarnate  PrependMagickMethod(MagickIncarnate)
 #define MagickMonitor  PrependMagickMethod(MagickMonitor)
-#define MagickOpenStream  PrependMagickMethod(MagickOpenStream)
 #define MagickOptionToMnemonic  PrependMagickMethod(MagickOptionToMnemonic)
 #define MagickToMime  PrependMagickMethod(MagickToMime)
 #define MagickWarning  PrependMagickMethod(MagickWarning)
@@ -678,6 +709,7 @@ extern "C" {
 #define MontageImages  PrependMagickMethod(MontageImages)
 #define MorphImages  PrependMagickMethod(MorphImages)
 #define MosaicImages  PrependMagickMethod(MosaicImages)
+#define MotionBlurImageChannel  PrependMagickMethod(MotionBlurImageChannel)
 #define MotionBlurImage  PrependMagickMethod(MotionBlurImage)
 #define MSBOrderLong  PrependMagickMethod(MSBOrderLong)
 #define MSBOrderShort  PrependMagickMethod(MSBOrderShort)
@@ -699,6 +731,7 @@ extern "C" {
 #define OpaquePaintImage  PrependMagickMethod(OpaquePaintImage)
 #define OpenBlob  PrependMagickMethod(OpenBlob)
 #define OpenCacheView  PrependMagickMethod(OpenCacheView)
+#define OpenMagickStream  PrependMagickMethod(OpenMagickStream)
 #define OpenStream  PrependMagickMethod(OpenStream)
 #define OptimizeImageLayers  PrependMagickMethod(OptimizeImageLayers)
 #define OptimizeImageTransparency  PrependMagickMethod(OptimizeImageTransparency)
@@ -721,10 +754,13 @@ extern "C" {
 #define ParseMagickOption  PrependMagickMethod(ParseMagickOption)
 #define ParseMetaGeometry  PrependMagickMethod(ParseMetaGeometry)
 #define ParsePageGeometry  PrependMagickMethod(ParsePageGeometry)
-#define ParseSizeGeometry  PrependMagickMethod(ParseSizeGeometry)
-#define PersistCache  PrependMagickMethod(PersistCache)
+#define ParseRegionGeometry  PrependMagickMethod(ParseRegionGeometry)
+#define PasskeyDecipherImage  PrependMagickMethod(PasskeyDecipherImage)
+#define PasskeyEncipherImage  PrependMagickMethod(PasskeyEncipherImage)
+#define PersistPixelCache  PrependMagickMethod(PersistPixelCache)
 #define PingBlob  PrependMagickMethod(PingBlob)
 #define PingImage  PrependMagickMethod(PingImage)
+#define PingImages  PrependMagickMethod(PingImages)
 #define PlasmaImage  PrependMagickMethod(PlasmaImage)
 #define PolaroidImage  PrependMagickMethod(PolaroidImage)
 #define PopImageList  PrependMagickMethod(PopImageList)
@@ -746,6 +782,9 @@ extern "C" {
 #define QueryColorname  PrependMagickMethod(QueryColorname)
 #define QueryMagickColorname  PrependMagickMethod(QueryMagickColorname)
 #define QueryMagickColor  PrependMagickMethod(QueryMagickColor)
+#define QueueAuthenticNexus  PrependMagickMethod(QueueAuthenticNexus)
+#define QueueAuthenticPixels  PrependMagickMethod(QueueAuthenticPixels)
+#define QueueCacheViewAuthenticPixels  PrependMagickMethod(QueueCacheViewAuthenticPixels)
 #define RadialBlurImageChannel  PrependMagickMethod(RadialBlurImageChannel)
 #define RadialBlurImage  PrependMagickMethod(RadialBlurImage)
 #define RaiseImage  PrependMagickMethod(RaiseImage)
@@ -766,13 +805,14 @@ extern "C" {
 #define ReadBlobShort  PrependMagickMethod(ReadBlobShort)
 #define ReadBlobString  PrependMagickMethod(ReadBlobString)
 #define ReadImage  PrependMagickMethod(ReadImage)
+#define ReadImages  PrependMagickMethod(ReadImages)
 #define ReadInlineImage  PrependMagickMethod(ReadInlineImage)
 #define ReadStream  PrependMagickMethod(ReadStream)
 #define RecolorImage  PrependMagickMethod(RecolorImage)
 #define ReduceNoiseImage  PrependMagickMethod(ReduceNoiseImage)
 #define ReferenceBlob  PrependMagickMethod(ReferenceBlob)
-#define ReferenceCache  PrependMagickMethod(ReferenceCache)
 #define ReferenceImage  PrependMagickMethod(ReferenceImage)
+#define ReferencePixelCache  PrependMagickMethod(ReferencePixelCache)
 #define RegisterARTImage  PrependMagickMethod(RegisterARTImage)
 #define RegisterAVIImage  PrependMagickMethod(RegisterAVIImage)
 #define RegisterAVSImage  PrependMagickMethod(RegisterAVSImage)
@@ -792,6 +832,7 @@ extern "C" {
 #define RegisterDPSImage  PrependMagickMethod(RegisterDPSImage)
 #define RegisterDPXImage  PrependMagickMethod(RegisterDPXImage)
 #define RegisterEPTImage  PrependMagickMethod(RegisterEPTImage)
+#define RegisterEXRImage  PrependMagickMethod(RegisterEXRImage)
 #define RegisterFAXImage  PrependMagickMethod(RegisterFAXImage)
 #define RegisterFITSImage  PrependMagickMethod(RegisterFITSImage)
 #define RegisterGIFImage  PrependMagickMethod(RegisterGIFImage)
@@ -801,6 +842,7 @@ extern "C" {
 #define RegisterHTMLImage  PrependMagickMethod(RegisterHTMLImage)
 #define RegisterICONImage  PrependMagickMethod(RegisterICONImage)
 #define RegisterINFOImage  PrependMagickMethod(RegisterINFOImage)
+#define RegisterINLINEImage  PrependMagickMethod(RegisterINLINEImage)
 #define RegisterIPLImage  PrependMagickMethod(RegisterIPLImage)
 #define RegisterJP2Image  PrependMagickMethod(RegisterJP2Image)
 #define RegisterJPEGImage  PrependMagickMethod(RegisterJPEGImage)
@@ -880,6 +922,8 @@ extern "C" {
 #define RelinquishMagickResource  PrependMagickMethod(RelinquishMagickResource)
 #define RelinquishSemaphoreInfo  PrependMagickMethod(RelinquishSemaphoreInfo)
 #define RelinquishUniqueFileResource  PrependMagickMethod(RelinquishUniqueFileResource)
+#define RemapImage  PrependMagickMethod(RemapImage)
+#define RemapImages  PrependMagickMethod(RemapImages)
 #define RemoteDisplayCommand  PrependMagickMethod(RemoteDisplayCommand)
 #define RemoveDuplicateLayers  PrependMagickMethod(RemoveDuplicateLayers)
 #define RemoveElementByValueFromLinkedList  PrependMagickMethod(RemoveElementByValueFromLinkedList)
@@ -931,14 +975,10 @@ extern "C" {
 #define SepiaToneImage  PrependMagickMethod(SepiaToneImage)
 #define SetBlobExempt  PrependMagickMethod(SetBlobExempt)
 #define SetBlobExtent  PrependMagickMethod(SetBlobExtent)
-#define SetCacheMethods  PrependMagickMethod(SetCacheMethods)
-#define SetCacheNexus  PrependMagickMethod(SetCacheNexus)
 #define SetCacheThreshold  PrependMagickMethod(SetCacheThreshold)
 #define SetCacheViewPixels  PrependMagickMethod(SetCacheViewPixels)
-#define SetCacheView  PrependMagickMethod(SetCacheView)
 #define SetCacheViewStorageClass  PrependMagickMethod(SetCacheViewStorageClass)
 #define SetCacheViewVirtualPixelMethod  PrependMagickMethod(SetCacheViewVirtualPixelMethod)
-#define SetCacheVirtualPixelMethod  PrependMagickMethod(SetCacheVirtualPixelMethod)
 #define SetClientName  PrependMagickMethod(SetClientName)
 #define SetClientPath  PrependMagickMethod(SetClientPath)
 #define SetErrorHandler  PrependMagickMethod(SetErrorHandler)
@@ -981,14 +1021,22 @@ extern "C" {
 #define SetMagickRegistry  PrependMagickMethod(SetMagickRegistry)
 #define SetMagickResourceLimit  PrependMagickMethod(SetMagickResourceLimit)
 #define SetMonitorHandler  PrependMagickMethod(SetMonitorHandler)
+#define SetPixelCacheMaximumThreads  PrependMagickMethod(SetPixelCacheMaximumThreads)
+#define SetPixelCacheMethods  PrependMagickMethod(SetPixelCacheMethods)
+#define SetPixelCacheVirtualMethod  PrependMagickMethod(SetPixelCacheVirtualMethod)
 #define SetQuantumAlphaType  PrependMagickMethod(SetQuantumAlphaType)
 #define SetQuantumDepth  PrependMagickMethod(SetQuantumDepth)
 #define SetQuantumFormat  PrependMagickMethod(SetQuantumFormat)
 #define SetQuantumImageType  PrependMagickMethod(SetQuantumImageType)
+#define SetQuantumMinIsWhite  PrependMagickMethod(SetQuantumMinIsWhite)
+#define SetQuantumPack  PrependMagickMethod(SetQuantumPack)
 #define SetQuantumPad  PrependMagickMethod(SetQuantumPad)
+#define SetQuantumQuantum  PrependMagickMethod(SetQuantumQuantum)
+#define SetQuantumScale  PrependMagickMethod(SetQuantumScale)
 #define SetRandomKey  PrependMagickMethod(SetRandomKey)
 #define SetRandomTrueRandom  PrependMagickMethod(SetRandomTrueRandom)
 #define SetResampleFilterInterpolateMethod  PrependMagickMethod(SetResampleFilterInterpolateMethod)
+#define SetResampleFilter  PrependMagickMethod(SetResampleFilter)
 #define SetResampleFilterVirtualPixelMethod  PrependMagickMethod(SetResampleFilterVirtualPixelMethod)
 #define SetResizeFilterSupport  PrependMagickMethod(SetResizeFilterSupport)
 #define SetSignatureDigest  PrependMagickMethod(SetSignatureDigest)
@@ -1016,7 +1064,7 @@ extern "C" {
 #define SketchImage  PrependMagickMethod(SketchImage)
 #define SolarizeImage  PrependMagickMethod(SolarizeImage)
 #define SortColormapByIntensity  PrependMagickMethod(SortColormapByIntensity)
-#define SparseColorInterpolate  PrependMagickMethod(SparseColorInterpolate)
+#define SparseColorImage  PrependMagickMethod(SparseColorImage)
 #define SpliceImageIntoList  PrependMagickMethod(SpliceImageIntoList)
 #define SpliceImageList  PrependMagickMethod(SpliceImageList)
 #define SpliceImage  PrependMagickMethod(SpliceImage)
@@ -1025,6 +1073,7 @@ extern "C" {
 #define SpreadImage  PrependMagickMethod(SpreadImage)
 #define StartTimer  PrependMagickMethod(StartTimer)
 #define SteganoImage  PrependMagickMethod(SteganoImage)
+#define StereoAnaglyphImage  PrependMagickMethod(StereoAnaglyphImage)
 #define StereoImage  PrependMagickMethod(StereoImage)
 #define StreamImage  PrependMagickMethod(StreamImage)
 #define StringInfoToHexString  PrependMagickMethod(StringInfoToHexString)
@@ -1039,11 +1088,12 @@ extern "C" {
 #define StripString  PrependMagickMethod(StripString)
 #define SubstituteString  PrependMagickMethod(SubstituteString)
 #define SwirlImage  PrependMagickMethod(SwirlImage)
-#define SyncCacheNexus  PrependMagickMethod(SyncCacheNexus)
+#define SyncAuthenticPixelCacheNexus  PrependMagickMethod(SyncAuthenticPixelCacheNexus)
+#define SyncAuthenticPixels  PrependMagickMethod(SyncAuthenticPixels)
+#define SyncCacheViewAuthenticPixels  PrependMagickMethod(SyncCacheViewAuthenticPixels)
+#define SyncCacheViewPixels  PrependMagickMethod(SyncCacheViewPixels)
 #define SyncCacheView  PrependMagickMethod(SyncCacheView)
 #define SyncImageList  PrependMagickMethod(SyncImageList)
-#define SyncImageOptions  PrependMagickMethod(SyncImageOptions)
-#define SyncImagePixelCache  PrependMagickMethod(SyncImagePixelCache)
 #define SyncImagePixels  PrependMagickMethod(SyncImagePixels)
 #define SyncImage  PrependMagickMethod(SyncImage)
 #define SyncImageProfiles  PrependMagickMethod(SyncImageProfiles)
@@ -1067,6 +1117,7 @@ extern "C" {
 #define TransformRGBImage  PrependMagickMethod(TransformRGBImage)
 #define TranslateText  PrependMagickMethod(TranslateText)
 #define TransparentImage  PrependMagickMethod(TransparentImage)
+#define TransparentPaintImageChroma  PrependMagickMethod(TransparentPaintImageChroma)
 #define TransparentPaintImage  PrependMagickMethod(TransparentPaintImage)
 #define TransposeImage  PrependMagickMethod(TransposeImage)
 #define TransverseImage  PrependMagickMethod(TransverseImage)
@@ -1093,6 +1144,7 @@ extern "C" {
 #define UnregisterDPSImage  PrependMagickMethod(UnregisterDPSImage)
 #define UnregisterDPXImage  PrependMagickMethod(UnregisterDPXImage)
 #define UnregisterEPTImage  PrependMagickMethod(UnregisterEPTImage)
+#define UnregisterEXRImage  PrependMagickMethod(UnregisterEXRImage)
 #define UnregisterFAXImage  PrependMagickMethod(UnregisterFAXImage)
 #define UnregisterFITSImage  PrependMagickMethod(UnregisterFITSImage)
 #define UnregisterGIFImage  PrependMagickMethod(UnregisterGIFImage)
@@ -1102,6 +1154,7 @@ extern "C" {
 #define UnregisterHTMLImage  PrependMagickMethod(UnregisterHTMLImage)
 #define UnregisterICONImage  PrependMagickMethod(UnregisterICONImage)
 #define UnregisterINFOImage  PrependMagickMethod(UnregisterINFOImage)
+#define UnregisterINLINEImage  PrependMagickMethod(UnregisterINLINEImage)
 #define UnregisterIPLImage  PrependMagickMethod(UnregisterIPLImage)
 #define UnregisterJP2Image  PrependMagickMethod(UnregisterJP2Image)
 #define UnregisterJPEGImage  PrependMagickMethod(UnregisterJPEGImage)
@@ -1183,6 +1236,7 @@ extern "C" {
 #define ValidateColormapIndex  PrependMagickMethod(ValidateColormapIndex)
 #define VignetteImage  PrependMagickMethod(VignetteImage)
 #define WaveImage  PrependMagickMethod(WaveImage)
+#define WhiteThresholdImageChannel  PrependMagickMethod(WhiteThresholdImageChannel)
 #define WhiteThresholdImage  PrependMagickMethod(WhiteThresholdImage)
 #define WriteBlobByte  PrependMagickMethod(WriteBlobByte)
 #define WriteBlobFloat  PrependMagickMethod(WriteBlobFloat)
