@@ -9,13 +9,13 @@
 %                        M   M  IIIII  M   M  EEEEE                           %
 %                                                                             %
 %                                                                             %
-%                         ImageMagick Mime Methods                            %
+%                          MagickCore Mime Methods                            %
 %                                                                             %
 %                              Software Design                                %
 %                                 July 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -205,7 +205,7 @@ MagickExport void DestroyMimeList(void)
 %
 %    o length: the length of the binary signature.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport const MimeInfo *GetMimeInfo(const char *filename,
@@ -403,7 +403,7 @@ MagickExport const MimeInfo *GetMimeInfo(const char *filename,
 %    o number_aliases:  This integer returns the number of magics in the
 %      list.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -500,7 +500,7 @@ MagickExport const MimeInfo **GetMimeInfoList(const char *pattern,
 %    o number_aliases:  This integer returns the number of image format aliases
 %      in the list.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -645,7 +645,7 @@ MagickExport const char *GetMimeType(const MimeInfo *mime_info)
 %
 %  A description of each parameter follows.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 static MagickBooleanType InitializeMimeList(ExceptionInfo *exception)
@@ -686,7 +686,7 @@ static MagickBooleanType InitializeMimeList(ExceptionInfo *exception)
 %
 %    o file:  An pointer to a FILE.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport MagickBooleanType ListMimeInfo(FILE *file,ExceptionInfo *exception)
@@ -775,7 +775,7 @@ MagickExport MagickBooleanType ListMimeInfo(FILE *file,ExceptionInfo *exception)
 %
 %    o depth: depth of <include /> statements.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 static MagickBooleanType LoadMimeList(const char *xml,const char *filename,
@@ -838,7 +838,10 @@ static MagickBooleanType LoadMimeList(const char *xml,const char *filename,
             if (*path != '\0')
               (void) ConcatenateMagickString(path,DirectorySeparator,
                 MaxTextExtent);
-            (void) ConcatenateMagickString(path,attribute,MaxTextExtent);
+            if (*attribute == *DirectorySeparator)
+              (void) CopyMagickString(path,attribute,MaxTextExtent);
+            else
+              (void) ConcatenateMagickString(path,attribute,MaxTextExtent);
             xml=FileToString(path,~0,exception);
             if (xml != (char *) NULL)
               {
@@ -990,7 +993,7 @@ static MagickBooleanType LoadMimeList(const char *xml,const char *filename,
 %
 %    o filename: the font file name.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport MagickBooleanType LoadMimeLists(const char *filename,
