@@ -442,7 +442,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
     (void) ParseAbsoluteGeometry("0x0+0+0",&image->page);
     progress_monitor=SetImageProgressMonitor(image,(MagickProgressMonitor) NULL,
       image->client_data);
-    flags=ParseSizeGeometry(image,montage_info->geometry,&geometry,exception);
+    flags=ParseRegionGeometry(image,montage_info->geometry,&geometry,exception);
     thumbnail=ThumbnailImage(image,geometry.width,geometry.height,exception);
     if (thumbnail == (Image *) NULL)
       break;
