@@ -10,14 +10,14 @@
 %                   OOO   P        T    IIIII   OOO   N   N                   %
 %                                                                             %
 %                                                                             %
-%                        ImageMagick Option Methods                           %
+%                         MagickCore Option Methods                           %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -363,6 +363,10 @@ static const OptionInfo
     { "-interlace", 1L, MagickFalse },
     { "+interpolate", 0L, MagickFalse },
     { "-interpolate", 1L, MagickFalse },
+    { "+interword-spacing", 0L, MagickFalse },
+    { "-interword-spacing", 1L, MagickFalse },
+    { "+kerning", 0L, MagickFalse },
+    { "-kerning", 1L, MagickFalse },
     { "+label", 0L, MagickFalse },
     { "-label", 1L, MagickFalse },
     { "+lat", 0L, MagickFalse },
@@ -826,7 +830,10 @@ static const OptionInfo
   {
     { "Undefined", (long) UndefinedEvaluateOperator, MagickTrue },
     { "Add", (long) AddEvaluateOperator, MagickFalse },
+    { "AddModulus", (long) AddModulusEvaluateOperator, MagickFalse },
     { "And", (long) AndEvaluateOperator, MagickFalse },
+    { "Cos", (long) CosineEvaluateOperator, MagickFalse },
+    { "Cosine", (long) CosineEvaluateOperator, MagickFalse },
     { "Divide", (long) DivideEvaluateOperator, MagickFalse },
     { "GaussianNoise", (long) GaussianNoiseEvaluateOperator, MagickFalse },
     { "ImpulseNoise", (long) ImpulseNoiseEvaluateOperator, MagickFalse },
@@ -842,6 +849,8 @@ static const OptionInfo
     { "Pow", (long) PowEvaluateOperator, MagickFalse },
     { "RightShift", (long) RightShiftEvaluateOperator, MagickFalse },
     { "Set", (long) SetEvaluateOperator, MagickFalse },
+    { "Sin", (long) SineEvaluateOperator, MagickFalse },
+    { "Sine", (long) SineEvaluateOperator, MagickFalse },
     { "Subtract", (long) SubtractEvaluateOperator, MagickFalse },
     { "Threshold", (long) ThresholdEvaluateOperator, MagickFalse },
     { "ThresholdBlack", (long) ThresholdBlackEvaluateOperator, MagickFalse },
@@ -883,6 +892,13 @@ static const OptionInfo
     { "Welsh", (long) WelshFilter, MagickFalse },
     { (char *) NULL, (long) UndefinedFilter, MagickFalse }
   },
+  FunctionOptions[] =
+  {
+    { "Undefined", (long) UndefinedFunction, MagickTrue },
+    { "Polynomial", (long) PolynomialFunction, MagickFalse },
+    { "Sinusoid", (long) SinusoidFunction, MagickFalse },
+    { (char *) NULL, (long) UndefinedFunction, MagickFalse }
+  },
   GravityOptions[] =
   {
     { "Undefined", (long) UndefinedGravity, MagickTrue },
@@ -1003,20 +1019,23 @@ static const OptionInfo
   },
   ListOptions[] =
   {
-    { "Undefined", (long) MagickUndefinedOptions, MagickTrue },
     { "Align", (long) MagickAlignOptions, MagickFalse },
     { "Alpha", (long) MagickAlphaOptions, MagickFalse },
     { "Boolean", (long) MagickBooleanOptions, MagickFalse },
     { "Channel", (long) MagickChannelOptions, MagickFalse },
     { "Class", (long) MagickClassOptions, MagickFalse },
     { "ClipPath", (long) MagickClipPathOptions, MagickFalse },
+    { "Coder", (long) MagickCoderOptions, MagickFalse },
+    { "Color", (long) MagickColorOptions, MagickFalse },
     { "Colorspace", (long) MagickColorspaceOptions, MagickFalse },
-    { "Compose", (long) MagickComposeOptions, MagickFalse },
     { "Command", (long) MagickCommandOptions, MagickFalse },
+    { "Compose", (long) MagickComposeOptions, MagickFalse },
     { "Compress", (long) MagickCompressOptions, MagickFalse },
+    { "Configure", (long) MagickConfigureOptions, MagickFalse },
     { "DataType", (long) MagickDataTypeOptions, MagickFalse },
     { "Debug", (long) MagickDebugOptions, MagickFalse },
     { "Decoration", (long) MagickDecorateOptions, MagickFalse },
+    { "Delegate", (long) MagickDelegateOptions, MagickFalse },
     { "Dispose", (long) MagickDisposeOptions, MagickFalse },
     { "Distort", (long) MagickDistortOptions, MagickFalse },
     { "Dither", (long) MagickDitherOptions, MagickFalse },
@@ -1025,6 +1044,8 @@ static const OptionInfo
     { "FillRule", (long) MagickFillRuleOptions, MagickFalse },
     { "Filter", (long) MagickFilterOptions, MagickFalse },
     { "Font", (long) MagickFontOptions, MagickFalse },
+    { "Format", (long) MagickFormatOptions, MagickFalse },
+    { "Function", (long) MagickFunctionOptions, MagickFalse },
     { "Gravity", (long) MagickGravityOptions, MagickFalse },
     { "ImageList", (long) MagickImageListOptions, MagickFalse },
     { "Intent", (long) MagickIntentOptions, MagickFalse },
@@ -1034,34 +1055,30 @@ static const OptionInfo
     { "LineCap", (long) MagickLineCapOptions, MagickFalse },
     { "LineJoin", (long) MagickLineJoinOptions, MagickFalse },
     { "List", (long) MagickListOptions, MagickFalse },
+    { "Locale", (long) MagickLocaleOptions, MagickFalse },
     { "LogEvent", (long) MagickLogEventOptions, MagickFalse },
-    { "Metric", (long) MagickMetricOptions, MagickFalse },
+    { "Log", (long) MagickLogOptions, MagickFalse },
+    { "Magic", (long) MagickMagicOptions, MagickFalse },
     { "Method", (long) MagickMethodOptions, MagickFalse },
+    { "Metric", (long) MagickMetricOptions, MagickFalse },
     { "Mime", (long) MagickMimeOptions, MagickFalse },
     { "Mode", (long) MagickModeOptions, MagickFalse },
+    { "Module", (long) MagickModuleOptions, MagickFalse },
     { "Noise", (long) MagickNoiseOptions, MagickFalse },
     { "Orientation", (long) MagickOrientationOptions, MagickFalse },
     { "Preview", (long) MagickPreviewOptions, MagickFalse },
     { "Primitive", (long) MagickPrimitiveOptions, MagickFalse },
     { "QuantumFormat", (long) MagickQuantumFormatOptions, MagickFalse },
-    { "Resolution", (long) MagickResolutionOptions, MagickFalse },
     { "Resource", (long) MagickResourceOptions, MagickFalse },
     { "SparseColor", (long) MagickSparseColorOptions, MagickFalse },
     { "Storage", (long) MagickStorageOptions, MagickFalse },
     { "Stretch", (long) MagickStretchOptions, MagickFalse },
     { "Style", (long) MagickStyleOptions, MagickFalse },
-    { "VirtualPixel", (long) MagickVirtualPixelOptions, MagickFalse },
-    { "Coder", (long) MagickCoderOptions, MagickFalse },
-    { "Color", (long) MagickColorOptions, MagickFalse },
-    { "Configure", (long) MagickConfigureOptions, MagickFalse },
-    { "Delegate", (long) MagickDelegateOptions, MagickFalse },
-    { "Format", (long) MagickFormatOptions, MagickFalse },
-    { "Locale", (long) MagickLocaleOptions, MagickFalse },
-    { "Log", (long) MagickLogOptions, MagickFalse },
-    { "Magic", (long) MagickMagicOptions, MagickFalse },
-    { "Module", (long) MagickModuleOptions, MagickFalse },
     { "Threshold", (long) MagickThresholdOptions, MagickFalse },
     { "Type", (long) MagickTypeOptions, MagickFalse },
+    { "Units", (long) MagickResolutionOptions, MagickFalse },
+    { "Undefined", (long) MagickUndefinedOptions, MagickTrue },
+    { "VirtualPixel", (long) MagickVirtualPixelOptions, MagickFalse },
     { (char *) NULL, (long) MagickUndefinedOptions, MagickFalse }
   },
   LogEventOptions[] =
@@ -1550,6 +1567,7 @@ static const OptionInfo *GetOptionInfo(const MagickOption option)
     case MagickEvaluateOptions: return(EvaluateOptions);
     case MagickFillRuleOptions: return(FillRuleOptions);
     case MagickFilterOptions: return(FilterOptions);
+    case MagickFunctionOptions: return(FunctionOptions);
     case MagickGravityOptions: return(GravityOptions);
     case MagickImageListOptions: return(ImageListOptions);
     case MagickIntentOptions: return(IntentOptions);
