@@ -15,7 +15,7 @@
 %                     I    M   M  P      O   O  R R      T                    %
 %                   IIIII  M   M  P       OOO   R  R     T                    %
 %                                                                             %
-%                       Methods to Import Quantum Pixels                      %
+%                 MagickCore Methods to Import Quantum Pixels                 %
 %                                                                             %
 %                             Software Design                                 %
 %                               John Cristy                                   %
@@ -89,13 +89,16 @@
 %
 %  The format of the ImportQuantumPixels method is:
 %
-%      size_t ImportQuantumPixels(Image *image,const QuantumInfo *quantum_info,
-%        const QuantumType quantum_type,const unsigned char *pixels)
+%      size_t ImportQuantumPixels(Image *image,ViewInfo *image_view,
+%        const QuantumInfo *quantum_info,const QuantumType quantum_type,
+%        const unsigned char *pixels,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
 %    o image: the image.
 %
+%    o image_view: the image cache view.
+%
 %    o quantum_info: the quantum info.
 %
 %    o quantum_type: Declare which pixel components to transfer (red, green,
@@ -103,6 +106,8 @@
 %
 %    o pixels:  The pixel components are transferred from this buffer.
 %
+%    o exception: return any errors or warnings in this structure.
+%
 */
 
 static inline IndexPacket PushColormapIndex(Image *image,
@@ -177,7 +182,7 @@ static inline const unsigned char *PushFloatPixel(
 }
 
 static inline const unsigned char *PushQuantumPixel(QuantumState *quantum_state,
-  const unsigned long depth,const unsigned char *pixels,QuantumAny *quantum)
+  const unsigned long depth,const unsigned char *pixels,unsigned long *quantum)
 {
   register long
     i;
@@ -234,9 +239,9 @@ static inline const unsigned char *PushQuantumLongPixel(
   return(pixels);
 }
 
-MagickExport size_t ImportQuantumPixels(Image *image,
+MagickExport size_t ImportQuantumPixels(Image *image,ViewInfo *image_view,
   const QuantumInfo *quantum_info,const QuantumType quantum_type,
-  const unsigned char *pixels)
+  const unsigned char *pixels,ExceptionInfo *exception)
 {
   EndianType
     endian;
@@ -248,8 +253,7 @@ MagickExport size_t ImportQuantumPixels(Image *image,
     number_pixels;
 
   QuantumAny
-    pixel,
-    scale;
+    range;
 
   QuantumState
     quantum_state;
@@ -269,6 +273,9 @@ MagickExport size_t ImportQuantumPixels(Image *image,
   size_t
     extent;
 
+  unsigned long
+    pixel;
+
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
@@ -276,12 +283,18 @@ MagickExport size_t ImportQuantumPixels(Image *image,
   assert(quantum_info != (QuantumInfo *) NULL);
   assert(quantum_info->signature == MagickSignature);
   if (pixels == (const unsigned char *) NULL)
-    pixels=quantum_info->pixels;
-  number_pixels=GetPixelCacheExtent(image);
+    pixels=GetQuantumPixels(quantum_info);
   x=0;
   p=pixels;
-  q=GetPixels(image);
-  indexes=GetIndexes(image);
+  number_pixels=GetImageExtent(image);
+  q=GetAuthenticPixelQueue(image);
+  indexes=GetAuthenticIndexQueue(image);
+  if (image_view != (ViewInfo *) NULL)
+    {
+      number_pixels=GetCacheViewExtent(image_view);
+      q=GetCacheViewAuthenticPixelQueue(image_view);
+      indexes=GetCacheViewAuthenticIndexQueue(image_view);
+    }
   InitializeQuantumState(quantum_info,image->endian,&quantum_state);
   extent=GetQuantumExtent(image,quantum_info,quantum_type);
   endian=quantum_state.endian;
@@ -294,8 +307,8 @@ MagickExport size_t ImportQuantumPixels(Image *image,
 
       if (image->storage_class != PseudoClass)
         {
-          (void) ThrowMagickException(&image->exception,GetMagickModule(),
-            ImageError,"ColormappedImageRequired","`%s'",image->filename);
+          (void) ThrowMagickException(exception,GetMagickModule(),ImageError,
+            "ColormappedImageRequired","`%s'",image->filename);
           return(extent);
         }
       range_exception=MagickFalse;
@@ -456,7 +469,7 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
       }
       if (range_exception != MagickFalse)
-        (void) ThrowMagickException(&image->exception,GetMagickModule(),
+        (void) ThrowMagickException(exception,GetMagickModule(),
           CorruptImageError,"InvalidColormapIndex","`%s'",image->filename);
       break;
     }
@@ -467,7 +480,7 @@ MagickExport size_t ImportQuantumPixels(Image *image,
 
       if (image->storage_class != PseudoClass)
         {
-          (void) ThrowMagickException(&image->exception,GetMagickModule(),
+          (void) ThrowMagickException(exception,GetMagickModule(),
             ImageError,"ColormappedImageRequired","`%s'",image->filename);
           return(extent);
         }
@@ -521,13 +534,14 @@ MagickExport size_t ImportQuantumPixels(Image *image,
           register unsigned char
             pixel;
 
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             pixel=(unsigned char) ((*p >> 4) & 0xf);
             indexes[x]=PushColormapIndex(image,pixel,&range_exception);
             *q=image->colormap[(long) indexes[x]];
-            q->opacity=(Quantum) (QuantumRange-(QuantumRange*((int) (*p) &
-              0xf)/15));
+            pixel=(unsigned char) ((*p) & 0xf);
+            q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel,range));
             p++;
             q++;
           }
@@ -625,15 +639,14 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         default:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
             indexes[x]=PushColormapIndex(image,pixel,&range_exception);
             *q=image->colormap[(long) indexes[x]];
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel,
-              image->depth,scale));
+            q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel,range));
             p+=quantum_info->pad;
             q++;
           }
@@ -641,7 +654,7 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
       }
       if (range_exception != MagickFalse)
-        (void) ThrowMagickException(&image->exception,GetMagickModule(),
+        (void) ThrowMagickException(exception,GetMagickModule(),
           CorruptImageError,"InvalidColormapIndex","`%s'",image->filename);
       break;
     }
@@ -689,16 +702,16 @@ MagickExport size_t ImportQuantumPixels(Image *image,
           register unsigned char
             pixel;
 
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < ((long) number_pixels-1); x+=2)
           {
             pixel=(unsigned char) ((*p >> 4) & 0xf);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             q->green=q->red;
             q->blue=q->red;
             q++;
             pixel=(unsigned char) ((*p) & 0xf);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             q->green=q->red;
             q->blue=q->red;
             p++;
@@ -707,7 +720,7 @@ MagickExport size_t ImportQuantumPixels(Image *image,
           for (bit=0; bit < (long) (number_pixels % 2); bit++)
           {
             pixel=(unsigned char) (*p++ >> 4);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             q->green=q->red;
             q->blue=q->red;
             q++;
@@ -724,7 +737,7 @@ MagickExport size_t ImportQuantumPixels(Image *image,
               for (x=0; x < (long) number_pixels; x++)
               {
                 p=PushCharPixel(p,&pixel);
-                q->red=(Quantum) (QuantumRange-q->red);
+                q->red=(Quantum) (QuantumRange-ScaleCharToQuantum(pixel));
                 q->green=q->red;
                 q->blue=q->red;
                 p+=quantum_info->pad;
@@ -745,7 +758,7 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         case 10:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           if (quantum_info->pack == MagickFalse)
             {
               if (image->endian != LSBEndian)
@@ -753,18 +766,15 @@ MagickExport size_t ImportQuantumPixels(Image *image,
                   for (x=0; x < (long) number_pixels/3; x++)
                   {
                     p=PushLongPixel(endian,p,&pixel);
-                    q->red=ScaleAnyToQuantum((pixel >> 0) & 0x3ff,image->depth,
-                      scale);
+                    q->red=ScaleAnyToQuantum((pixel >> 0) & 0x3ff,range);
                     q->green=q->red;
                     q->blue=q->red;
                     q++;
-                    q->red=ScaleAnyToQuantum((pixel >> 10) & 0x3ff,image->depth,
-                      scale);
+                    q->red=ScaleAnyToQuantum((pixel >> 10) & 0x3ff,range);
                     q->green=q->red;
                     q->blue=q->red;
                     q++;
-                    q->red=ScaleAnyToQuantum((pixel >> 20) & 0x3ff,image->depth,
-                      scale);
+                    q->red=ScaleAnyToQuantum((pixel >> 20) & 0x3ff,range);
                     q->green=q->red;
                     q->blue=q->red;
                     p+=quantum_info->pad;
@@ -775,18 +785,15 @@ MagickExport size_t ImportQuantumPixels(Image *image,
               for (x=0; x < (long) number_pixels/3; x++)
               {
                 p=PushLongPixel(endian,p,&pixel);
-                q->red=ScaleAnyToQuantum((pixel >> 22) & 0x3ff,image->depth,
-                  scale);
+                q->red=ScaleAnyToQuantum((pixel >> 22) & 0x3ff,range);
                 q->green=q->red;
                 q->blue=q->red;
                 q++;
-                q->red=ScaleAnyToQuantum((pixel >> 12) & 0x3ff,image->depth,
-                  scale);
+                q->red=ScaleAnyToQuantum((pixel >> 12) & 0x3ff,range);
                 q->green=q->red;
                 q->blue=q->red;
                 q++;
-                q->red=ScaleAnyToQuantum((pixel >> 2) & 0x3ff,image->depth,
-                  scale);
+                q->red=ScaleAnyToQuantum((pixel >> 2) & 0x3ff,range);
                 q->green=q->red;
                 q->blue=q->red;
                 p+=quantum_info->pad;
@@ -797,7 +804,7 @@ MagickExport size_t ImportQuantumPixels(Image *image,
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             q->green=q->red;
             q->blue=q->red;
             p+=quantum_info->pad;
@@ -807,7 +814,7 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         case 12:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           if (quantum_info->pack == MagickFalse)
             {
               unsigned short
@@ -816,14 +823,12 @@ MagickExport size_t ImportQuantumPixels(Image *image,
               for (x=0; x < (long) (number_pixels-1); x+=2)
               {
                 p=PushShortPixel(endian,p,&pixel);
-                q->red=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),image->depth,
-                  scale);
+                q->red=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),range);
                 q->green=q->red;
                 q->blue=q->red;
                 q++;
                 p=PushShortPixel(endian,p,&pixel);
-                q->red=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),image->depth,
-                  scale);
+                q->red=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),range);
                 q->green=q->red;
                 q->blue=q->red;
                 p+=quantum_info->pad;
@@ -832,8 +837,7 @@ MagickExport size_t ImportQuantumPixels(Image *image,
               for (bit=0; bit < (long) (number_pixels % 2); bit++)
               {
                 p=PushShortPixel(endian,p,&pixel);
-                q->red=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),image->depth,
-                  scale);
+                q->red=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),range);
                 q->green=q->red;
                 q->blue=q->red;
                 p+=quantum_info->pad;
@@ -846,7 +850,7 @@ MagickExport size_t ImportQuantumPixels(Image *image,
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             q->green=q->red;
             q->blue=q->red;
             p+=quantum_info->pad;
@@ -936,11 +940,11 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         default:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             q->green=q->red;
             q->blue=q->red;
             p+=quantum_info->pad;
@@ -994,14 +998,15 @@ MagickExport size_t ImportQuantumPixels(Image *image,
           register unsigned char
             pixel;
 
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             pixel=(unsigned char) ((*p >> 4) & 0xf);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             q->green=q->red;
             q->blue=q->red;
-            q->opacity=(Quantum) (QuantumRange-(QuantumRange*((*p) & 0xf)/15));
+            pixel=(unsigned char) ((*p) & 0xf);
+            q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel,range));
             p++;
             q++;
           }
@@ -1027,15 +1032,15 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         case 10:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             q->green=q->red;
             q->blue=q->red;
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->opacity=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->opacity=ScaleAnyToQuantum(pixel,range);
             p+=quantum_info->pad;
             q++;
           }
@@ -1043,15 +1048,15 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         case 12:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             q->green=q->red;
             q->blue=q->red;
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->opacity=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->opacity=ScaleAnyToQuantum(pixel,range);
             p+=quantum_info->pad;
             q++;
           }
@@ -1134,16 +1139,15 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         default:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             q->green=q->red;
             q->blue=q->red;
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel,
-              image->depth,scale));
+            q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel,range));
             p+=quantum_info->pad;
             q++;
           }
@@ -1232,11 +1236,11 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         default:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             p+=quantum_info->pad;
             q++;
           }
@@ -1325,11 +1329,11 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         default:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->green=ScaleAnyToQuantum(pixel,range);
             p+=quantum_info->pad;
             q++;
           }
@@ -1418,11 +1422,11 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         default:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->blue=ScaleAnyToQuantum(pixel,range);
             p+=quantum_info->pad;
             q++;
           }
@@ -1510,12 +1514,11 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         default:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel,
-              image->depth,scale));
+            q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel,range));
             p+=quantum_info->pad;
             q++;
           }
@@ -1528,8 +1531,8 @@ MagickExport size_t ImportQuantumPixels(Image *image,
     {
       if (image->colorspace != CMYKColorspace)
         {
-          (void) ThrowMagickException(&image->exception,GetMagickModule(),
-            ImageError,"ColorSeparatedImageRequired","`%s'",image->filename);
+          (void) ThrowMagickException(exception,GetMagickModule(),ImageError,
+            "ColorSeparatedImageRequired","`%s'",image->filename);
           return(extent);
         }
       switch (quantum_info->depth)
@@ -1607,11 +1610,11 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         default:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            indexes[x]=ScaleAnyToQuantum(pixel,image->depth,scale);
+            indexes[x]=ScaleAnyToQuantum(pixel,range);
             p+=quantum_info->pad;
             q++;
           }
@@ -1644,18 +1647,15 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         case 10:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           if (quantum_info->pack == MagickFalse)
             {
               for (x=0; x < (long) number_pixels; x++)
               {
                 p=PushLongPixel(endian,p,&pixel);
-                q->red=ScaleAnyToQuantum((pixel >> 22) & 0x3ff,image->depth,
-                  scale);
-                q->green=ScaleAnyToQuantum((pixel >> 12) & 0x3ff,image->depth,
-                  scale);
-                q->blue=ScaleAnyToQuantum((pixel >> 2) & 0x3ff,image->depth,
-                  scale);
+                q->red=ScaleAnyToQuantum((pixel >> 22) & 0x3ff,range);
+                q->green=ScaleAnyToQuantum((pixel >> 12) & 0x3ff,range);
+                q->blue=ScaleAnyToQuantum((pixel >> 2) & 0x3ff,range);
                 p+=quantum_info->pad;
                 q++;
               }
@@ -1666,11 +1666,11 @@ MagickExport size_t ImportQuantumPixels(Image *image,
               for (x=0; x < (long) number_pixels; x++)
               {
                 p=PushQuantumLongPixel(&quantum_state,image->depth,p,&pixel);
-                q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+                q->red=ScaleAnyToQuantum(pixel,range);
                 p=PushQuantumLongPixel(&quantum_state,image->depth,p,&pixel);
-                q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+                q->green=ScaleAnyToQuantum(pixel,range);
                 p=PushQuantumLongPixel(&quantum_state,image->depth,p,&pixel);
-                q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+                q->blue=ScaleAnyToQuantum(pixel,range);
                 q++;
               }
               break;
@@ -1678,18 +1678,18 @@ MagickExport size_t ImportQuantumPixels(Image *image,
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->green=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->blue=ScaleAnyToQuantum(pixel,range);
             q++;
           }
           break;
         }
         case 12:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           if (quantum_info->pack == MagickFalse)
             {
               unsigned short
@@ -1703,20 +1703,17 @@ MagickExport size_t ImportQuantumPixels(Image *image,
                   default:
                   case 0:
                   {
-                    q->red=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),
-                      image->depth,scale);
+                    q->red=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),range);
                     break;
                   }
                   case 1:
                   {
-                    q->green=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),
-                      image->depth,scale);
+                    q->green=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),range);
                     break;
                   }
                   case 2:
                   {
-                    q->blue=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),
-                      image->depth,scale);
+                    q->blue=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),range);
                     q++;
                     break;
                   }
@@ -1727,20 +1724,17 @@ MagickExport size_t ImportQuantumPixels(Image *image,
                   default:
                   case 0:
                   {
-                    q->red=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),
-                      image->depth,scale);
+                    q->red=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),range);
                     break;
                   }
                   case 1:
                   {
-                    q->green=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),
-                      image->depth,scale);
+                    q->green=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),range);
                     break;
                   }
                   case 2:
                   {
-                    q->blue=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),
-                      image->depth,scale);
+                    q->blue=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),range);
                     q++;
                     break;
                   }
@@ -1755,20 +1749,17 @@ MagickExport size_t ImportQuantumPixels(Image *image,
                   default:
                   case 0:
                   {
-                    q->red=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),
-                      image->depth,scale);
+                    q->red=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),range);
                     break;
                   }
                   case 1:
                   {
-                    q->green=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),
-                      image->depth,scale);
+                    q->green=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),range);
                     break;
                   }
                   case 2:
                   {
-                    q->blue=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),
-                      image->depth,scale);
+                    q->blue=ScaleAnyToQuantum((QuantumAny) (pixel >> 4),range);
                     q++;
                     break;
                   }
@@ -1784,11 +1775,11 @@ MagickExport size_t ImportQuantumPixels(Image *image,
               for (x=0; x < (long) number_pixels; x++)
               {
                 p=PushQuantumLongPixel(&quantum_state,image->depth,p,&pixel);
-                q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+                q->red=ScaleAnyToQuantum(pixel,range);
                 p=PushQuantumLongPixel(&quantum_state,image->depth,p,&pixel);
-                q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+                q->green=ScaleAnyToQuantum(pixel,range);
                 p=PushQuantumLongPixel(&quantum_state,image->depth,p,&pixel);
-                q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+                q->blue=ScaleAnyToQuantum(pixel,range);
                 q++;
               }
               break;
@@ -1796,11 +1787,11 @@ MagickExport size_t ImportQuantumPixels(Image *image,
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->green=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->blue=ScaleAnyToQuantum(pixel,range);
             q++;
           }
           break;
@@ -1882,15 +1873,15 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         default:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->green=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->blue=ScaleAnyToQuantum(pixel,range);
             q++;
           }
           break;
@@ -2078,18 +2069,17 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         default:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->green=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->blue=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel,
-              image->depth,scale));
+            q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel,range));
             q++;
           }
           break;
@@ -2206,17 +2196,17 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         default:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->green=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->blue=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->opacity=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->opacity=ScaleAnyToQuantum(pixel,range);
             q++;
           }
           break;
@@ -2228,8 +2218,8 @@ MagickExport size_t ImportQuantumPixels(Image *image,
     {
       if (image->colorspace != CMYKColorspace)
         {
-          (void) ThrowMagickException(&image->exception,GetMagickModule(),
-            ImageError,"ColorSeparatedImageRequired","`%s'",image->filename);
+          (void) ThrowMagickException(exception,GetMagickModule(),ImageError,
+            "ColorSeparatedImageRequired","`%s'",image->filename);
           return(extent);
         }
       switch (quantum_info->depth)
@@ -2339,17 +2329,17 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         default:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->green=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->blue=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            indexes[x]=ScaleAnyToQuantum(pixel,image->depth,scale);
+            indexes[x]=ScaleAnyToQuantum(pixel,range);
             q++;
           }
           break;
@@ -2361,8 +2351,8 @@ MagickExport size_t ImportQuantumPixels(Image *image,
     {
       if (image->colorspace != CMYKColorspace)
         {
-          (void) ThrowMagickException(&image->exception,GetMagickModule(),
-            ImageError,"ColorSeparatedImageRequired","`%s'",image->filename);
+          (void) ThrowMagickException(exception,GetMagickModule(),ImageError,
+            "ColorSeparatedImageRequired","`%s'",image->filename);
           return(extent);
         }
       switch (quantum_info->depth)
@@ -2483,20 +2473,100 @@ MagickExport size_t ImportQuantumPixels(Image *image,
         }
         default:
         {
-          scale=GetQuantumScale(image->depth);
+          range=GetQuantumRange(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->red=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->red=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->green=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->green=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->blue=ScaleAnyToQuantum(pixel,image->depth,scale);
+            q->blue=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            indexes[x]=ScaleAnyToQuantum(pixel,image->depth,scale);
+            indexes[x]=ScaleAnyToQuantum(pixel,range);
             p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
-            q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel,
-              image->depth,scale));
+            q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel,range));
+            q++;
+          }
+          break;
+        }
+      }
+      break;
+    }
+    case CbYCrYQuantum:
+    {
+      switch (quantum_info->depth)
+      {
+        case 10:
+        {
+          Quantum
+            cbcr[4];
+
+          pixel=0;
+          if (quantum_info->pack == MagickFalse)
+            {
+              long
+                n;
+
+              register long
+                i;
+
+              unsigned long
+                quantum;
+
+              n=0;
+              quantum=0;
+              for (x=0; x < (long) number_pixels; x+=2)
+              {
+                for (i=0; i < 4; i++)
+                {
+                  switch (n % 3)
+                  {
+                    case 0:
+                    {
+                      p=PushLongPixel(endian,p,&pixel);
+                      quantum=(unsigned long) (ScaleShortToQuantum(
+                        (unsigned short) (((pixel >> 22) & 0x3ff) << 6)));
+                      break;
+                    }
+                    case 1:
+                    {
+                      quantum=(unsigned long) (ScaleShortToQuantum(
+                        (unsigned short) (((pixel >> 12) & 0x3ff) << 6)));
+                      break;
+                    }
+                    case 2:
+                    {
+                      quantum=(unsigned long) (ScaleShortToQuantum(
+                        (unsigned short) (((pixel >> 2) & 0x3ff) << 6)));
+                      break;
+                    }
+                  }
+                  cbcr[i]=(Quantum) (quantum);
+                  n++;
+                }
+                p+=quantum_info->pad;
+                q->red=cbcr[1];
+                q->green=cbcr[0];
+                q->blue=cbcr[2];
+                q++;
+                q->red=cbcr[3];
+                q->green=cbcr[0];
+                q->blue=cbcr[2];
+                q++;
+              }
+              break;
+            }
+        }
+        default:
+        {
+          range=GetQuantumRange(image->depth);
+          for (x=0; x < (long) number_pixels; x++)
+          {
+            p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
+            q->red=ScaleAnyToQuantum(pixel,range);
+            p=PushQuantumPixel(&quantum_state,image->depth,p,&pixel);
+            q->green=ScaleAnyToQuantum(pixel,range);
             q++;
           }
           break;
@@ -2515,7 +2585,7 @@ MagickExport size_t ImportQuantumPixels(Image *image,
       /*
         Disassociate alpha.
       */
-      q=GetPixels(image);
+      q=GetAuthenticPixelQueue(image);
       for (x=0; x < (long) image->columns; x++)
       {
         alpha=QuantumScale*((MagickRealType) QuantumRange-q->opacity);
