@@ -9,7 +9,7 @@
 %               Q  QQ  U   U  A   A  N  NN    T    U   U  M   M               %
 %                QQQQ   UUU   A   A  N   N    T     UUU   M   M               %
 %                                                                             %
-%                 Methods to Acquire / Destroy Quantum Pixels                 %
+%             MagicCore Methods to Acquire / Destroy Quantum Pixels           %
 %                                                                             %
 %                             Software Design                                 %
 %                               John Cristy                                   %
@@ -70,6 +70,12 @@
 */
 #define QuantumSignature  0xab
 
+/*
+  Forward declarations.
+*/
+static void
+  DestroyQuantumPixels(QuantumInfo *);
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -106,6 +112,9 @@ static inline unsigned long MagickMax(const unsigned long x,
 MagickExport QuantumInfo *AcquireQuantumInfo(const ImageInfo *image_info,
   Image *image)
 {
+  MagickBooleanType
+    status;
+
   QuantumInfo
     *quantum_info;
 
@@ -114,8 +123,11 @@ MagickExport QuantumInfo *AcquireQuantumInfo(const ImageInfo *image_info,
     ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   quantum_info->signature=MagickSignature;
   GetQuantumInfo(image_info,quantum_info);
-  if (image != (const Image *) NULL)
-    (void) SetQuantumDepth(image,image->depth,quantum_info);
+  if (image == (const Image *) NULL)
+    return(quantum_info);
+  status=SetQuantumDepth(image,quantum_info,image->depth);
+  if (status == MagickFalse)
+    quantum_info=DestroyQuantumInfo(quantum_info);
   return(quantum_info);
 }
 
@@ -124,6 +136,58 @@ MagickExport QuantumInfo *AcquireQuantumInfo(const ImageInfo *image_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
++   A c q u i r e Q u a n t u m P i x e l s                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  AcquireQuantumPixels() allocates the unsigned char structure.
+%
+%  The format of the AcquireQuantumPixels method is:
+%
+%      MagickBooleanType AcquireQuantumPixels(QuantumInfo *quantum_info,
+%        const size_t extent)
+%
+%  A description of each parameter follows:
+%
+%    o quantum_info: the quantum info.
+%
+%    o extent: the quantum info.
+%
+*/
+static MagickBooleanType AcquireQuantumPixels(QuantumInfo *quantum_info,
+  const size_t extent)
+{
+  register long
+    i;
+
+  assert(quantum_info != (QuantumInfo *) NULL);
+  assert(quantum_info->signature == MagickSignature);
+  quantum_info->number_threads=GetPixelCacheMaximumThreads();
+  quantum_info->pixels=(unsigned char **) AcquireQuantumMemory(
+    quantum_info->number_threads,sizeof(*quantum_info->pixels));
+  if (quantum_info->pixels == (unsigned char **) NULL)
+    return(MagickFalse);
+  quantum_info->extent=extent;
+  (void) ResetMagickMemory(quantum_info->pixels,0,
+    sizeof(*quantum_info->pixels));
+  for (i=0; i < (long) quantum_info->number_threads; i++)
+  {
+    quantum_info->pixels[i]=(unsigned char *) AcquireQuantumMemory(extent+1,
+      sizeof(**quantum_info->pixels));
+  	if (quantum_info->pixels[i] == (unsigned char *) NULL)
+      return(MagickFalse);
+    quantum_info->pixels[i][extent]=QuantumSignature;
+  }
+  return(MagickTrue);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   D e s t r o y Q u a n t u m I n f o                                       %
 %                                                                             %
 %                                                                             %
@@ -139,19 +203,15 @@ MagickExport QuantumInfo *AcquireQuantumInfo(const ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o quantum_info: the quantum_info info.
+%    o quantum_info: the quantum info.
 %
 */
 MagickExport QuantumInfo *DestroyQuantumInfo(QuantumInfo *quantum_info)
 {
   assert(quantum_info != (QuantumInfo *) NULL);
   assert(quantum_info->signature == MagickSignature);
-  if (quantum_info->pixels != (unsigned char *) NULL)
-    {
-      assert(quantum_info->pixels[quantum_info->extent] == QuantumSignature);
-      quantum_info->pixels=(unsigned char *) RelinquishMagickMemory(
-        quantum_info->pixels);
-    }
+  if (quantum_info->pixels != (unsigned char **) NULL)
+    DestroyQuantumPixels(quantum_info);
   if (quantum_info->semaphore != (SemaphoreInfo *) NULL)
     DestroySemaphoreInfo(&quantum_info->semaphore);
   quantum_info->signature=(~MagickSignature);
@@ -164,6 +224,46 @@ MagickExport QuantumInfo *DestroyQuantumInfo(QuantumInfo *quantum_info)
 %                                                                             %
 %                                                                             %
 %                                                                             %
++   D e s t r o y Q u a n t u m P i x e l s                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  DestroyQuantumPixels() destroys the quantum pixels.
+%
+%  The format of the DestroyQuantumPixels() method is:
+%
+%      void DestroyQuantumPixels(QuantumInfo *quantum_info)
+%
+%  A description of each parameter follows:
+%
+%    o quantum_info: the quantum info.
+%
+*/
+static void DestroyQuantumPixels(QuantumInfo *quantum_info)
+{
+  register long
+    i;
+
+  assert(quantum_info != (QuantumInfo *) NULL);
+  assert(quantum_info->signature == MagickSignature);
+  assert(quantum_info->pixels != (unsigned char **) NULL);
+  for (i=0; i < (long) quantum_info->number_threads; i++)
+  {
+    assert(quantum_info->pixels[i][quantum_info->extent] == QuantumSignature);
+    quantum_info->pixels[i]=(unsigned char *) RelinquishMagickMemory(
+      quantum_info->pixels[i]);
+  }
+  quantum_info->pixels=(unsigned char **) RelinquishMagickMemory(
+    quantum_info->pixels);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   G e t Q u a n t u m E x t e n t                                           %
 %                                                                             %
 %                                                                             %
@@ -190,9 +290,6 @@ MagickExport QuantumInfo *DestroyQuantumInfo(QuantumInfo *quantum_info)
 MagickExport size_t GetQuantumExtent(const Image *image,
   const QuantumInfo *quantum_info,const QuantumType quantum_type)
 {
-  MagickSizeType
-    number_pixels;
-
   size_t
     packet_size;
 
@@ -210,10 +307,9 @@ MagickExport size_t GetQuantumExtent(const Image *image,
     case CMYKAQuantum: packet_size=5; break;
     default: break;
   }
-  number_pixels=GetPixelCacheExtent(image);
   if (quantum_info->pack == MagickFalse)
-    return((size_t) (packet_size*number_pixels*((image->depth+7)/8)));
-  return((size_t) ((packet_size*number_pixels*image->depth+7)/8));
+    return((size_t) (packet_size*image->columns*((image->depth+7)/8)));
+  return((size_t) ((packet_size*image->columns*image->depth+7)/8));
 }
 
 /*
@@ -252,6 +348,7 @@ MagickExport void GetQuantumInfo(const ImageInfo *image_info,
   quantum_info->maximum=1.0;
   quantum_info->scale=QuantumRange;
   quantum_info->pack=MagickTrue;
+  quantum_info->semaphore=AllocateSemaphoreInfo();
   quantum_info->signature=MagickSignature;
   if (image_info == (const ImageInfo *) NULL)
     return;
@@ -310,9 +407,13 @@ MagickExport void GetQuantumInfo(const ImageInfo *image_info,
 */
 MagickExport unsigned char *GetQuantumPixels(const QuantumInfo *quantum_info)
 {
+  long
+    id;
+
   assert(quantum_info != (QuantumInfo *) NULL);
   assert(quantum_info->signature == MagickSignature);
-  return(quantum_info->pixels);
+  id=GetPixelCacheThreadId();
+  return(quantum_info->pixels[id]);
 }
 
 /*
@@ -386,18 +487,18 @@ MagickExport QuantumType GetQuantumType(Image *image,ExceptionInfo *exception)
 %
 %  The format of the SetQuantumAlphaType method is:
 %
-%      void SetQuantumAlphaType(const QuantumAlphaType type,
-%        QuantumInfo *quantum_info)
+%      void SetQuantumAlphaType(QuantumInfo *quantum_info,
+%        const QuantumAlphaType type)
 %
 %  A description of each parameter follows:
 %
+%    o quantum_info: the quantum info.
+%
 %    o type: the alpha type (e.g. associate).
 %
-%    o quantum_info: the quantum_info info.
-%
 */
-MagickExport void SetQuantumAlphaType(const QuantumAlphaType type,
-  QuantumInfo *quantum_info)
+MagickExport void SetQuantumAlphaType(QuantumInfo *quantum_info,
+  const QuantumAlphaType type)
 {
   assert(quantum_info != (QuantumInfo *) NULL);
   assert(quantum_info->signature == MagickSignature);
@@ -419,21 +520,24 @@ MagickExport void SetQuantumAlphaType(const QuantumAlphaType type,
 %
 %  The format of the SetQuantumDepth method is:
 %
-%      unsigned char *SetQuantumDepth(const Image *image,
-%        const unsigned long depth,QuantumInfo *quantum_info)
+%      MagickBooleanType SetQuantumDepth(const Image *image,
+%        QuantumInfo *quantum_info,const unsigned long depth)
 %
 %  A description of each parameter follows:
 %
 %    o image: the image.
 %
+%    o quantum_info: the quantum info.
+%
 %    o depth: the quantum depth.
 %
-%    o quantum_info: the quantum_info info.
-%
 */
-MagickExport unsigned char *SetQuantumDepth(const Image *image,
-  const unsigned long depth,QuantumInfo *quantum_info)
+MagickExport MagickBooleanType SetQuantumDepth(const Image *image,
+  QuantumInfo *quantum_info,const unsigned long depth)
 {
+  MagickBooleanType
+    status;
+
   /*
     Allocate the quantum pixel buffer.
   */
@@ -451,22 +555,11 @@ MagickExport unsigned char *SetQuantumDepth(const Image *image,
       else
         quantum_info->depth=32;
     }
-  if (quantum_info->pixels != (unsigned char *) NULL)
-    {
-      assert(quantum_info->pixels[quantum_info->extent] == QuantumSignature);
-      quantum_info->pixels=(unsigned char *) RelinquishMagickMemory(
-        quantum_info->pixels);
-    }
-  quantum_info->pixels=(unsigned char *) AcquireQuantumMemory(
-    (quantum_info->pad+5)*image->columns+1,((quantum_info->depth+7)/8)*
-    sizeof(*quantum_info->pixels));
-  if (quantum_info->pixels == (unsigned char *) NULL)
-    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
-  quantum_info->extent=(quantum_info->pad+5)*image->columns*
-    ((quantum_info->depth+7)/8);
-  (void) ResetMagickMemory(quantum_info->pixels,0,quantum_info->extent);
-  quantum_info->pixels[quantum_info->extent]=QuantumSignature;
-  return(quantum_info->pixels);
+  if (quantum_info->pixels != (unsigned char **) NULL)
+    DestroyQuantumPixels(quantum_info);
+  status=AcquireQuantumPixels(quantum_info,(quantum_info->pad+5)*image->columns*
+    ((quantum_info->depth+7)/8));
+  return(status);
 }
 
 /*
@@ -484,20 +577,20 @@ MagickExport unsigned char *SetQuantumDepth(const Image *image,
 %
 %  The format of the SetQuantumFormat method is:
 %
-%      unsigned char *SetQuantumFormat(const Image *image,
-%        const QuantumFormatType format,QuantumInfo *quantum_info)
+%      MagickBooleanType SetQuantumFormat(const Image *image,
+%        QuantumInfo *quantum_info,const QuantumFormatType format)
 %
 %  A description of each parameter follows:
 %
 %    o image: the image.
 %
+%    o quantum_info: the quantum info.
+%
 %    o format: the quantum format.
 %
-%    o quantum_info: the quantum_info info.
-%
 */
-MagickExport unsigned char *SetQuantumFormat(const Image *image,
-  const QuantumFormatType format,QuantumInfo *quantum_info)
+MagickExport MagickBooleanType SetQuantumFormat(const Image *image,
+  QuantumInfo *quantum_info,const QuantumFormatType format)
 {
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
@@ -506,7 +599,7 @@ MagickExport unsigned char *SetQuantumFormat(const Image *image,
   assert(quantum_info != (QuantumInfo *) NULL);
   assert(quantum_info->signature == MagickSignature);
   quantum_info->format=format;
-  return(SetQuantumDepth(image,quantum_info->depth,quantum_info));
+  return(SetQuantumDepth(image,quantum_info,quantum_info->depth));
 }
 
 /*
@@ -581,6 +674,40 @@ MagickExport void SetQuantumImageType(Image *image,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   S e t Q u a n t u m P a c k                                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SetQuantumPack() sets the quantum pack flag.
+%
+%  The format of the SetQuantumPack method is:
+%
+%      void SetQuantumPack(QuantumInfo *quantum_info,
+%        const MagickBooleanType pack)
+%
+%  A description of each parameter follows:
+%
+%    o quantum_info: the quantum info.
+%
+%    o pack: the pack flag.
+%
+*/
+MagickExport void SetQuantumPack(QuantumInfo *quantum_info,
+  const MagickBooleanType pack)
+{
+  assert(quantum_info != (QuantumInfo *) NULL);
+  assert(quantum_info->signature == MagickSignature);
+  quantum_info->pack=pack;
+}
+
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   S e t Q u a n t u m P a d                                                 %
 %                                                                             %
 %                                                                             %
@@ -591,20 +718,20 @@ MagickExport void SetQuantumImageType(Image *image,
 %
 %  The format of the SetQuantumPad method is:
 %
-%      unsigned char *SetQuantumPad(const Image *image,const unsigned long pad,
-%        QuantumInfo *quantum_info)
+%      MagickBooleanType SetQuantumPad(const Image *image,
+%        QuantumInfo *quantum_info,const unsigned long pad)
 %
 %  A description of each parameter follows:
 %
 %    o image: the image.
 %
+%    o quantum_info: the quantum info.
+%
 %    o pad: the quantum pad.
 %
-%    o quantum_info: the quantum_info info.
-%
 */
-MagickExport unsigned char *SetQuantumPad(const Image *image,
-  const unsigned long pad,QuantumInfo *quantum_info)
+MagickExport MagickBooleanType SetQuantumPad(const Image *image,
+  QuantumInfo *quantum_info,const unsigned long pad)
 {
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
@@ -613,5 +740,102 @@ MagickExport unsigned char *SetQuantumPad(const Image *image,
   assert(quantum_info != (QuantumInfo *) NULL);
   assert(quantum_info->signature == MagickSignature);
   quantum_info->pad=pad;
-  return(SetQuantumDepth(image,quantum_info->depth,quantum_info));
+  return(SetQuantumDepth(image,quantum_info,quantum_info->depth));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   S e t Q u a n t u m M i n I s W h i t e                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SetQuantumMinIsWhite() sets the quantum min-is-white flag.
+%
+%  The format of the SetQuantumMinIsWhite method is:
+%
+%      void SetQuantumMinIsWhite(QuantumInfo *quantum_info,
+%        const MagickBooleanType min_is_white)
+%
+%  A description of each parameter follows:
+%
+%    o quantum_info: the quantum info.
+%
+%    o min_is_white: the min-is-white flag.
+%
+*/
+MagickExport void SetQuantumMinIsWhite(QuantumInfo *quantum_info,
+  const MagickBooleanType min_is_white)
+{
+  assert(quantum_info != (QuantumInfo *) NULL);
+  assert(quantum_info->signature == MagickSignature);
+  quantum_info->min_is_white=min_is_white;
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   S e t Q u a n t u m Q u a n t u m                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SetQuantumQuantum() sets the quantum quantum.
+%
+%  The format of the SetQuantumQuantum method is:
+%
+%      void SetQuantumQuantum(QuantumInfo *quantum_info,
+%        const unsigned long quantum)
+%
+%  A description of each parameter follows:
+%
+%    o quantum_info: the quantum info.
+%
+%    o quantum: the quantum quantum.
+%
+*/
+MagickExport void SetQuantumQuantum(QuantumInfo *quantum_info,
+  const unsigned long quantum)
+{
+  assert(quantum_info != (QuantumInfo *) NULL);
+  assert(quantum_info->signature == MagickSignature);
+  quantum_info->quantum=quantum;
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   S e t Q u a n t u m S c a l e                                             %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SetQuantumScale() sets the quantum scale.
+%
+%  The format of the SetQuantumScale method is:
+%
+%      void SetQuantumScale(QuantumInfo *quantum_info,const double scale)
+%
+%  A description of each parameter follows:
+%
+%    o quantum_info: the quantum info.
+%
+%    o scale: the quantum scale.
+%
+*/
+MagickExport void SetQuantumScale(QuantumInfo *quantum_info,const double scale)
+{
+  assert(quantum_info != (QuantumInfo *) NULL);
+  assert(quantum_info->signature == MagickSignature);
+  quantum_info->scale=scale;
 }
