@@ -10,7 +10,7 @@
 %           R  R    EEEEE   SSSSS  A   A  M   M  P      LLLLL  EEEEE          %
 %                                                                             %
 %                                                                             %
-%                           Pixel Resampling Methods.                         %
+%                      MagickCore Pixel Resampling Methods                    %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
@@ -18,7 +18,7 @@
 %                                August 2007                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -113,12 +113,6 @@ struct _ResampleFilter
     signature;
 };
 
-/*
-  Forward declarations.
-*/
-static void
-  SetResampleFilter(ResampleFilter *,const FilterTypes,const double);
-
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -153,7 +147,7 @@ static void
 %        for (x=0; x < (long) image->columns; x++) {
 %          X= ....;   Y= ....;
 %          ScaleResampleFilter(resample_filter, ... scaling vectors ...);
-%          pixel=ResamplePixelColor(resample_filter,X,Y);
+%          (void) ResamplePixelColor(resample_filter,X,Y,&pixel);
 %          ... assign resampled pixel value ...
 %        }
 %      }
@@ -168,7 +162,7 @@ static void
 %
 %    o image: the image.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport ResampleFilter *AcquireResampleFilter(const Image *image,
@@ -246,11 +240,9 @@ MagickExport ResampleFilter *DestroyResampleFilter(
   if (resample_filter->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       resample_filter->image->filename);
-
   resample_filter->view=DestroyCacheView(resample_filter->view);
   resample_filter->image=DestroyImage(resample_filter->image);
   resample_filter->signature=(~MagickSignature);
-
   resample_filter=(ResampleFilter *) RelinquishMagickMemory(resample_filter);
   return(resample_filter);
 }
@@ -273,8 +265,9 @@ MagickExport ResampleFilter *DestroyResampleFilter(
 %
 %  The format of the InterpolateResampleFilter method is:
 %
-%      MagickPixelPacket InterpolateResampleFilter(ResampleInfo *resample_filter,
-%        const InterpolatePixelMethod method,const double x,const double y)
+%      MagickBooleanType InterpolateResampleFilter(
+%        ResampleInfo *resample_filter,const InterpolatePixelMethod method,
+%        const double x,const double y,MagickPixelPacket *pixel)
 %
 %  A description of each parameter follows:
 %
@@ -284,6 +277,8 @@ MagickExport ResampleFilter *DestroyResampleFilter(
 %
 %    o x,y: A double representing the current (x,y) position of the pixel.
 %
+%    o pixel: return the interpolated pixel here.
+%
 */
 
 static inline double MagickMax(const double x,const double y)
@@ -364,12 +359,12 @@ static inline long NearestNeighbor(MagickRealType x)
   return((long) (x-0.5));
 }
 
-static MagickPixelPacket InterpolateResampleFilter(
+static MagickBooleanType InterpolateResampleFilter(
   ResampleFilter *resample_filter,const InterpolatePixelMethod method,
-  const double x,const double y)
+  const double x,const double y,MagickPixelPacket *pixel)
 {
-  MagickPixelPacket
-    pixel;
+  MagickBooleanType
+    status;
 
   register const IndexPacket
     *indexes;
@@ -382,7 +377,7 @@ static MagickPixelPacket InterpolateResampleFilter(
 
   assert(resample_filter != (ResampleFilter *) NULL);
   assert(resample_filter->signature == MagickSignature);
-  GetMagickPixelPacket(resample_filter->image,&pixel);
+  status=MagickTrue;
   switch (method)
   {
     case AverageInterpolatePixel:
@@ -394,11 +389,14 @@ static MagickPixelPacket InterpolateResampleFilter(
         alpha[16],
         gamma;
 
-      p=AcquireCacheViewPixels(resample_filter->view,(long) floor(x)-1,(long)
+      p=GetCacheViewVirtualPixels(resample_filter->view,(long) floor(x)-1,(long)
         floor(y)-1,4,4,resample_filter->exception);
       if (p == (const PixelPacket *) NULL)
-        break;
-      indexes=AcquireCacheViewIndexes(resample_filter->view);
+        {
+          status=MagickFalse;
+          break;
+        }
+      indexes=GetCacheViewVirtualIndexQueue(resample_filter->view);
       for (i=0; i < 16L; i++)
       {
         GetMagickPixelPacket(resample_filter->image,pixels+i);
@@ -415,12 +413,12 @@ static MagickPixelPacket InterpolateResampleFilter(
           }
         gamma=alpha[i];
         gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-        pixel.red+=gamma*0.0625*pixels[i].red;
-        pixel.green+=gamma*0.0625*pixels[i].green;
-        pixel.blue+=gamma*0.0625*pixels[i].blue;
-        pixel.opacity+=0.0625*pixels[i].opacity;
+        pixel->red+=gamma*0.0625*pixels[i].red;
+        pixel->green+=gamma*0.0625*pixels[i].green;
+        pixel->blue+=gamma*0.0625*pixels[i].blue;
+        pixel->opacity+=0.0625*pixels[i].opacity;
         if (resample_filter->image->colorspace == CMYKColorspace)
-          pixel.index+=gamma*0.0625*pixels[i].index;
+          pixel->index+=gamma*0.0625*pixels[i].index;
         p++;
       }
       break;
@@ -437,11 +435,14 @@ static MagickPixelPacket InterpolateResampleFilter(
       PointInfo
         delta;
 
-      p=AcquireCacheViewPixels(resample_filter->view,(long) floor(x)-1,(long)
+      p=GetCacheViewVirtualPixels(resample_filter->view,(long) floor(x)-1,(long)
         floor(y)-1,4,4,resample_filter->exception);
       if (p == (const PixelPacket *) NULL)
-        break;
-      indexes=AcquireCacheViewIndexes(resample_filter->view);
+        {
+          status=MagickFalse;
+          break;
+        }
+      indexes=GetCacheViewVirtualIndexQueue(resample_filter->view);
       for (i=0; i < 16L; i++)
       {
         GetMagickPixelPacket(resample_filter->image,pixels+i);
@@ -462,63 +463,75 @@ static MagickPixelPacket InterpolateResampleFilter(
       for (i=0; i < 4L; i++)
         BicubicInterpolate(pixels+4*i,delta.x,u+i);
       delta.y=y-floor(y);
-      BicubicInterpolate(u,delta.y,&pixel);
+      BicubicInterpolate(u,delta.y,pixel);
       break;
     }
     case BilinearInterpolatePixel:
     default:
     {
       MagickPixelPacket
-        pixels[16];
+        pixels[4];
 
       MagickRealType
-        alpha[16],
+        alpha[4],
         gamma;
 
       PointInfo
-        delta;
+        delta,
+        epsilon;
 
-      p=AcquireCacheViewPixels(resample_filter->view,(long) floor(x),(long)
+      p=GetCacheViewVirtualPixels(resample_filter->view,(long) floor(x),(long)
         floor(y),2,2,resample_filter->exception);
       if (p == (const PixelPacket *) NULL)
-        break;
-      indexes=AcquireCacheViewIndexes(resample_filter->view);
+        {
+          status=MagickFalse;
+          break;
+        }
+      indexes=GetCacheViewVirtualIndexQueue(resample_filter->view);
       for (i=0; i < 4L; i++)
       {
-        GetMagickPixelPacket(resample_filter->image,pixels+i);
-        SetMagickPixelPacket(resample_filter->image,p,indexes+i,pixels+i);
+        pixels[i].red=(MagickRealType) p[i].red;
+        pixels[i].green=(MagickRealType) p[i].green;
+        pixels[i].blue=(MagickRealType) p[i].blue;
+        pixels[i].opacity=(MagickRealType) p[i].opacity;
         alpha[i]=1.0;
-        if (resample_filter->image->matte != MagickFalse)
-          {
-            alpha[i]=QuantumScale*((MagickRealType) QuantumRange-p->opacity);
-            pixels[i].red*=alpha[i];
-            pixels[i].green*=alpha[i];
-            pixels[i].blue*=alpha[i];
-            if (resample_filter->image->colorspace == CMYKColorspace)
-              pixels[i].index*=alpha[i];
-          }
-        p++;
       }
+      if (resample_filter->image->matte != MagickFalse)
+        for (i=0; i < 4L; i++)
+        {
+          alpha[i]=QuantumScale*((MagickRealType) QuantumRange-p[i].opacity);
+          pixels[i].red*=alpha[i];
+          pixels[i].green*=alpha[i];
+          pixels[i].blue*=alpha[i];
+        }
+      if (indexes != (IndexPacket *) NULL)
+        for (i=0; i < 4L; i++)
+        {
+          pixels[i].index=(MagickRealType) indexes[i];
+          if (resample_filter->image->colorspace == CMYKColorspace)
+            pixels[i].index*=alpha[i];
+        }
       delta.x=x-floor(x);
       delta.y=y-floor(y);
-      gamma=(((1.0-delta.y)*((1.0-delta.x)*alpha[0]+delta.x*alpha[1])+delta.y*
-        ((1.0-delta.x)*alpha[2]+delta.x*alpha[3])));
+      epsilon.x=1.0-delta.x;
+      epsilon.y=1.0-delta.y;
+      gamma=((epsilon.y*(epsilon.x*alpha[0]+delta.x*alpha[1])+delta.y*
+        (epsilon.x*alpha[2]+delta.x*alpha[3])));
       gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-      pixel.red=gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].red+delta.x*
-        pixels[1].red)+delta.y*((1.0-delta.x)*pixels[2].red+delta.x*
-        pixels[3].red));
-      pixel.green=gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].green+delta.x*
-        pixels[1].green)+delta.y*((1.0-delta.x)*pixels[2].green+
-        delta.x*pixels[3].green));
-      pixel.blue=gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].blue+delta.x*
-        pixels[1].blue)+delta.y*((1.0-delta.x)*pixels[2].blue+delta.x*
+      pixel->red=gamma*(epsilon.y*(epsilon.x*pixels[0].red+delta.x*
+        pixels[1].red)+delta.y*(epsilon.x*pixels[2].red+delta.x*pixels[3].red));
+      pixel->green=gamma*(epsilon.y*(epsilon.x*pixels[0].green+delta.x*
+        pixels[1].green)+delta.y*(epsilon.x*pixels[2].green+delta.x*
+        pixels[3].green));
+      pixel->blue=gamma*(epsilon.y*(epsilon.x*pixels[0].blue+delta.x*
+        pixels[1].blue)+delta.y*(epsilon.x*pixels[2].blue+delta.x*
         pixels[3].blue));
-      pixel.opacity=((1.0-delta.y)*((1.0-delta.x)*pixels[0].opacity+delta.x*
-        pixels[1].opacity)+delta.y*((1.0-delta.x)*pixels[2].opacity+delta.x*
+      pixel->opacity=(epsilon.y*(epsilon.x*pixels[0].opacity+delta.x*
+        pixels[1].opacity)+delta.y*(epsilon.x*pixels[2].opacity+delta.x*
         pixels[3].opacity));
       if (resample_filter->image->colorspace == CMYKColorspace)
-        pixel.index=gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].index+delta.x*
-          pixels[1].index)+delta.y*((1.0-delta.x)*pixels[2].index+delta.x*
+        pixel->index=gamma*(epsilon.y*(epsilon.x*pixels[0].index+delta.x*
+          pixels[1].index)+delta.y*(epsilon.x*pixels[2].index+delta.x*
           pixels[3].index));
       break;
     }
@@ -544,19 +557,23 @@ static MagickPixelPacket InterpolateResampleFilter(
       excerpt_image=ExcerptImage(resample_filter->image,&geometry,
         resample_filter->exception);
       if (excerpt_image == (Image *) NULL)
-        break;
+        {
+          status=MagickFalse;
+          break;
+        }
       filter_image=ResizeImage(excerpt_image,1,1,resample_filter->image->filter,
         resample_filter->image->blur,resample_filter->exception);
       excerpt_image=DestroyImage(excerpt_image);
       if (filter_image == (Image *) NULL)
         break;
       filter_view=AcquireCacheView(filter_image);
-      p=AcquireCacheViewPixels(filter_view,0,0,1,1,resample_filter->exception);
+      p=GetCacheViewVirtualPixels(filter_view,0,0,1,1,
+        resample_filter->exception);
       if (p != (const PixelPacket *) NULL)
         {
-          indexes=AcquireIndexes(filter_image);
+          indexes=GetVirtualIndexQueue(filter_image);
           GetMagickPixelPacket(resample_filter->image,pixels);
-          SetMagickPixelPacket(resample_filter->image,p,indexes,&pixel);
+          SetMagickPixelPacket(resample_filter->image,p,indexes,pixel);
         }
       filter_view=DestroyCacheView(filter_view);
       filter_image=DestroyImage(filter_image);
@@ -567,13 +584,16 @@ static MagickPixelPacket InterpolateResampleFilter(
       MagickPixelPacket
         pixels[1];
 
-      p=AcquireCacheViewPixels(resample_filter->view,(long) floor(x),(long)
+      p=GetCacheViewVirtualPixels(resample_filter->view,(long) floor(x),(long)
         floor(y),1,1,resample_filter->exception);
       if (p == (const PixelPacket *) NULL)
-        break;
-      indexes=AcquireCacheViewIndexes(resample_filter->view);
+        {
+          status=MagickFalse;
+          break;
+        }
+      indexes=GetCacheViewVirtualIndexQueue(resample_filter->view);
       GetMagickPixelPacket(resample_filter->image,pixels);
-      SetMagickPixelPacket(resample_filter->image,p,indexes,&pixel);
+      SetMagickPixelPacket(resample_filter->image,p,indexes,pixel);
       break;
     }
     case MeshInterpolatePixel:
@@ -589,11 +609,14 @@ static MagickPixelPacket InterpolateResampleFilter(
         delta,
         luminance;
 
-      p=AcquireCacheViewPixels(resample_filter->view,(long) floor(x),(long)
+      p=GetCacheViewVirtualPixels(resample_filter->view,(long) floor(x),(long)
         floor(y),2,2,resample_filter->exception);
       if (p == (const PixelPacket *) NULL)
-        break;
-      indexes=AcquireCacheViewIndexes(resample_filter->view);
+        {
+          status=MagickFalse;
+          break;
+        }
+      indexes=GetCacheViewVirtualIndexQueue(resample_filter->view);
       for (i=0; i < 4L; i++)
       {
         GetMagickPixelPacket(resample_filter->image,pixels+i);
@@ -627,16 +650,16 @@ static MagickPixelPacket InterpolateResampleFilter(
               delta.y=1.0-delta.y;
               gamma=MeshInterpolate(&delta,alpha[2],alpha[3],alpha[0]);
               gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-              pixel.red=gamma*MeshInterpolate(&delta,pixels[2].red,
+              pixel->red=gamma*MeshInterpolate(&delta,pixels[2].red,
                 pixels[3].red,pixels[0].red);
-              pixel.green=gamma*MeshInterpolate(&delta,pixels[2].green,
+              pixel->green=gamma*MeshInterpolate(&delta,pixels[2].green,
                 pixels[3].green,pixels[0].green);
-              pixel.blue=gamma*MeshInterpolate(&delta,pixels[2].blue,
+              pixel->blue=gamma*MeshInterpolate(&delta,pixels[2].blue,
                 pixels[3].blue,pixels[0].blue);
-              pixel.opacity=gamma*MeshInterpolate(&delta,pixels[2].opacity,
+              pixel->opacity=gamma*MeshInterpolate(&delta,pixels[2].opacity,
                 pixels[3].opacity,pixels[0].opacity);
               if (resample_filter->image->colorspace == CMYKColorspace)
-                pixel.index=gamma*MeshInterpolate(&delta,pixels[2].index,
+                pixel->index=gamma*MeshInterpolate(&delta,pixels[2].index,
                   pixels[3].index,pixels[0].index);
             }
           else
@@ -647,16 +670,16 @@ static MagickPixelPacket InterpolateResampleFilter(
               delta.x=1.0-delta.x;
               gamma=MeshInterpolate(&delta,alpha[1],alpha[0],alpha[3]);
               gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-              pixel.red=gamma*MeshInterpolate(&delta,pixels[1].red,
+              pixel->red=gamma*MeshInterpolate(&delta,pixels[1].red,
                 pixels[0].red,pixels[3].red);
-              pixel.green=gamma*MeshInterpolate(&delta,pixels[1].green,
+              pixel->green=gamma*MeshInterpolate(&delta,pixels[1].green,
                 pixels[0].green,pixels[3].green);
-              pixel.blue=gamma*MeshInterpolate(&delta,pixels[1].blue,
+              pixel->blue=gamma*MeshInterpolate(&delta,pixels[1].blue,
                 pixels[0].blue,pixels[3].blue);
-              pixel.opacity=gamma*MeshInterpolate(&delta,pixels[1].opacity,
+              pixel->opacity=gamma*MeshInterpolate(&delta,pixels[1].opacity,
                 pixels[0].opacity,pixels[3].opacity);
               if (resample_filter->image->colorspace == CMYKColorspace)
-                pixel.index=gamma*MeshInterpolate(&delta,pixels[1].index,
+                pixel->index=gamma*MeshInterpolate(&delta,pixels[1].index,
                   pixels[0].index,pixels[3].index);
             }
         }
@@ -672,16 +695,16 @@ static MagickPixelPacket InterpolateResampleFilter(
               */
               gamma=MeshInterpolate(&delta,alpha[0],alpha[1],alpha[2]);
               gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-              pixel.red=gamma*MeshInterpolate(&delta,pixels[0].red,
+              pixel->red=gamma*MeshInterpolate(&delta,pixels[0].red,
                 pixels[1].red,pixels[2].red);
-              pixel.green=gamma*MeshInterpolate(&delta,pixels[0].green,
+              pixel->green=gamma*MeshInterpolate(&delta,pixels[0].green,
                 pixels[1].green,pixels[2].green);
-              pixel.blue=gamma*MeshInterpolate(&delta,pixels[0].blue,
+              pixel->blue=gamma*MeshInterpolate(&delta,pixels[0].blue,
                 pixels[1].blue,pixels[2].blue);
-              pixel.opacity=gamma*MeshInterpolate(&delta,pixels[0].opacity,
+              pixel->opacity=gamma*MeshInterpolate(&delta,pixels[0].opacity,
                 pixels[1].opacity,pixels[2].opacity);
               if (resample_filter->image->colorspace == CMYKColorspace)
-                pixel.index=gamma*MeshInterpolate(&delta,pixels[0].index,
+                pixel->index=gamma*MeshInterpolate(&delta,pixels[0].index,
                   pixels[1].index,pixels[2].index);
             }
           else
@@ -693,16 +716,16 @@ static MagickPixelPacket InterpolateResampleFilter(
               delta.y=1.0-delta.y;
               gamma=MeshInterpolate(&delta,alpha[3],alpha[2],alpha[1]);
               gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-              pixel.red=gamma*MeshInterpolate(&delta,pixels[3].red,
+              pixel->red=gamma*MeshInterpolate(&delta,pixels[3].red,
                 pixels[2].red,pixels[1].red);
-              pixel.green=gamma*MeshInterpolate(&delta,pixels[3].green,
+              pixel->green=gamma*MeshInterpolate(&delta,pixels[3].green,
                 pixels[2].green,pixels[1].green);
-              pixel.blue=gamma*MeshInterpolate(&delta,pixels[3].blue,
+              pixel->blue=gamma*MeshInterpolate(&delta,pixels[3].blue,
                 pixels[2].blue,pixels[1].blue);
-              pixel.opacity=gamma*MeshInterpolate(&delta,pixels[3].opacity,
+              pixel->opacity=gamma*MeshInterpolate(&delta,pixels[3].opacity,
                 pixels[2].opacity,pixels[1].opacity);
               if (resample_filter->image->colorspace == CMYKColorspace)
-                pixel.index=gamma*MeshInterpolate(&delta,pixels[3].index,
+                pixel->index=gamma*MeshInterpolate(&delta,pixels[3].index,
                   pixels[2].index,pixels[1].index);
             }
         }
@@ -713,13 +736,16 @@ static MagickPixelPacket InterpolateResampleFilter(
       MagickPixelPacket
         pixels[1];
 
-      p=AcquireCacheViewPixels(resample_filter->view,NearestNeighbor(x),
+      p=GetCacheViewVirtualPixels(resample_filter->view,NearestNeighbor(x),
         NearestNeighbor(y),1,1,resample_filter->exception);
       if (p == (const PixelPacket *) NULL)
-        break;
-      indexes=AcquireCacheViewIndexes(resample_filter->view);
+        {
+          status=MagickFalse;
+          break;
+        }
+      indexes=GetCacheViewVirtualIndexQueue(resample_filter->view);
       GetMagickPixelPacket(resample_filter->image,pixels);
-      SetMagickPixelPacket(resample_filter->image,p,indexes,&pixel);
+      SetMagickPixelPacket(resample_filter->image,p,indexes,pixel);
       break;
     }
     case SplineInterpolatePixel:
@@ -740,11 +766,14 @@ static MagickPixelPacket InterpolateResampleFilter(
       PointInfo
         delta;
 
-      p=AcquireCacheViewPixels(resample_filter->view,(long) floor(x)-1,(long)
+      p=GetCacheViewVirtualPixels(resample_filter->view,(long) floor(x)-1,(long)
         floor(y)-1,4,4,resample_filter->exception);
       if (p == (const PixelPacket *) NULL)
-        break;
-      indexes=AcquireCacheViewIndexes(resample_filter->view);
+        {
+          status=MagickFalse;
+          break;
+        }
+      indexes=GetCacheViewVirtualIndexQueue(resample_filter->view);
       n=0;
       delta.x=x-floor(x);
       delta.y=y-floor(y);
@@ -768,13 +797,13 @@ static MagickPixelPacket InterpolateResampleFilter(
           dx=CubicWeightingFunction(delta.x-(MagickRealType) j);
           gamma=alpha[n];
           gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-          pixel.red+=gamma*dx*dy*pixels[n].red;
-          pixel.green+=gamma*dx*dy*pixels[n].green;
-          pixel.blue+=gamma*dx*dy*pixels[n].blue;
+          pixel->red+=gamma*dx*dy*pixels[n].red;
+          pixel->green+=gamma*dx*dy*pixels[n].green;
+          pixel->blue+=gamma*dx*dy*pixels[n].blue;
           if (resample_filter->image->matte != MagickFalse)
-            pixel.opacity+=dx*dy*pixels[n].opacity;
+            pixel->opacity+=dx*dy*pixels[n].opacity;
           if (resample_filter->image->colorspace == CMYKColorspace)
-            pixel.index+=gamma*dx*dy*pixels[n].index;
+            pixel->index+=gamma*dx*dy*pixels[n].index;
           n++;
           p++;
         }
@@ -782,7 +811,7 @@ static MagickPixelPacket InterpolateResampleFilter(
       break;
     }
   }
-  return(pixel);
+  return(status);
 }
 
 /*
@@ -797,27 +826,32 @@ static MagickPixelPacket InterpolateResampleFilter(
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  ResamplePixelColor() samples the pixel values surrounding the location
-%  given using a Elliptical Weighted Average, at the scale previously
-%  calculated, and in the most efficent manner posible for the
-%  VirtualPixelMethod also previously set.
+%  given using an elliptical weighted average, at the scale previously
+%  calculated, and in the most efficent manner possible for the
+%  VirtualPixelMethod setting.
 %
 %  The format of the ResamplePixelColor method is:
 %
-%     MagickPixelPacket ResamplePixelColor(ResampleFilter *resample_filter,
-%       const double u0,const double v0 )
+%     MagickBooleanType ResamplePixelColor(ResampleFilter *resample_filter,
+%       const double u0,const double v0,MagickPixelPacket *pixel)
 %
 %  A description of each parameter follows:
 %
-%    o resample_filter: the Resampling Information Structure
+%    o resample_filter: the resample filter.
 %
 %    o u0,v0: A double representing the center of the area to resample,
-%             The distortion transformed transformed x,y coordinate.
+%        The distortion transformed transformed x,y coordinate.
+%
+%    o pixel: the resampled pixel is returned here.
 %
 */
-MagickExport MagickPixelPacket ResamplePixelColor(
-  ResampleFilter *resample_filter,const double u0,const double v0)
+MagickExport MagickBooleanType ResamplePixelColor(
+  ResampleFilter *resample_filter,const double u0,const double v0,
+  MagickPixelPacket *pixel)
 {
-  MagickPixelPacket pixel;
+  MagickBooleanType
+    status;
+
   long u,v, uw,v1,v2, hit;
   double u1;
   double U,V,Q,DQ,DDQ;
@@ -825,16 +859,15 @@ MagickExport MagickPixelPacket ResamplePixelColor(
   register double weight;
   register const PixelPacket *pixels;
   register const IndexPacket *indexes;
-
   assert(resample_filter != (ResampleFilter *) NULL);
   assert(resample_filter->signature == MagickSignature);
 
-  GetMagickPixelPacket(resample_filter->image,&pixel);
-
+  status=MagickTrue;
+  GetMagickPixelPacket(resample_filter->image,pixel);
   if ( resample_filter->do_interpolate ) {
-    pixel = InterpolateResampleFilter(resample_filter,
-         resample_filter->interpolate,u0,v0);
-    return(pixel);
+    status=InterpolateResampleFilter(resample_filter,
+      resample_filter->interpolate,u0,v0,pixel);
+    return(status);
   }
 
   /*
@@ -902,8 +935,9 @@ MagickExport MagickPixelPacket ResamplePixelColor(
   }
   if ( hit ) {
     /* whole area is a solid color -- just return that color */
-    pixel = InterpolateResampleFilter(resample_filter,IntegerInterpolatePixel,u0,v0);
-    return(pixel);
+    status=InterpolateResampleFilter(resample_filter,IntegerInterpolatePixel,
+      u0,v0,pixel);
+    return(status);
   }
 
   /*
@@ -919,8 +953,9 @@ MagickExport MagickPixelPacket ResamplePixelColor(
         case WhiteVirtualPixelMethod
         case MaskVirtualPixelMethod:
         case MaskVirtualPixelMethod:
-          pixel = InterpolateResampleFilter(resample_filter->image,resample_filter->view,
-                IntegerInterpolatePixel, u0,v0, resample_filter->exception);
+          status=InterpolateResampleFilter(resample_filter->image,
+            resample_filter->view,IntegerInterpolatePixel,u0,v0,
+            &pixel);
           break;
       */
       case UndefinedVirtualPixelMethod:
@@ -929,8 +964,8 @@ MagickExport MagickPixelPacket ResamplePixelColor(
         /* We need an average edge pixel!
            How should I calculate an average edge color?
            Just return an averaged neighbourhood, seems to work well */
-        pixel = InterpolateResampleFilter(resample_filter,AverageInterpolatePixel,
-          u0,v0);
+        status=InterpolateResampleFilter(resample_filter,
+          AverageInterpolatePixel,u0,v0,pixel);
         break;
       case TileVirtualPixelMethod:
       case MirrorVirtualPixelMethod:
@@ -951,25 +986,29 @@ MagickExport MagickPixelPacket ResamplePixelColor(
           average_image=ResizeImage(resample_filter->image,1,1,BoxFilter,1.0,
            resample_filter->exception);
           if (average_image == (Image *) NULL)
-            return(resample_filter->average_pixel);
+            {
+              *pixel=resample_filter->average_pixel;
+              break;
+            }
           average_view=AcquireCacheView(average_image);
-          pixels=(PixelPacket *)AcquireCacheViewPixels(average_view,0,0,1,1,
+          pixels=(PixelPacket *)GetCacheViewVirtualPixels(average_view,0,0,1,1,
             resample_filter->exception);
           if (pixels == (const PixelPacket *) NULL) {
             average_view=DestroyCacheView(average_view);
             average_image=DestroyImage(average_image);
-            return(resample_filter->average_pixel);
+            *pixel=resample_filter->average_pixel;
+            break;
           }
-          indexes=(IndexPacket *) GetCacheViewIndexes(average_view);
+          indexes=(IndexPacket *) GetCacheViewAuthenticIndexQueue(average_view);
           SetMagickPixelPacket(resample_filter->image,pixels,indexes,
             &(resample_filter->average_pixel));
           average_view=DestroyCacheView(average_view);
           average_image=DestroyImage(average_image);
         }
-        pixel = resample_filter->average_pixel;
+        *pixel=resample_filter->average_pixel;
         break;
     }
-    return(pixel);
+    return(status);
   }
 
   /*
@@ -978,9 +1017,9 @@ MagickExport MagickPixelPacket ResamplePixelColor(
   hit = 0;
   divisor_c = 0.0;
   divisor_m = 0.0;
-  pixel.red = pixel.green = pixel.blue = 0.0;
-  if (resample_filter->image->matte != MagickFalse) pixel.opacity = 0.0;
-  if (resample_filter->image->colorspace == CMYKColorspace) pixel.index = 0.0;
+  pixel->red = pixel->green = pixel->blue = 0.0;
+  if (resample_filter->image->matte != MagickFalse) pixel->opacity = 0.0;
+  if (resample_filter->image->colorspace == CMYKColorspace) pixel->index = 0.0;
 
   /*
     Determine the parellelogram bounding box fitted to the ellipse
@@ -1010,11 +1049,11 @@ MagickExport MagickPixelPacket ResamplePixelColor(
     DQ = resample_filter->A*(2.0*U+1) + resample_filter->B*V;
 
     /* get the scanline of pixels for this v */
-    pixels=AcquireCacheViewPixels(resample_filter->view,u,v,(unsigned long) uw,
+    pixels=GetCacheViewVirtualPixels(resample_filter->view,u,v,(unsigned long) uw,
       1,resample_filter->exception);
     if (pixels == (const PixelPacket *) NULL)
-      return(pixel);
-    indexes=AcquireCacheViewIndexes(resample_filter->view);
+      return(MagickFalse);
+    indexes=GetCacheViewVirtualIndexQueue(resample_filter->view);
 
     /* count up the weighted pixel colors */
     for( u=0; u<uw; u++ ) {
@@ -1022,16 +1061,16 @@ MagickExport MagickPixelPacket ResamplePixelColor(
       if ( Q < (double)WLUT_WIDTH ) {
         weight = resample_filter->filter_lut[(int)Q];
 
-        pixel.opacity  += weight*pixels->opacity;
+        pixel->opacity  += weight*pixels->opacity;
         divisor_m += weight;
 
         if (resample_filter->image->matte != MagickFalse)
           weight *= QuantumScale*((MagickRealType)(QuantumRange-pixels->opacity));
-        pixel.red   += weight*pixels->red;
-        pixel.green += weight*pixels->green;
-        pixel.blue  += weight*pixels->blue;
+        pixel->red   += weight*pixels->red;
+        pixel->green += weight*pixels->green;
+        pixel->blue  += weight*pixels->blue;
         if (resample_filter->image->colorspace == CMYKColorspace)
-          pixel.index += weight*(*indexes);
+          pixel->index += weight*(*indexes);
         divisor_c += weight;
 
         hit++;
@@ -1048,24 +1087,23 @@ MagickExport MagickPixelPacket ResamplePixelColor(
   */
   if ( hit < 4 || divisor_c < 1.0 ) {
     /* not enough pixels in resampling, resort to direct interpolation */
-    pixel = InterpolateResampleFilter(resample_filter,
-      resample_filter->interpolate,u0,v0);
-    return pixel;
+    status=InterpolateResampleFilter(resample_filter,
+      resample_filter->interpolate,u0,v0,pixel);
+    return status;
   }
 
   /*
     Finialize results of resampling
   */
   divisor_m = 1.0/divisor_m;
-  pixel.opacity = (MagickRealType) RoundToQuantum(divisor_m*pixel.opacity);
+  pixel->opacity = (MagickRealType) RoundToQuantum(divisor_m*pixel->opacity);
   divisor_c = 1.0/divisor_c;
-  pixel.red   = (MagickRealType) RoundToQuantum(divisor_c*pixel.red);
-  pixel.green = (MagickRealType) RoundToQuantum(divisor_c*pixel.green);
-  pixel.blue  = (MagickRealType) RoundToQuantum(divisor_c*pixel.blue);
+  pixel->red   = (MagickRealType) RoundToQuantum(divisor_c*pixel->red);
+  pixel->green = (MagickRealType) RoundToQuantum(divisor_c*pixel->green);
+  pixel->blue  = (MagickRealType) RoundToQuantum(divisor_c*pixel->blue);
   if (resample_filter->image->colorspace == CMYKColorspace)
-    pixel.index = (MagickRealType) RoundToQuantum(divisor_c*pixel.index);
-
-  return pixel;
+    pixel->index = (MagickRealType) RoundToQuantum(divisor_c*pixel->index);
+  return(MagickTrue);
 }
 
 /*
@@ -1236,8 +1274,6 @@ MagickExport void ScaleResampleFilter(ResampleFilter *resample_filter,
     resample_filter->C = C*scale;
     /* ..ple_filter->F = WLUT_WIDTH; -- hardcoded */
   }
-
-  return;
 }
 
 /*
@@ -1245,7 +1281,7 @@ MagickExport void ScaleResampleFilter(ResampleFilter *resample_filter,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-+   S e t R e s a m p l e F i l t e r                                         %
+%   S e t R e s a m p l e F i l t e r                                         %
 %                                                                             %
 %                                                                             %
 %                                                                             %
@@ -1273,7 +1309,7 @@ MagickExport void ScaleResampleFilter(ResampleFilter *resample_filter,
 %    o blur: filter blur factor (radial scaling) for elliptical weighting LUT
 %
 */
-static void SetResampleFilter(ResampleFilter *resample_filter,
+MagickExport void SetResampleFilter(ResampleFilter *resample_filter,
   const FilterTypes filter,const double blur)
 {
   register int
