@@ -10,14 +10,14 @@
 %           R  R    EEEEE   SSSSS   OOO    UUU   R  R    CCCC  EEEEE          %
 %                                                                             %
 %                                                                             %
-%                        Get/Set ImageMagick Resources.                       %
+%                        Get/Set MagickCore Resources                         %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                               September 2002                                %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -40,6 +40,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/cache.h"
 #include "magick/configure.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -714,7 +715,7 @@ MagickExport void InitializeMagickResources(void)
     limit=GetConfigureOption("MAGICK_THREAD_LIMIT");
   if (limit != (char *) NULL)
     {
-      SetCacheViewMaximumThreads((unsigned long) atol(limit));
+      SetPixelCacheMaximumThreads((unsigned long) atol(limit));
       limit=DestroyString(limit);
     }
 }
@@ -741,7 +742,7 @@ MagickExport void InitializeMagickResources(void)
 %
 %    o file:  An pointer to a FILE.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
