@@ -260,12 +260,12 @@ static MagickBooleanType Classify(Image *image,short **extrema,
     progress,
     y;
 
-  MagickBooleanType
-    status;
-
   MagickRealType
     *free_squares;
 
+  MagickStatusType
+    status;
+
   register long
     i;
 
@@ -395,7 +395,7 @@ static MagickBooleanType Classify(Image *image,short **extrema,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-        #pragma omp critical
+        #pragma omp critical (MagickCore_Classify)
 #endif
         proceed=SetImageProgress(image,SegmentImageTag,progress++,
           2*image->rows);
@@ -631,7 +631,7 @@ static MagickBooleanType Classify(Image *image,short **extrema,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-        #pragma omp critical
+        #pragma omp critical (MagickCore_Classify)
 #endif
         proceed=SetImageProgress(image,SegmentImageTag,progress++,
           2*image->rows);
