@@ -446,7 +446,7 @@ static inline ssize_t ReadRadonCell(const RadonInfo *radon_info,
 
 #if !defined(MAGICKCORE_HAVE_PPREAD)
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_ReadRadonCell)
 #endif
   {
     i=(-1);
@@ -490,7 +490,7 @@ static inline ssize_t WriteRadonCell(const RadonInfo *radon_info,
 
 #if !defined(MAGICKCORE_HAVE_PWRITE)
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_WriteRadonCell)
 #endif
   {
     if (MagickSeek(radon_info->file,offset,SEEK_SET) >= 0)
@@ -878,8 +878,7 @@ MagickExport Image *DeskewImage(const Image *image,const double threshold,
     *artifact;
 
   double
-    degrees,
-    sum;
+    degrees;
 
   Image
     *clone_image,
@@ -919,7 +918,6 @@ MagickExport Image *DeskewImage(const Image *image,const double threshold,
       ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
     }
   max_projection=0;
-  sum=0.0;
   skew=0;
   for (i=0; i < (long) (2*width-1); i++)
   {
@@ -928,7 +926,6 @@ MagickExport Image *DeskewImage(const Image *image,const double threshold,
         skew=i-(long) width+1;
         max_projection=projection[i];
       }
-    sum+=projection[i];
   }
   projection=(unsigned long *) RelinquishMagickMemory(projection);
   /*
@@ -1095,7 +1092,7 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
               proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_IntegralRotateImage)
 #endif
             proceed=SetImageProgress(image,RotateImageTag,progress++,
               image->rows);
@@ -1171,7 +1168,7 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
             register long
               x;
 
-            q=QueueCacheViewAuthenticPixels(rotate_view,
+            q=QueueCacheViewAuthenticPixels(rotate_view,(long) 
               rotate_image->columns-(tile_y+tile_height),y+tile_x,tile_height,
               1,exception);
             if (q == (PixelPacket *) NULL)
@@ -1210,7 +1207,7 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
               proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_IntegralRotateImage)
 #endif
             proceed=SetImageProgress(image,RotateImageTag,progress+=TileHeight,
               image->rows);
@@ -1282,7 +1279,7 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
               proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_IntegralRotateImage)
 #endif
             proceed=SetImageProgress(image,RotateImageTag,progress++,
               image->rows);
@@ -1400,7 +1397,7 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
               proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_IntegralRotateImage)
 #endif
             proceed=SetImageProgress(image,RotateImageTag,progress+=TileHeight,
               image->rows);
@@ -1677,7 +1674,7 @@ static MagickBooleanType XShearImage(Image *image,const MagickRealType degrees,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_XShearImage)
 #endif
         proceed=SetImageProgress(image,XShearImageTag,progress++,height);
         if (proceed == MagickFalse)
@@ -1897,7 +1894,7 @@ static MagickBooleanType YShearImage(Image *image,const MagickRealType degrees,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_YShearImage)
 #endif
         proceed=SetImageProgress(image,YShearImageTag,progress++,image->rows);
         if (proceed == MagickFalse)
@@ -2122,8 +2119,8 @@ MagickExport Image *ShearImage(const Image *image,const double x_shear,
   integral_image=CloneImage(image,0,0,MagickTrue,exception);
   if (integral_image == (Image *) NULL)
     ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
-  shear.x=(-tan(DegreesToRadians(x_shear)));
-  shear.y=(-tan(DegreesToRadians(y_shear)));
+  shear.x=(-tan(DegreesToRadians(fmod(x_shear,360.0))));
+  shear.y=tan(DegreesToRadians(fmod(y_shear,360.0)));
   if ((shear.x == 0.0) && (shear.y == 0.0))
     return(integral_image);
   if (SetImageStorageClass(integral_image,DirectClass) == MagickFalse)
