@@ -10,14 +10,14 @@
 %                  SSSSS    T    A   A    T    IIIII   CCCC                   %
 %                                                                             %
 %                                                                             %
-%                         ImageMagick Static Methods                          %
+%                          MagickCore Static Methods                          %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -77,7 +77,7 @@
 %
 %    o argv: A text array containing the command line arguments.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 #if defined(MAGICKCORE_MODULES_SUPPORT)
@@ -195,6 +195,7 @@ MagickExport void RegisterStaticModules(void)
   (void) RegisterHTMLImage();
   (void) RegisterICONImage();
   (void) RegisterINFOImage();
+  (void) RegisterINLINEImage();
   (void) RegisterIPLImage();
 #if defined(MAGICKCORE_JBIG_DELEGATE)
   (void) RegisterJBIGImage();
@@ -358,6 +359,7 @@ MagickExport void UnregisterStaticModules(void)
   UnregisterHTMLImage();
   UnregisterICONImage();
   UnregisterINFOImage();
+  UnregisterINLINEImage();
   UnregisterIPLImage();
 #if defined(MAGICKCORE_JBIG_DELEGATE)
   UnregisterJBIGImage();
