@@ -317,19 +317,19 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
             status;
 
           QuantumAny
-            scale;
+            range;
 
           status=0;
-          scale=GetQuantumScale(current_depth[id]);
+          range=GetQuantumRange(current_depth[id]);
           if ((channel & RedChannel) != 0)
             status|=p->red != ScaleAnyToQuantum(ScaleQuantumToAny(p->red,
-              current_depth[id],scale),current_depth[id],scale);
+              range),range);
           if ((channel & GreenChannel) != 0)
             status|=p->green != ScaleAnyToQuantum(ScaleQuantumToAny(p->green,
-              current_depth[id],scale),current_depth[id],scale);
+              range),range);
           if ((channel & BlueChannel) != 0)
             status|=p->blue != ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,
-              current_depth[id],scale),current_depth[id],scale);
+              range),range);
           if (status == 0)
             break;
           current_depth[id]++;
@@ -374,26 +374,26 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
           status;
 
         QuantumAny
-          scale;
+          range;
 
         status=0;
-        scale=GetQuantumScale(current_depth[id]);
+        range=GetQuantumRange(current_depth[id]);
         if ((channel & RedChannel) != 0)
-          status|=p->red != ScaleAnyToQuantum(ScaleQuantumToAny(p->red,
-            current_depth[id],scale),current_depth[id],scale);
+          status|=p->red != ScaleAnyToQuantum(ScaleQuantumToAny(p->red,range),
+            range);
         if ((channel & GreenChannel) != 0)
           status|=p->green != ScaleAnyToQuantum(ScaleQuantumToAny(p->green,
-            current_depth[id],scale),current_depth[id],scale);
+            range),range);
         if ((channel & BlueChannel) != 0)
-          status|=p->blue != ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,
-            current_depth[id],scale),current_depth[id],scale);
+          status|=p->blue != ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,range),
+            range);
         if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
           status|=p->opacity != ScaleAnyToQuantum(ScaleQuantumToAny(p->opacity,
-            current_depth[id],scale),current_depth[id],scale);
+            range),range);
         if (((channel & IndexChannel) != 0) &&
             (image->colorspace == CMYKColorspace))
           status|=indexes[x] != ScaleAnyToQuantum(ScaleQuantumToAny(indexes[x],
-            current_depth[id],scale),current_depth[id],scale);
+            range),range);
         if (status == 0)
           break;
         current_depth[id]++;
@@ -521,8 +521,6 @@ MagickExport MagickBooleanType GetImageChannelMean(const Image *image,
   const ChannelType channel,double *mean,double *standard_deviation,
   ExceptionInfo *exception)
 {
-#define PixelSquared(x)  ((x)*(x))
-
   double
     area;
 
@@ -598,6 +596,164 @@ MagickExport MagickBooleanType GetImageChannelMean(const Image *image,
   return(y == (long) image->rows ? MagickTrue : MagickFalse);
 }
 
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   G e t I m a g e C h a n n e l K u r t o s i s                             %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetImageChannelKurtosis() returns the kurtosis and skewness of one or more
+%  image channels.
+%
+%  The format of the GetImageChannelKurtosis method is:
+%
+%      MagickBooleanType GetImageChannelKurtosis(const Image *image,
+%        const ChannelType channel,double *kurtosis,double *skewness,
+%        ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o image: the image.
+%
+%    o channel: the channel.
+%
+%    o kurtosis: the kurtosis of the channel.
+%
+%    o skewness: the skewness of the channel.
+%
+%    o exception: return any errors or warnings in this structure.
+%
+*/
+
+MagickExport MagickBooleanType GetImageKurtosis(const Image *image,
+  double *kurtosis,double *skewness,ExceptionInfo *exception)
+{
+  MagickBooleanType
+    status;
+
+  status=GetImageChannelKurtosis(image,AllChannels,kurtosis,skewness,
+    exception);
+  return(status);
+}
+
+MagickExport MagickBooleanType GetImageChannelKurtosis(const Image *image,
+  const ChannelType channel,double *kurtosis,double *skewness,
+  ExceptionInfo *exception)
+{
+  double
+    area,
+    mean,
+    standard_deviation,
+    sum_squares,
+    sum_cubes,
+    sum_fourth_power;
+
+  long
+    y;
+
+  register const IndexPacket
+    *indexes;
+
+  register const PixelPacket
+    *p;
+
+  register long
+    x;
+
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  *kurtosis=0.0;
+  *skewness=0.0;
+  area=0.0;
+  mean=0.0;
+  standard_deviation=0.0;
+  sum_squares=0.0;
+  sum_cubes=0.0;
+  sum_fourth_power=0.0;
+  for (y=0; y < (long) image->rows; y++)
+  {
+    p=GetVirtualPixels(image,0,y,image->columns,1,exception);
+    if (p == (const PixelPacket *) NULL)
+      break;
+    indexes=GetVirtualIndexQueue(image);
+    for (x=0; x < (long) image->columns; x++)
+    {
+      if ((channel & RedChannel) != 0)
+        {
+          mean+=p->red;
+          sum_squares+=(double) p->red*p->red;
+          sum_cubes+=(double) p->red*p->red*p->red;
+          sum_fourth_power+=(double) p->red*p->red*p->red*p->red;
+          area++;
+        }
+      if ((channel & GreenChannel) != 0)
+        {
+          mean+=p->green;
+          sum_squares+=(double) p->green*p->green;
+          sum_cubes+=(double) p->green*p->green*p->green;
+          sum_fourth_power+=(double) p->green*p->green*p->green*p->green;
+          area++;
+        }
+      if ((channel & BlueChannel) != 0)
+        {
+          mean+=p->blue;
+          sum_squares+=(double) p->blue*p->blue;
+          sum_cubes+=(double) p->blue*p->blue*p->blue;
+          sum_fourth_power+=(double) p->blue*p->blue*p->blue*p->blue;
+          area++;
+        }
+      if ((channel & OpacityChannel) != 0)
+        {
+          mean+=p->opacity;
+          sum_squares+=(double) p->opacity*p->opacity;
+          sum_cubes+=(double) p->opacity*p->opacity*p->opacity;
+          sum_fourth_power+=(double) p->opacity*p->opacity*p->opacity*
+            p->opacity;
+          area++;
+        }
+      if (((channel & IndexChannel) != 0) &&
+          (image->colorspace == CMYKColorspace))
+        {
+          mean+=indexes[x];
+          sum_squares+=(double) indexes[x]*indexes[x];
+          sum_cubes+=(double) indexes[x]*indexes[x]*indexes[x];
+          sum_fourth_power+=(double) indexes[x]*indexes[x]*indexes[x]*
+            indexes[x];
+          area++;
+        }
+      p++;
+    }
+  }
+  if (y < (long) image->rows)
+    return(MagickFalse);
+  if (area != 0.0)
+    {
+      mean/=area;
+      sum_squares/=area;
+      sum_cubes/=area;
+      sum_fourth_power/=area;
+    }
+  standard_deviation=sqrt(sum_squares-(mean*mean));
+  if (standard_deviation != 0.0)
+    {
+      *kurtosis=sum_fourth_power-4.0*mean*sum_cubes+6.0*mean*mean*sum_squares-
+        3.0*mean*mean*mean*mean;
+      *kurtosis/=standard_deviation*standard_deviation*standard_deviation*
+        standard_deviation;
+      *kurtosis-=3.0;
+      *skewness=sum_cubes-3.0*mean*sum_squares+2.0*mean*mean*mean;
+      *skewness/=standard_deviation*standard_deviation*standard_deviation;
+    }
+  return(y == (long) image->rows ? MagickTrue : MagickFalse);
+}
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -726,9 +882,9 @@ MagickExport MagickBooleanType GetImageChannelRange(const Image *image,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  GetImageChannelStatistics() returns statistics for each channel in the
-%  image.  The statistics incude the channel depth, its minima, maxima, mean,
-%  and the standard deviation.  You can access the red channel mean, for
-%  example, like this:
+%  image.  The statistics include the channel depth, its minima, maxima, mean,
+%  standard deviation, kurtosis and skewness.  You can access the red channel
+%  mean, for example, like this:
 %
 %      channel_statistics=GetImageChannelStatistics(image,excepton);
 %      red_mean=channel_statistics[RedChannel].mean;
@@ -769,7 +925,9 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
     *channel_statistics;
 
   double
-    area;
+    area,
+    sum_squares,
+    sum_cubes;
 
   long
     y;
@@ -778,7 +936,7 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
     status;
 
   QuantumAny
-    scale;
+    range;
 
   register const IndexPacket
     *indexes;
@@ -815,6 +973,8 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
     channel_statistics[i].minima=1.0E+37;
     channel_statistics[i].mean=0.0;
     channel_statistics[i].standard_deviation=0.0;
+    channel_statistics[i].kurtosis=0.0;
+    channel_statistics[i].skewness=0.0;
   }
   y=(long) image->rows;
   for (y=0; y < (long) image->rows; y++)
@@ -828,9 +988,9 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
       if (channel_statistics[RedChannel].depth != MAGICKCORE_QUANTUM_DEPTH)
         {
           depth=channel_statistics[RedChannel].depth;
-          scale=GetQuantumScale(depth);
-          status=p->red != ScaleAnyToQuantum(ScaleQuantumToAny(p->red,depth,
-            scale),depth,scale) ? MagickTrue : MagickFalse;
+          range=GetQuantumRange(depth);
+          status=p->red != ScaleAnyToQuantum(ScaleQuantumToAny(p->red,range),
+            range) ? MagickTrue : MagickFalse;
           if (status != MagickFalse)
             {
               channel_statistics[RedChannel].depth++;
@@ -840,9 +1000,9 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
       if (channel_statistics[GreenChannel].depth != MAGICKCORE_QUANTUM_DEPTH)
         {
           depth=channel_statistics[GreenChannel].depth;
-          scale=GetQuantumScale(depth);
+          range=GetQuantumRange(depth);
           status=p->green != ScaleAnyToQuantum(ScaleQuantumToAny(p->green,
-            depth,scale),depth,scale) ? MagickTrue : MagickFalse;
+            range),range) ? MagickTrue : MagickFalse;
           if (status != MagickFalse)
             {
               channel_statistics[GreenChannel].depth++;
@@ -852,9 +1012,9 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
       if (channel_statistics[BlueChannel].depth != MAGICKCORE_QUANTUM_DEPTH)
         {
           depth=channel_statistics[BlueChannel].depth;
-          scale=GetQuantumScale(depth);
+          range=GetQuantumRange(depth);
           status=p->blue != ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,
-            depth,scale),depth,scale) ? MagickTrue : MagickFalse;
+            range),range) ? MagickTrue : MagickFalse;
           if (status != MagickFalse)
             {
               channel_statistics[BlueChannel].depth++;
@@ -864,9 +1024,9 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
       if (channel_statistics[OpacityChannel].depth != MAGICKCORE_QUANTUM_DEPTH)
         {
           depth=channel_statistics[OpacityChannel].depth;
-          scale=GetQuantumScale(depth);
+          range=GetQuantumRange(depth);
           status=p->opacity != ScaleAnyToQuantum(ScaleQuantumToAny(p->opacity,
-            depth,scale),depth,scale) ? MagickTrue : MagickFalse;
+            range),range) ? MagickTrue : MagickFalse;
           if (status != MagickFalse)
             {
               channel_statistics[OpacityChannel].depth++;
@@ -878,9 +1038,9 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
           if (channel_statistics[BlackChannel].depth != MAGICKCORE_QUANTUM_DEPTH)
             {
               depth=channel_statistics[BlackChannel].depth;
-              scale=GetQuantumScale(depth);
+              range=GetQuantumRange(depth);
               status=indexes[x] != ScaleAnyToQuantum(ScaleQuantumToAny(
-                indexes[x],depth,scale),depth,scale) ? MagickTrue : MagickFalse;
+                indexes[x],range),range) ? MagickTrue : MagickFalse;
               if (status != MagickFalse)
                 {
                   channel_statistics[BlackChannel].depth++;
@@ -893,22 +1053,32 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
       if ((double) p->red > channel_statistics[RedChannel].maxima)
         channel_statistics[RedChannel].maxima=(double) p->red;
       channel_statistics[RedChannel].mean+=p->red;
-      channel_statistics[RedChannel].standard_deviation+=(double)
+      channel_statistics[RedChannel].standard_deviation+=(double) p->red*p->red;
+      channel_statistics[RedChannel].kurtosis+=(double) p->red*p->red*
         p->red*p->red;
+      channel_statistics[RedChannel].skewness+=(double) p->red*p->red*p->red;
       if ((double) p->green < channel_statistics[GreenChannel].minima)
         channel_statistics[GreenChannel].minima=(double) p->green;
       if ((double) p->green > channel_statistics[GreenChannel].maxima)
         channel_statistics[GreenChannel].maxima=(double) p->green;
       channel_statistics[GreenChannel].mean+=p->green;
-      channel_statistics[GreenChannel].standard_deviation+=(double)
+      channel_statistics[GreenChannel].standard_deviation+=(double) p->green*
+        p->green;
+      channel_statistics[GreenChannel].kurtosis+=(double) p->green*p->green*
         p->green*p->green;
+      channel_statistics[GreenChannel].skewness+=(double) p->green*p->green*
+        p->green;
       if ((double) p->blue < channel_statistics[BlueChannel].minima)
         channel_statistics[BlueChannel].minima=(double) p->blue;
       if ((double) p->blue > channel_statistics[BlueChannel].maxima)
         channel_statistics[BlueChannel].maxima=(double) p->blue;
       channel_statistics[BlueChannel].mean+=p->blue;
-      channel_statistics[BlueChannel].standard_deviation+=(double)
+      channel_statistics[BlueChannel].standard_deviation+=(double) p->blue*
+        p->blue;
+      channel_statistics[BlueChannel].kurtosis+=(double) p->blue*p->blue*
         p->blue*p->blue;
+      channel_statistics[BlueChannel].skewness+=(double) p->blue*p->blue*
+        p->blue;
       if ((double) p->opacity < channel_statistics[OpacityChannel].minima)
         channel_statistics[OpacityChannel].minima=(double) p->opacity;
       if ((double) p->opacity > channel_statistics[OpacityChannel].maxima)
@@ -916,6 +1086,10 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
       channel_statistics[OpacityChannel].mean+=p->opacity;
       channel_statistics[OpacityChannel].standard_deviation+=(double)
         p->opacity*p->opacity;
+      channel_statistics[OpacityChannel].kurtosis+=(double) p->opacity*
+        p->opacity*p->opacity*p->opacity;
+      channel_statistics[OpacityChannel].skewness+=(double) p->opacity*
+        p->opacity*p->opacity;
       if (image->colorspace == CMYKColorspace)
         {
           if ((double) indexes[x] < channel_statistics[BlackChannel].minima)
@@ -925,6 +1099,10 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
           channel_statistics[BlackChannel].mean+=indexes[x];
           channel_statistics[BlackChannel].standard_deviation+=(double)
             indexes[x]*indexes[x];
+          channel_statistics[BlackChannel].kurtosis+=(double) indexes[x]*
+            indexes[x]*indexes[x]*indexes[x];
+          channel_statistics[BlackChannel].skewness+=(double) indexes[x]*
+            indexes[x]*indexes[x];
         }
       x++;
       p++;
@@ -935,6 +1113,8 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
   {
     channel_statistics[i].mean/=area;
     channel_statistics[i].standard_deviation/=area;
+    channel_statistics[i].kurtosis/=area;
+    channel_statistics[i].skewness/=area;
   }
   for (i=0; i < AllChannels; i++)
   {
@@ -948,19 +1128,53 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
     channel_statistics[AllChannels].mean+=channel_statistics[i].mean;
     channel_statistics[AllChannels].standard_deviation+=
       channel_statistics[i].standard_deviation;
+    channel_statistics[AllChannels].kurtosis+=channel_statistics[i].kurtosis;
+    channel_statistics[AllChannels].skewness+=channel_statistics[i].skewness;
   }
   channels=4;
   if (image->colorspace == CMYKColorspace)
     channels++;
   channel_statistics[AllChannels].mean/=channels;
   channel_statistics[AllChannels].standard_deviation/=channels;
+  channel_statistics[AllChannels].kurtosis/=channels;
+  channel_statistics[AllChannels].skewness/=channels;
   for (i=0; i <= AllChannels; i++)
+  {
+    sum_squares=0.0;
+    sum_squares=channel_statistics[i].standard_deviation;
+    sum_cubes=0.0;
+    sum_cubes=channel_statistics[i].skewness;
     channel_statistics[i].standard_deviation=sqrt(
       channel_statistics[i].standard_deviation-
        (channel_statistics[i].mean*channel_statistics[i].mean));
+    if (channel_statistics[i].standard_deviation == 0.0)
+      {
+        channel_statistics[i].kurtosis=0.0;
+        channel_statistics[i].skewness=0.0;
+      }
+    else
+      {
+        channel_statistics[i].skewness=(channel_statistics[i].skewness-
+          3.0*channel_statistics[i].mean*sum_squares+
+          2.0*channel_statistics[i].mean*channel_statistics[i].mean*
+          channel_statistics[i].mean)/
+          (channel_statistics[i].standard_deviation*
+           channel_statistics[i].standard_deviation*
+           channel_statistics[i].standard_deviation);
+        channel_statistics[i].kurtosis=(channel_statistics[i].kurtosis-
+          4.0*channel_statistics[i].mean*sum_cubes+
+          6.0*channel_statistics[i].mean*channel_statistics[i].mean*sum_squares-
+          3.0*channel_statistics[i].mean*channel_statistics[i].mean*
+          1.0*channel_statistics[i].mean*channel_statistics[i].mean)/
+          (channel_statistics[i].standard_deviation*
+           channel_statistics[i].standard_deviation*
+           channel_statistics[i].standard_deviation*
+           channel_statistics[i].standard_deviation)-3.0;
+      }
+  }
   return(channel_statistics);
 }
-
+ 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -1060,7 +1274,7 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
     status;
 
   QuantumAny
-    scale;
+    range;
 
   ViewInfo
     *image_view;
@@ -1079,7 +1293,7 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
     Scale pixels to desired depth.
   */
   status=MagickTrue;
-  scale=GetQuantumScale(depth);
+  range=GetQuantumRange(depth);
   exception=(&image->exception);
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
@@ -1109,21 +1323,16 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        q->red=ScaleAnyToQuantum(ScaleQuantumToAny(q->red,depth,scale),depth,
-          scale);
+        q->red=ScaleAnyToQuantum(ScaleQuantumToAny(q->red,range),range);
       if ((channel & GreenChannel) != 0)
-        q->green=ScaleAnyToQuantum(ScaleQuantumToAny(q->green,depth,scale),
-          depth,scale);
+        q->green=ScaleAnyToQuantum(ScaleQuantumToAny(q->green,range),range);
       if ((channel & BlueChannel) != 0)
-        q->blue=ScaleAnyToQuantum(ScaleQuantumToAny(q->blue,depth,scale),
-          depth,scale);
+        q->blue=ScaleAnyToQuantum(ScaleQuantumToAny(q->blue,range),range);
       if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
-        q->opacity=ScaleAnyToQuantum(ScaleQuantumToAny(q->opacity,depth,scale),
-          depth,scale);
+        q->opacity=ScaleAnyToQuantum(ScaleQuantumToAny(q->opacity,range),range);
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
-        indexes[x]=ScaleAnyToQuantum(ScaleQuantumToAny(indexes[x],depth,scale),
-          depth,scale);
+        indexes[x]=ScaleAnyToQuantum(ScaleQuantumToAny(indexes[x],range),range);
       q++;
     }
     if (SyncCacheViewAuthenticPixels(image_view,exception) == MagickFalse)
@@ -1136,7 +1345,7 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
   if (image->storage_class == PseudoClass)
     {
       QuantumAny
-        scale;
+        range;
 
       register long
         i;
@@ -1145,24 +1354,21 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
         *p;
 
       p=image->colormap;
-      scale=GetQuantumScale(depth);
+      range=GetQuantumRange(depth);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (i=0; i < (long) image->colors; i++)
       {
         if ((channel & RedChannel) != 0)
-          p->red=ScaleAnyToQuantum(ScaleQuantumToAny(p->red,depth,
-            scale),depth,scale);
+          p->red=ScaleAnyToQuantum(ScaleQuantumToAny(p->red,range),range);
         if ((channel & GreenChannel) != 0)
-          p->green=ScaleAnyToQuantum(ScaleQuantumToAny(p->green,depth,
-            scale),depth,scale);
+          p->green=ScaleAnyToQuantum(ScaleQuantumToAny(p->green,range),range);
         if ((channel & BlueChannel) != 0)
-          p->blue=ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,depth,
-            scale),depth,scale);
+          p->blue=ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,range),range);
         if ((channel & OpacityChannel) != 0)
-          p->opacity=ScaleAnyToQuantum(ScaleQuantumToAny(p->opacity,depth,
-            scale),depth,scale);
+          p->opacity=ScaleAnyToQuantum(ScaleQuantumToAny(p->opacity,range),
+            range);
         p++;
       }
     }
