@@ -10,14 +10,14 @@
 %                  SSSSS     T    R  R   IIIII  N   N   GGGG                  %
 %                                                                             %
 %                                                                             %
-%                       ImageMagick String Methods                            %
+%                        MagickCore String Methods                            %
 %                                                                             %
 %                             Software Design                                 %
 %                               John Cristy                                   %
 %                               August 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -654,7 +654,8 @@ MagickExport char *ConstantString(const char *source)
 %
 %  CopyMagickString() copies the source string to the destination string.  The
 %  destination buffer is always null-terminated even if the string must be
-%  truncated.
+%  truncated.  The return value is the minimum of the source string length
+%  or the length parameter.
 %
 %  The format of the CopyMagickString method is:
 %
@@ -713,7 +714,6 @@ MagickExport size_t CopyMagickString(char *destination,const char *source,
     }
   if (length != 0)
     *q='\0';
-  while (*p++ != '\0') ;
   return((size_t) (p-source-1));
 }
 
@@ -911,7 +911,7 @@ MagickExport char *EscapeString(const char *source,const char escape)
 %
 %    o extent: Maximum length of the string.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport char *FileToString(const char *filename,const size_t extent,
@@ -950,7 +950,7 @@ MagickExport char *FileToString(const char *filename,const size_t extent,
 %
 %    o extent: Maximum length of the string.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport StringInfo *FileToStringInfo(const char *filename,
@@ -1008,16 +1008,26 @@ MagickExport long FormatMagickSize(const MagickSizeType size,char *format)
     count;
 
   register long
-    i;
+    i,
+    j;
 
   static const char
     *units[] = { "b", "kb", "mb", "gb", "tb", "pb", "eb", (char *) NULL };
 
-  length=1.0*size;
+#if _MSC_VER == 1200
+  length=(double) ((MagickOffsetType) size);
+#else
+  length=(double) size;
+#endif
   for (i=0; (length >= 1024.0) && (units[i+1] != (const char *) NULL); i++)
     length/=1024.0;
-  count=FormatMagickString(format,MaxTextExtent,"%.*g%s",(int) (i+2),length,
-    units[i]);
+  for (j=2; j < 10; j++)
+  {
+    count=FormatMagickString(format,MaxTextExtent,"%.*g%s",(int) (i+j),length,
+      units[i]);
+    if (strchr(format,'+') == (char *) NULL)
+      break;
+  }
   return(count);
 }
 
@@ -1118,23 +1128,27 @@ MagickExport long FormatMagickTime(const time_t time,const size_t length,
     count;
 
   struct tm
-    local_time,
-    utc_time;
+    *local_time,
+    *utc_time;
 
   time_t
     timezone;
 
   assert(timestamp != (char *) NULL);
-  local_time=(*localtime(&time));
-  utc_time=(*gmtime(&time));
-  timezone=(time_t) ((local_time.tm_min-utc_time.tm_min)/60+local_time.tm_hour-
-    utc_time.tm_hour+24*((local_time.tm_year-utc_time.tm_year) != 0 ?
-    (local_time.tm_year-utc_time.tm_year) : (local_time.tm_yday-
-    utc_time.tm_yday)));
+  local_time=localtime(&time);
+  if (local_time == (struct tm *) NULL)
+    return(0);
+  utc_time=gmtime(&time);
+  if (utc_time == (struct tm *) NULL)
+    return(0);
+  timezone=(time_t) ((local_time->tm_min-utc_time->tm_min)/60+
+    local_time->tm_hour-utc_time->tm_hour+24*((local_time->tm_year-
+    utc_time->tm_year) != 0 ? (local_time->tm_year-utc_time->tm_year) :
+    (local_time->tm_yday-utc_time->tm_yday)));
   count=FormatMagickString(timestamp,length,
-    "%04d-%02d-%02dT%02d:%02d:%02d%+03ld:00",local_time.tm_year+1900,
-    local_time.tm_mon+1,local_time.tm_mday,local_time.tm_hour,local_time.tm_min,
-    local_time.tm_sec,(long) timezone);
+    "%04d-%02d-%02dT%02d:%02d:%02d%+03ld:00",local_time->tm_year+1900,
+    local_time->tm_mon+1,local_time->tm_mday,local_time->tm_hour,
+    local_time->tm_min,local_time->tm_sec,(long) timezone);
   return(count);
 }
 
@@ -1757,7 +1771,7 @@ MagickExport StringInfo *SplitStringInfo(StringInfo *string_info,
     return((StringInfo *) NULL);
   split_info=AcquireStringInfo(offset);
   SetStringInfo(split_info,string_info);
-  (void) memmove(string_info->datum,string_info->datum+offset,
+  (void) CopyMagickMemory(string_info->datum,string_info->datum+offset,
     string_info->length-offset+MaxTextExtent);
   SetStringInfoLength(string_info,string_info->length-offset);
   return(split_info);
