@@ -286,7 +286,7 @@ MagickExport Image *AdaptiveThresholdImage(const Image *image,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_AdaptiveThresholdImage)
 #endif
         proceed=SetImageProgress(image,ThresholdImageTag,progress++,
           image->rows);
@@ -453,7 +453,7 @@ MagickExport MagickBooleanType BilevelImageChannel(Image *image,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_BilevelImageChannel)
 #endif
         proceed=SetImageProgress(image,ThresholdImageTag,progress++,
           image->rows);
@@ -509,21 +509,8 @@ MagickExport MagickBooleanType BlackThresholdImage(Image *image,
   return(status);
 }
 
-static inline MagickBooleanType IsLongGrayPixel(const LongPixelPacket *pixel)
-{
-#if !defined(MAGICKCORE_HDRI_SUPPORT)
-  if ((pixel->red == pixel->green) && (pixel->green == pixel->blue))
-    return(MagickTrue);
-#else
-  if ((fabs(pixel->red-pixel->green) <= MagickEpsilon) &&
-      (fabs(pixel->green-pixel->blue) <= MagickEpsilon))
-    return(MagickTrue);
-#endif
-  return(MagickFalse);
-}
-
 MagickExport MagickBooleanType BlackThresholdImageChannel(Image *image,
-  const ChannelType channel,const char *threshold,ExceptionInfo *exception)
+  const ChannelType channel,const char *thresholds,ExceptionInfo *exception)
 {
 #define ThresholdImageTag  "Threshold/Image"
 
@@ -534,12 +521,12 @@ MagickExport MagickBooleanType BlackThresholdImageChannel(Image *image,
     progress,
     y;
 
-  LongPixelPacket
-    pixel;
-
   MagickBooleanType
     status;
 
+  MagickPixelPacket
+    threshold;
+
   MagickStatusType
     flags;
 
@@ -550,31 +537,32 @@ MagickExport MagickBooleanType BlackThresholdImageChannel(Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  if (threshold == (const char *) NULL)
+  if (thresholds == (const char *) NULL)
     return(MagickTrue);
   if (SetImageStorageClass(image,DirectClass) == MagickFalse)
     return(MagickFalse);
-  flags=ParseGeometry(threshold,&geometry_info);
-  pixel.red=(long) (geometry_info.rho+0.5);
-  pixel.green=(long) (geometry_info.sigma+0.5);
+  GetMagickPixelPacket(image,&threshold);
+  flags=ParseGeometry(thresholds,&geometry_info);
+  threshold.red=geometry_info.rho;
+  threshold.green=geometry_info.sigma;
   if ((flags & SigmaValue) == 0)
-    pixel.green=pixel.red;
-  pixel.blue=(long) (geometry_info.xi+0.5);
+    threshold.green=threshold.red;
+  threshold.blue=geometry_info.xi;
   if ((flags & XiValue) == 0)
-    pixel.blue=pixel.red;
-  pixel.opacity=(long) (geometry_info.psi+0.5);
+    threshold.blue=threshold.red;
+  threshold.opacity=geometry_info.psi;
   if ((flags & XiValue) == 0)
-    pixel.opacity=pixel.red;
-  pixel.index=(long) (geometry_info.chi+0.5);
+    threshold.opacity=threshold.red;
+  threshold.index=geometry_info.chi;
   if ((flags & ChiValue) == 0)
-    pixel.index=pixel.red;
+    threshold.index=threshold.red;
   if ((flags & PercentValue) != 0)
     {
-      pixel.red*=(QuantumRange/100.0);
-      pixel.green*=(QuantumRange/100.0);
-      pixel.blue*=(QuantumRange/100.0);
-      pixel.opacity*=(QuantumRange/100.0);
-      pixel.index*=(QuantumRange/100.0);
+      threshold.red*=(QuantumRange/100.0);
+      threshold.green*=(QuantumRange/100.0);
+      threshold.blue*=(QuantumRange/100.0);
+      threshold.opacity*=(QuantumRange/100.0);
+      threshold.index*=(QuantumRange/100.0);
     }
   /*
     Black threshold image.
@@ -605,10 +593,10 @@ MagickExport MagickBooleanType BlackThresholdImageChannel(Image *image,
         continue;
       }
     indexes=GetCacheViewAuthenticIndexQueue(image_view);
-    if (IsLongGrayPixel(&pixel) != MagickFalse)
+    if (IsMagickGray(&threshold) != MagickFalse)
       for (x=0; x < (long) image->columns; x++)
       {
-        if ((MagickRealType) PixelIntensityToQuantum(q) < pixel.red)
+        if ((MagickRealType) PixelIntensityToQuantum(q) < threshold.red)
           {
             if ((channel & RedChannel) != 0)
               q->red=(Quantum) 0;
@@ -623,20 +611,20 @@ MagickExport MagickBooleanType BlackThresholdImageChannel(Image *image,
       for (x=0; x < (long) image->columns; x++)
       {
         if (((channel & RedChannel) != 0) &&
-            (q->red < pixel.red))
+            ((MagickRealType) q->red < threshold.red))
           q->red=(Quantum) 0;
         if (((channel & GreenChannel) != 0) &&
-            (q->green < pixel.green))
+            ((MagickRealType) q->green < threshold.green))
           q->green=(Quantum) 0;
         if (((channel & BlueChannel) != 0) &&
-            (q->blue < pixel.blue))
+            ((MagickRealType) q->blue < threshold.blue))
           q->blue=(Quantum) 0;
         if (((channel & OpacityChannel) != 0) &&
-            (q->opacity < pixel.opacity))
+            ((MagickRealType) q->opacity < threshold.opacity))
           q->opacity=(Quantum) 0;
         if (((channel & IndexChannel) != 0) &&
             (image->colorspace == CMYKColorspace) &&
-            (indexes[x] < pixel.index))
+            ((MagickRealType) indexes[x] < threshold.index))
           indexes[x]=(Quantum) 0;
         q++;
       }
@@ -648,7 +636,7 @@ MagickExport MagickBooleanType BlackThresholdImageChannel(Image *image,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_BlackThresholdImageChannel)
 #endif
         proceed=SetImageProgress(image,ThresholdImageTag,progress++,
           image->rows);
@@ -882,7 +870,7 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
       }
       content = p;
     }
-    value=strtol(content,&p,10);
+    value=(double) strtol(content,&p,10);
     if (p != content)
       {
         (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
@@ -1412,7 +1400,7 @@ printf("DEBUG levels  r=%ld g=%ld b=%ld a=%ld i=%ld\n",
             proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_OrderedPosterizeImageChannel)
 #endif
           proceed=SetImageProgress(image,DitherImageTag,progress++,image->rows);
           if (proceed == MagickFalse)
@@ -1599,7 +1587,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
               proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_RandomThresholdImageChannel)
 #endif
             proceed=SetImageProgress(image,ThresholdImageTag,progress++,
               image->rows);
@@ -1723,7 +1711,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_RandomThresholdImageChannel)
 #endif
         proceed=SetImageProgress(image,ThresholdImageTag,progress++,
           image->rows);
@@ -1780,7 +1768,7 @@ MagickExport MagickBooleanType WhiteThresholdImage(Image *image,
 }
 
 MagickExport MagickBooleanType WhiteThresholdImageChannel(Image *image,
-  const ChannelType channel,const char *threshold,ExceptionInfo *exception)
+  const ChannelType channel,const char *thresholds,ExceptionInfo *exception)
 {
 #define ThresholdImageTag  "Threshold/Image"
 
@@ -1791,12 +1779,12 @@ MagickExport MagickBooleanType WhiteThresholdImageChannel(Image *image,
     progress,
     y;
 
-  LongPixelPacket
-    pixel;
-
   MagickBooleanType
     status;
 
+  MagickPixelPacket
+    threshold;
+
   MagickStatusType
     flags;
 
@@ -1807,31 +1795,32 @@ MagickExport MagickBooleanType WhiteThresholdImageChannel(Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  if (threshold == (const char *) NULL)
+  if (thresholds == (const char *) NULL)
     return(MagickTrue);
   if (SetImageStorageClass(image,DirectClass) == MagickFalse)
     return(MagickFalse);
-  flags=ParseGeometry(threshold,&geometry_info);
-  pixel.red=(long) (geometry_info.rho+0.5);
-  pixel.green=(long) (geometry_info.sigma+0.5);
+  flags=ParseGeometry(thresholds,&geometry_info);
+  GetMagickPixelPacket(image,&threshold);
+  threshold.red=geometry_info.rho;
+  threshold.green=geometry_info.sigma;
   if ((flags & SigmaValue) == 0)
-    pixel.green=pixel.red;
-  pixel.blue=geometry_info.xi;
+    threshold.green=threshold.red;
+  threshold.blue=geometry_info.xi;
   if ((flags & XiValue) == 0)
-    pixel.blue=pixel.red;
-  pixel.opacity=(long) (geometry_info.psi+0.5);
+    threshold.blue=threshold.red;
+  threshold.opacity=geometry_info.psi;
   if ((flags & XiValue) == 0)
-    pixel.opacity=pixel.red;
-  pixel.index=geometry_info.chi;
+    threshold.opacity=threshold.red;
+  threshold.index=geometry_info.chi;
   if ((flags & ChiValue) == 0)
-    pixel.index=pixel.red;
+    threshold.index=threshold.red;
   if ((flags & PercentValue) != 0)
     {
-      pixel.red*=(QuantumRange/100.0);
-      pixel.green*=(QuantumRange/100.0);
-      pixel.blue*=(QuantumRange/100.0);
-      pixel.opacity*=(QuantumRange/100.0);
-      pixel.index*=(QuantumRange/100.0);
+      threshold.red*=(QuantumRange/100.0);
+      threshold.green*=(QuantumRange/100.0);
+      threshold.blue*=(QuantumRange/100.0);
+      threshold.opacity*=(QuantumRange/100.0);
+      threshold.index*=(QuantumRange/100.0);
     }
   /*
     White threshold image.
@@ -1862,10 +1851,10 @@ MagickExport MagickBooleanType WhiteThresholdImageChannel(Image *image,
         continue;
       }
     indexes=GetCacheViewAuthenticIndexQueue(image_view);
-    if (IsLongGrayPixel(&pixel) != MagickFalse)
+    if (IsMagickGray(&threshold) != MagickFalse)
       for (x=0; x < (long) image->columns; x++)
       {
-        if ((MagickRealType) PixelIntensityToQuantum(q) > pixel.red)
+        if ((MagickRealType) PixelIntensityToQuantum(q) > threshold.red)
           {
             if ((channel & RedChannel) != 0)
               q->red=(Quantum) QuantumRange;
@@ -1880,20 +1869,20 @@ MagickExport MagickBooleanType WhiteThresholdImageChannel(Image *image,
       for (x=0; x < (long) image->columns; x++)
       {
         if (((channel & RedChannel) != 0) &&
-            (q->red > pixel.red))
+            ((MagickRealType) q->red > threshold.red))
           q->red=(Quantum) QuantumRange;
         if (((channel & GreenChannel) != 0) &&
-            (q->green > pixel.green))
+            ((MagickRealType) q->green > threshold.green))
           q->green=(Quantum) QuantumRange;
         if (((channel & BlueChannel) != 0) &&
-            (q->blue > pixel.blue))
+            ((MagickRealType) q->blue > threshold.blue))
           q->blue=(Quantum) QuantumRange;
         if (((channel & OpacityChannel) != 0) &&
-            (q->opacity > pixel.opacity))
+            ((MagickRealType) q->opacity > threshold.opacity))
           q->opacity=(Quantum) QuantumRange;
         if (((channel & IndexChannel) != 0) &&
             (image->colorspace == CMYKColorspace) &&
-            (indexes[x] > pixel.index))
+            ((MagickRealType) indexes[x] > threshold.index))
           indexes[x]=(Quantum) QuantumRange;
         q++;
       }
@@ -1905,7 +1894,7 @@ MagickExport MagickBooleanType WhiteThresholdImageChannel(Image *image,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_WhiteThresholdImageChannel)
 #endif
         proceed=SetImageProgress(image,ThresholdImageTag,progress++,
           image->rows);
