@@ -692,7 +692,8 @@ MagickExport MagickBooleanType ExpandFilenames(int *number_arguments,
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(number_arguments != (int *) NULL);
   assert(arguments != (char ***) NULL);
-  vector=(char **) AcquireQuantumMemory(*number_arguments+1UL,sizeof(*vector));
+  vector=(char **) AcquireQuantumMemory((size_t) (*number_arguments+1),
+    sizeof(*vector));
   if (vector == (char **) NULL)
     return(MagickFalse);
   /*
@@ -1390,10 +1391,6 @@ MagickExport MagickBooleanType IsPathAccessible(const char *path)
 */
 static int IsPathDirectory(const char *path)
 {
-#if !defined(X_OK)
-#define X_OK  1
-#endif
-
   MagickBooleanType
     status;
 
@@ -1407,8 +1404,6 @@ static int IsPathDirectory(const char *path)
     return(-1);
   if (S_ISDIR(attributes.st_mode) == 0)
     return(0);
-  if (access(path,X_OK) != 0)
-    return(0);
   return(1);
 }
 
