@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -26,12 +26,15 @@ extern "C" {
   Define declarations.
 */
 #define MagickPackageName "ImageMagick"
-#define MagickCopyright  "Copyright (C) 1999-2008 ImageMagick Studio LLC"
-#define MagickLibVersion  0x643
-#define MagickLibVersionText  "6.4.3"
-#define MagickLibVersionNumber  1,0,0
-#define MagickReleaseDate  "2008-09-24"
-#define MagickChangeDate   "20080924"
+#define MagickCopyright  "Copyright (C) 1999-2009 ImageMagick Studio LLC"
+#define MagickLibVersion  0x649
+#define MagickLibVersionText  "6.4.9"
+#define MagickLibVersionNumber  2,0,0
+#define MagickLibSubversion  "-2"
+#define MagickReleaseDate  "2009-02-05"
+#define MagickChangeDate   "20090204"
+#define MagickAuthoritativeURL  "http://www.imagemagick.org"
+#define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6.4.9/index.html"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
@@ -59,10 +62,9 @@ extern "C" {
 #define MagickOPENMPSupport "OpenMP "
 #endif
 #define MagickSupport MagickHDRISupport MagickOPENMPSupport
-#define MagickVersion MagickPackageName " " MagickLibVersionText " " \
-  MagickReleaseDate " " MagickQuantumDepth " " MagickSupport \
-  "http://www.imagemagick.org"
-#define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6.4.3/index.html"
+#define MagickVersion MagickPackageName " " MagickLibVersionText \
+  MagickLibSubversion " " MagickReleaseDate " " MagickQuantumDepth " " \
+  MagickSupport MagickAuthoritativeURL
 
 extern MagickExport char
   *GetMagickHomeURL(void);
