@@ -23,7 +23,7 @@
 %                               December 2004                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -769,7 +769,7 @@ MagickExport XMLTreeInfo *GetXMLTreeChild(XMLTreeInfo *xml_info,const char *tag)
 %
 %  The format of the GetXMLTreeContent method is:
 %
-%      XMLTreeInfo *GetXMLTreeContent(XMLTreeInfo *xml_info)
+%      const char *GetXMLTreeContent(XMLTreeInfo *xml_info)
 %
 %  A description of each parameter follows:
 %
@@ -907,7 +907,7 @@ MagickExport XMLTreeInfo *GetXMLTreePath(XMLTreeInfo *xml_info,const char *path)
 %
 %  The format of the GetXMLTreeProcessingInstructions method is:
 %
-%      XMLTreeInfo *GetXMLTreeProcessingInstructions(XMLTreeInfo *xml_info,
+%      const char **GetXMLTreeProcessingInstructions(XMLTreeInfo *xml_info,
 %        const char *target)
 %
 %  A description of each parameter follows:
@@ -986,7 +986,7 @@ MagickExport XMLTreeInfo *GetXMLTreeSibling(XMLTreeInfo *xml_info)
 %
 %  The format of the GetXMLTreeTag method is:
 %
-%      XMLTreeInfo *GetXMLTreeTag(XMLTreeInfo *xml_info)
+%      const char *GetXMLTreeTag(XMLTreeInfo *xml_info)
 %
 %  A description of each parameter follows:
 %
@@ -1119,7 +1119,7 @@ MagickExport XMLTreeInfo *InsertTagIntoXMLTree(XMLTreeInfo *xml_info,
 %
 %    o xml:  The XML string.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -1797,6 +1797,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
     {
       (void) ThrowMagickException(exception,GetMagickModule(),OptionWarning,
         "ParseError","root tag missing");
+      utf8=DestroyString(utf8);
       return((XMLTreeInfo *) NULL);
     }
   attribute=(char **) NULL;
@@ -1814,6 +1815,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
           {
             (void) ThrowMagickException(exception,GetMagickModule(),
               OptionWarning,"ParseError","root tag missing");
+            utf8=DestroyString(utf8);
             return(&root->root);
           }
         p+=strcspn(p,XMLWhitespace "/>");
@@ -1844,6 +1846,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
             {
               (void) ThrowMagickException(exception,GetMagickModule(),
                 ResourceLimitError,"MemoryAllocationFailed","`%s'","");
+              utf8=DestroyString(utf8);
               return(&root->root);
             }
           attributes[l+2]=(char *) NULL;
@@ -1870,9 +1873,12 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
                     *p++='\0';
                   else
                     {
+                      attributes[l]=ConstantString("");
+                      attributes[l+1]=ConstantString("");
                       (void) DestroyXMLTreeAttributes(attributes);
                       (void) ThrowMagickException(exception,GetMagickModule(),
                         OptionWarning,"ParseError","missing %c",c);
+                      utf8=DestroyString(utf8);
                       return(&root->root);
                     }
                   j=1;
@@ -1902,6 +1908,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
                   (void) DestroyXMLTreeAttributes(attributes);
                 (void) ThrowMagickException(exception,GetMagickModule(),
                   OptionWarning,"ParseError","missing >");
+                utf8=DestroyString(utf8);
                 return(&root->root);
               }
             ParseOpenTag(root,tag,attributes);
@@ -1922,6 +1929,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
                   (void) DestroyXMLTreeAttributes(attributes);
                 (void) ThrowMagickException(exception,GetMagickModule(),
                   OptionWarning,"ParseError","missing >");
+                utf8=DestroyString(utf8);
                 return(&root->root);
               }
           }
@@ -1939,11 +1947,15 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
             {
               (void) ThrowMagickException(exception,GetMagickModule(),
                 OptionWarning,"ParseError","missing >");
+              utf8=DestroyString(utf8);
               return(&root->root);
             }
           *p='\0';
           if (ParseCloseTag(root,tag,p,exception) != (XMLTreeInfo *) NULL)
-            return(&root->root);
+            {
+              utf8=DestroyString(utf8);
+              return(&root->root);
+            }
           *p=c;
           if (isspace((int) ((unsigned char) *p)) != 0)
             p+=strspn(p,XMLWhitespace);
@@ -1960,6 +1972,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
               {
                 (void) ThrowMagickException(exception,GetMagickModule(),
                   OptionWarning,"ParseError","unclosed <!--");
+                utf8=DestroyString(utf8);
                 return(&root->root);
               }
           }
@@ -1979,6 +1992,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
                 {
                   (void) ThrowMagickException(exception,GetMagickModule(),
                     OptionWarning,"ParseError","unclosed <![CDATA[");
+                  utf8=DestroyString(utf8);
                   return(&root->root);
                 }
             }
@@ -1997,6 +2011,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
                   {
                     (void) ThrowMagickException(exception,GetMagickModule(),
                       OptionWarning,"ParseError","unclosed <!DOCTYPE");
+                    utf8=DestroyString(utf8);
                     return(&root->root);
                   }
                 if (l != 0)
@@ -2006,7 +2021,10 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
                     status=ParseInternalDoctype(root,tag,(size_t) (p-tag),
                       exception);
                     if (status == MagickFalse)
-                      return(&root->root);
+                      {
+                        utf8=DestroyString(utf8);
+                        return(&root->root);
+                      }
                     p++;
                   }
               }
@@ -2028,6 +2046,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
                     {
                       (void) ThrowMagickException(exception,GetMagickModule(),
                         OptionWarning,"ParseError","unclosed <?");
+                      utf8=DestroyString(utf8);
                       return(&root->root);
                     }
                   ParseProcessingInstructions(root,tag+1,(size_t) (p-tag-2));
@@ -2036,6 +2055,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
                 {
                   (void) ThrowMagickException(exception,GetMagickModule(),
                     OptionWarning,"ParseError","unexpected <");
+                  utf8=DestroyString(utf8);
                   return(&root->root);
                 }
      if ((p == (char *) NULL) || (*p == '\0'))
@@ -2347,7 +2367,7 @@ MagickExport XMLTreeInfo *SetXMLTreeContent(XMLTreeInfo *xml_info,
 %
 %  The format of the XMLTreeInfoToXML method is:
 %
-%      XMLTreeInfo *XMLTreeInfoToXML(XMLTreeInfo *xml_info)
+%      char *XMLTreeInfoToXML(XMLTreeInfo *xml_info)
 %
 %  A description of each parameter follows:
 %
