@@ -75,7 +75,7 @@ int main ( int argc, char **argv )
   exception=AcquireExceptionInfo();
   fuzz_factor = 0.0;
 #if defined(MAGICKCORE_HDRI_SUPPORT)
-  fuzz_factor = 0.06;
+  fuzz_factor = 0.07;
 #endif
 
   for (arg=1; arg < argc; arg++)
@@ -218,14 +218,14 @@ int main ( int argc, char **argv )
    * Save image to array
    */
   pixels_size=quantum_size*strlen(map)*rows*columns;
-  pixels=AcquireQuantumMemory(pixels_size,sizeof(unsigned char));
+  pixels=AcquireQuantumMemory(pixels_size,sizeof(*pixels));
   if( !pixels )
     {
       (void) printf ( "Failed to allocate memory for pixels\n");
       exit_status = 1;
       goto program_exit;
     }
-  memset((void *) pixels, 0, pixels_size);
+  memset((void *) pixels, 0, pixels_size*sizeof(*pixels));
 
   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                         "Writing image to pixel array");
@@ -246,10 +246,10 @@ int main ( int argc, char **argv )
    * Read image back from pixel array
    */
   original = AcquireImage((ImageInfo *) NULL);
-  SetImageExtent(original,columns,rows);
   if (strchr(map,'c') || strchr(map,'C') || strchr(map,'m') || strchr(map,'M') ||
       strchr(map,'y') || strchr(map,'y') || strchr(map,'k') || strchr(map,'k'))
     original->colorspace=CMYKColorspace;
+  SetImageExtent(original,columns,rows);
   (void) SetImageBackgroundColor(original);
 
   status = ImportImagePixels(original,0,0,columns,rows,map,storage_type,pixels);
@@ -265,7 +265,7 @@ int main ( int argc, char **argv )
   /*
    * Save image to pixel array
    */
-  memset((void *) pixels, 0, pixels_size);
+  memset((void *) pixels, 0, pixels_size*sizeof(*pixels));
   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                         "Writing image to pixel array");
   if( !ExportImagePixels(original,0,0,original->columns,original->rows,map,
@@ -284,6 +284,7 @@ int main ( int argc, char **argv )
   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                         "Reading image from pixel array");
   final = AcquireImage((ImageInfo *) NULL);
+  final->colorspace=original->colorspace;
   SetImageExtent(final,columns,rows);
   (void) SetImageBackgroundColor(final);
   status = ImportImagePixels(final,0,0,columns,rows,map,storage_type,pixels);
