@@ -57,7 +57,7 @@ int main ( int argc, char **argv )
     *imageInfo;
 
   ExceptionInfo
-    exception;
+    *exception;
 
   if (LocaleNCompare("rwblob",argv[0],7) == 0)
     MagickCoreGenesis((char *) NULL,MagickTrue);
@@ -65,7 +65,7 @@ int main ( int argc, char **argv )
     MagickCoreGenesis(*argv,MagickTrue);
 
   imageInfo=CloneImageInfo(0);
-  GetExceptionInfo( &exception );
+  exception=AcquireExceptionInfo();
 
   for (arg=1; arg < argc; arg++)
     {
@@ -137,7 +137,7 @@ int main ( int argc, char **argv )
             }
           else if (LocaleCompare("verbose",option+1) == 0)
             {
-              imageInfo->verbose+=1;
+              imageInfo->verbose=MagickTrue;
             }
         }
       else
@@ -166,15 +166,15 @@ int main ( int argc, char **argv )
    */
   imageInfo=DestroyImageInfo(imageInfo);
   imageInfo=CloneImageInfo(0);
-  GetExceptionInfo(&exception);
+  ClearMagickException(exception);
   imageInfo->dither=MagickFalse;
   (void) strncpy( imageInfo->filename, infile, MaxTextExtent-1 );
   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
     "Reading image %s", imageInfo->filename);
-  original = ReadImage ( imageInfo, &exception );
-  if (exception.severity >= ErrorException)
+  original = ReadImage ( imageInfo, exception );
+  if (exception->severity >= ErrorException)
     {
-      CatchException(&exception);
+      CatchException(exception);
       exit_status = 1;
       goto program_exit;
     }
@@ -192,7 +192,7 @@ int main ( int argc, char **argv )
   rows    = original->rows;
   columns = original->columns;
   size[0]='\0';
-  magick_info=GetMagickInfo(format,&exception);
+  magick_info=GetMagickInfo(format,exception);
   if (magick_info && magick_info->raw)
     FormatMagickString( size, MaxTextExtent, "%dx%d", columns, rows );
 
@@ -205,10 +205,10 @@ int main ( int argc, char **argv )
   original->delay = 10;
   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
     "Writing image to BLOB");
-  blob =(char *) ImageToBlob ( imageInfo, original, &blob_length, &exception );
-  if (exception.severity >= ErrorException)
+  blob =(char *) ImageToBlob ( imageInfo, original, &blob_length, exception );
+  if (exception->severity >= ErrorException)
     {
-      CatchException(&exception);
+      CatchException(exception);
       exit_status = 1;
       goto program_exit;
     }
@@ -230,10 +230,13 @@ int main ( int argc, char **argv )
   (void) CopyMagickString(imageInfo->filename,"",MaxTextExtent);
   if ( size[0] != '\0' )
     CloneString( &imageInfo->size, size );
-  original = BlobToImage( imageInfo, blob, blob_length, &exception );
-  if (exception.severity >= ErrorException)
+  (void) fflush(stdout);
+  (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+    "Reading image %s", imageInfo->filename);
+  original = BlobToImage( imageInfo, blob, blob_length, exception );
+  if (exception->severity >= ErrorException)
     {
-      CatchException(&exception);
+      CatchException(exception);
       exit_status = 1;
       goto program_exit;
     }
@@ -253,10 +256,10 @@ int main ( int argc, char **argv )
   (void) strncpy( original->magick, format, MaxTextExtent-1 );
   (void) CopyMagickString(imageInfo->filename,"",MaxTextExtent);
   original->delay = 10;
-  blob = (char *) ImageToBlob ( imageInfo, original, &blob_length, &exception );
-  if (exception.severity >= ErrorException)
+  blob = (char *) ImageToBlob ( imageInfo, original, &blob_length, exception );
+  if (exception->severity >= ErrorException)
     {
-      CatchException(&exception);
+      CatchException(exception);
       exit_status = 1;
       goto program_exit;
     }
@@ -278,10 +281,10 @@ int main ( int argc, char **argv )
     CloneString( &imageInfo->size, size );
   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
     "Reading image from BLOB");
-  final = BlobToImage( imageInfo, blob, blob_length, &exception );
-  if (exception.severity >= ErrorException)
+  final = BlobToImage( imageInfo, blob, blob_length, exception );
+  if (exception->severity >= ErrorException)
     {
-      CatchException(&exception);
+      CatchException(exception);
       exit_status = 1;
       goto program_exit;
     }
@@ -299,9 +302,6 @@ int main ( int argc, char **argv )
    */
 
   fuzz_factor = 0.0;
-#if defined(MAGICKCORE_HDRI_SUPPORT)
-  fuzz_factor = 0.06;
-#endif
   if ( !strcmp( "JPEG", format ) ||
        !strcmp( "JNG", format ) ||
        !strcmp( "JPG", format ) ||
@@ -320,6 +320,11 @@ int main ( int argc, char **argv )
        !strcmp( "UYVY", format ) ||
        !strcmp( "YUV", format ) || (final->compression == JPEGCompression))
     fuzz_factor = 0.06;
+#if defined(MAGICKCORE_HDRI_SUPPORT)
+  fuzz_factor = 0.07;
+  if ( !strcmp( "PCD", format ) || !strcmp( "PCDS", format ) )
+    fuzz_factor = 0.20;
+#endif
   
   SetImageColorspace(final,original->colorspace);
   if ( !IsImagesEqual(original, final ) &&
@@ -339,9 +344,11 @@ int main ( int argc, char **argv )
     original=DestroyImageList(original);
   if (final)
     final=DestroyImageList(final);
+  if (blob)
+    blob=RelinquishMagickMemory(blob);
 
+  exception=DestroyExceptionInfo(exception);
   imageInfo=DestroyImageInfo(imageInfo);
-  DestroyExceptionInfo(&exception);
   MagickCoreTerminus();
 
   if (pause)
