@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 1999-2008 ImageMagick Studio LLC
+# Copyright (C) 1999-2009 ImageMagick Studio LLC
 #
 # This program is covered by multiple licenses, which are described in
 # LICENSE. You should have received a copy of LICENSE with this
@@ -11,4 +11,4 @@
 set -e # Exit on any error
 . ${srcdir}/utilities/tests/common.sh
 
-${CONVERT} ${MODEL_MIFF} -label Quantize Quantize_out.miff
+${CONVERT} ${MODEL_MIFF} -colors 16 -label Quantize Quantize_out.miff
