@@ -10,10 +10,10 @@ PACKAGE_NAME='ImageMagick'
 #
 # Package version.  This is is the numeric version suffix applied to
 # PACKAGE_NAME (e.g. "1.0.0").
-PACKAGE_VERSION='6.4.3'
-PACKAGE_LIB_VERSION="0x643"
-PACKAGE_LIB_VERSION_NUMBER="6,4,3,10"
-PACKAGE_RELEASE="10"
+PACKAGE_VERSION='6.4.9'
+PACKAGE_LIB_VERSION="0x649"
+PACKAGE_RELEASE="2"
+PACKAGE_LIB_VERSION_NUMBER="6,4,9,${PACKAGE_RELEASE}"
 PACKAGE_RELEASE_DATE=`date +%F`
 
 #
@@ -23,13 +23,8 @@ PACKAGE_CHANGE_DATE=`awk '/^[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]/ { print
 
 #
 # Package version addendum.  This is an arbitrary suffix (if any) appended
-# to the package version. (e.g. "beta1") `echo -snapshot-``date '+%g%m%d'`
-CHANGE_DATE=`find ${srcdir}/ChangeLog -printf '%Ty%Tm%Td%\n' 2> /dev/null`
-if test -n "$CHANGE_DATE"; then
-  PACKAGE_VERSION_ADDENDUM=""
-else
-  PACKAGE_VERSION_ADDENDUM=""
-fi
+# to the package version. (e.g. "beta1")
+PACKAGE_LIB_SUBVERSION="-${PACKAGE_RELEASE}"
 
 #
 # Libtool library revision control info: See the libtool documentation under
@@ -51,6 +46,6 @@ fi
 #     increment age.
 #  6. If any interfaces have been removed since the last public release,
 #     then set age to 0.
-MAGICK_LIBRARY_CURRENT=1
+MAGICK_LIBRARY_CURRENT=2
 MAGICK_LIBRARY_REVISION=0
 MAGICK_LIBRARY_AGE=0
