@@ -17,7 +17,7 @@
 %                                July 1992                                    %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -84,11 +84,11 @@
 %
 %    o metadata: any metadata is returned here.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
-static void AnimateUsage(void)
+static MagickBooleanType AnimateUsage(void)
 {
   const char
     **p;
@@ -161,7 +161,6 @@ static void AnimateUsage(void)
       "-respect-parenthesis settings remain in effect until parenthesis boundary",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
-      "-scenes range        image scene range",
       "-seed value          seed a new sequence of pseudo-random numbers",
       "-set attribute value set an image attribute",
       "-size geometry       width and height of image",
@@ -217,7 +216,7 @@ static void AnimateUsage(void)
   (void) printf("\nButtons: \n");
   for (p=buttons; *p != (char *) NULL; p++)
     (void) printf("  %s\n",*p);
-  exit(0);
+  return(MagickTrue);
 }
 
 WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
@@ -248,7 +247,7 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
 #define ThrowAnimateInvalidArgumentException(option,argument) \
 { \
   (void) ThrowMagickException(exception,GetMagickModule(),OptionError, \
-    "InvalidArgument","`%s': %s",argument,option); \
+    "InvalidArgument","`%s': %s",option,argument); \
   DestroyAnimate(); \
   return(MagickFalse); \
 }
@@ -270,11 +269,8 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
     image_stack[MaxImageStackDepth+1];
 
   long
-    first_scene,
     j,
-    k,
-    last_scene,
-    scene;
+    k;
 
   MagickBooleanType
     fire,
@@ -318,10 +314,8 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
   status=MagickTrue;
   SetNotifyHandlers;
   display=(Display *) NULL;
-  first_scene=0;
   j=1;
   k=0;
-  last_scene=0;
   NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
@@ -357,7 +351,7 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
       }
     if ((LocaleCompare("help",option+1) == 0) ||
         (LocaleCompare("-help",option+1) == 0))
-      AnimateUsage();
+      return(AnimateUsage());
   }
   /*
     Get user defaults from X resource database.
@@ -431,52 +425,32 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
       }
     if (IsMagickOption(option) == MagickFalse)
       {
+        const char
+          *filename;
+
+        Image
+          *images;
+
         /*
-          Option is a file name.
+          Read input image.
         */
-        FireImageStack(MagickFalse,MagickTrue,pend);
-        for (scene=first_scene; scene <= last_scene ; scene++)
-        {
-          const char
-            *filename;
-
-          Image
-            *images;
-
-          /*
-            Read image.
-          */
-          filename=option;
-          if ((LocaleCompare(filename,"--") == 0) && (i < (argc-1)))
-            {
-              option=argv[++i];
-              filename=option;
-            }
-          (void) CopyMagickString(image_info->filename,filename,MaxTextExtent);
-          if (first_scene != last_scene)
-            {
-              char
-                filename[MaxTextExtent];
-
-              /*
-                Form filename for multi-part images.
-              */
-              (void) InterpretImageFilename(filename,MaxTextExtent,
-                image_info->filename,(int) scene);
-              if (LocaleCompare(filename,image_info->filename) == 0)
-                (void) FormatMagickString(filename,MaxTextExtent,"%s[%lu]",
-                  image_info->filename,scene);
-              (void) CopyMagickString(image_info->filename,filename,
-                MaxTextExtent);
-            }
-          images=ReadImage(image_info,exception);
-          status&=(images != (Image *) NULL) &&
-            (exception->severity < ErrorException);
-          if (images == (Image *) NULL)
-            continue;
-          AppendImageStack(images);
-          FireImageStack(MagickFalse,MagickFalse,MagickTrue);
-        }
+        FireImageStack(MagickTrue,MagickTrue,pend);
+        filename=option;
+        if ((LocaleCompare(filename,"--") == 0) && (i < (argc-1)))
+          {
+            option=argv[++i];
+            filename=option;
+          }
+        (void) CopyMagickString(image_info->filename,filename,MaxTextExtent);
+        if (image_info->ping != MagickFalse)
+          images=PingImages(image_info,exception);
+        else
+          images=ReadImages(image_info,exception);
+        status&=(images != (Image *) NULL) &&
+          (exception->severity < ErrorException);
+        if (images == (Image *) NULL)
+          continue;
+        AppendImageStack(images);
         continue;
       }
     pend=image != (Image *) NULL ? MagickTrue : MagickFalse;
@@ -590,6 +564,7 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
               clone_images=image_stack[k-1].image;
             if (clone_images == (Image *) NULL)
               ThrowAnimateException(ImageError,"ImageSequenceRequired",option);
+            FireImageStack(MagickFalse,MagickTrue,MagickTrue);
             if (*option == '+')
               clone_images=CloneImages(clone_images,"-1",exception);
             else
@@ -603,7 +578,6 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
               }
             if (clone_images == (Image *) NULL)
               ThrowAnimateException(OptionError,"NoSuchImage",option);
-            FireImageStack(MagickFalse,MagickTrue,MagickTrue);
             AppendImageStack(clone_images);
             break;
           }
@@ -973,6 +947,9 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
             char
               *p;
 
+            double
+              value;
+
             long
               resource;
 
@@ -989,11 +966,29 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowAnimateException(OptionError,"MissingArgument",option);
-            (void) strtod(argv[i],&p);
+            value=strtod(argv[i],&p);
             if ((p == argv[i]) && (LocaleCompare("unlimited",argv[i]) != 0))
               ThrowAnimateInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("list",option+1) == 0)
+          {
+            long
+              list;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowAnimateException(OptionError,"MissingArgument",option);
+            list=ParseMagickOption(MagickListOptions,MagickFalse,argv[i]);
+            if (list < 0)
+              ThrowAnimateException(OptionError,"UnrecognizedListType",argv[i]);
+            (void) MogrifyImageInfo(image_info,(int) (i-j+1),(const char **)
+              argv+j,exception);
+            DestroyAnimate();
+            return(MagickTrue);
+          }
         if (LocaleCompare("log",option+1) == 0)
           {
             if (*option == '+')
@@ -1215,10 +1210,8 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
               ThrowAnimateInvalidArgumentException(option,argv[i]);
             break;
           }
-        if (LocaleCompare("scenes",option+1) == 0)
+        if (LocaleCompare("scenes",option+1) == 0)  /* deprecated */
           {
-            first_scene=0;
-            last_scene=0;
             if (*option == '+')
               break;
             i++;
@@ -1226,9 +1219,6 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
               ThrowAnimateException(OptionError,"MissingArgument",option);
             if (IsSceneGeometry(argv[i],MagickFalse) == MagickFalse)
               ThrowAnimateInvalidArgumentException(option,argv[i]);
-            first_scene=atol(argv[i]);
-            last_scene=first_scene;
-            (void) sscanf(argv[i],"%ld-%ld",&first_scene,&last_scene);
             break;
           }
         if (LocaleCompare("set",option+1) == 0)
@@ -1426,7 +1416,7 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
 #else
   (void) ThrowMagickException(exception,GetMagickModule(),MissingDelegateError,
     "DelegateLibrarySupportNotBuiltIn","`%s' (X11)",image_info->filename);
-  AnimateUsage();
+  (void) AnimateUsage();
   return(MagickFalse);
 #endif
 }
