@@ -1108,6 +1108,25 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("list",option+1) == 0)
+          {
+            long
+              list;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowCompositeException(OptionError,"MissingArgument",option);
+            list=ParseMagickOption(MagickListOptions,MagickFalse,argv[i]);
+            if (list < 0)
+              ThrowCompositeException(OptionError,"UnrecognizedListType",
+                argv[i]);
+            (void) MogrifyImageInfo(image_info,(int) (i-j+1),(const char **)
+              argv+j,exception);
+            DestroyComposite();
+            return(MagickTrue);
+          }
         if (LocaleCompare("log",option+1) == 0)
           {
             if (*option == '+')
@@ -1347,7 +1366,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("stereo",option+1) == 0)
           {
-            int
+            MagickStatusType
               flags;
 
             composite_options.stereo=MagickFalse;
