@@ -17,7 +17,7 @@
 %                               December 2001                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -94,11 +94,11 @@
 %
 %    o metadata: any metadata is returned here.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
-static void ConjureUsage(void)
+static MagickBooleanType ConjureUsage(void)
 {
   const char
     **p;
@@ -136,7 +136,7 @@ static void ConjureUsage(void)
   (void) printf("\nIn additiion, define any key value pairs required by "
     "your script.  For\nexample,\n\n");
   (void) printf("    conjure -size 100x100 -color blue -foo bar script.msl\n");
-  exit(0);
+  return(MagickTrue);
 }
 
 WandExport MagickBooleanType ConjureImageCommand(ImageInfo *image_info,
@@ -159,7 +159,7 @@ WandExport MagickBooleanType ConjureImageCommand(ImageInfo *image_info,
 #define ThrowConjureInvalidArgumentException(option,argument) \
 { \
   (void) ThrowMagickException(exception,GetMagickModule(),OptionError, \
-    "InvalidArgument","`%s': %s",argument,option); \
+    "InvalidArgument","`%s': %s",option,argument); \
   DestroyConjure(); \
   return(MagickFalse); \
 }
@@ -188,10 +188,11 @@ WandExport MagickBooleanType ConjureImageCommand(ImageInfo *image_info,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(exception != (ExceptionInfo *) NULL);
   if (argc < 2)
-    ConjureUsage();
+    return(ConjureUsage());
   image=NewImageList();
   number_images=0;
   option=(char *) NULL;
+  (void) respect_parenthesis;
   /*
     Conjure an image.
   */
@@ -226,7 +227,7 @@ WandExport MagickBooleanType ConjureImageCommand(ImageInfo *image_info,
             (LocaleCompare("-help",option+1) == 0))
           {
             if (*option == '-')
-              ConjureUsage();
+              return(ConjureUsage());
             continue;
           }
         if (LocaleCompare("log",option+1) == 0)
@@ -268,14 +269,13 @@ WandExport MagickBooleanType ConjureImageCommand(ImageInfo *image_info,
             (void) fprintf(stdout,"Version: %s\n",
               GetMagickVersion((unsigned long *) NULL));
             (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
-            exit(0);
-            continue;
+            return(MagickTrue);
           }
         /*
           Persist key/value pair.
         */
         (void) DeleteImageOption(image_info,option+1);
-        status&=SetImageOption(image_info,option+1,argv[i+1]);
+        status=SetImageOption(image_info,option+1,argv[i+1]);
         if (status == MagickFalse)
           ThrowConjureException(ImageError,"UnableToPersistKey",option);
         i++;
@@ -285,16 +285,16 @@ WandExport MagickBooleanType ConjureImageCommand(ImageInfo *image_info,
       Interpret MSL script.
     */
     (void) DeleteImageOption(image_info,"filename");
-    status&=SetImageOption(image_info,"filename",argv[i]);
+    status=SetImageOption(image_info,"filename",argv[i]);
     if (status == MagickFalse)
       ThrowConjureException(ImageError,"UnableToPersistKey",argv[i]);
     (void) FormatMagickString(image_info->filename,MaxTextExtent,"msl:%s",
       argv[i]);
-    image=ReadImage(image_info,exception);
+    image=ReadImages(image_info,exception);
     CatchException(exception);
-    status&=image != (Image *) NULL;
     if (image != (Image *) NULL)
       image=DestroyImageList(image);
+    status=image != (Image *) NULL ? MagickTrue : MagickFalse;
     number_images++;
   }
   if (i != argc)
