@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -54,6 +54,10 @@ extern WandExport MagickBooleanType
   MagickGetImageChannelExtrema(MagickWand *,const ChannelType,unsigned long *,
     unsigned long *),
   MagickGetImageExtrema(MagickWand *,unsigned long *,unsigned long *),
+  MagickGetImageMatte(MagickWand *),
+  MagickGetImagePixels(MagickWand *,const long,const long,const unsigned long,
+    const unsigned long,const char *,const StorageType,void *),
+  MagickMapImage(MagickWand *,const MagickWand *,const MagickBooleanType),
   MagickMatteFloodfillImage(MagickWand *,const double,const double,
     const PixelWand *,const long,const long),
   MagickOpaqueImage(MagickWand *,const PixelWand *,const PixelWand *,
@@ -69,6 +73,8 @@ extern WandExport MagickBooleanType
   MagickSetImageAttribute(MagickWand *,const char *,const char *),
   MagickSetImageIndex(MagickWand *,const long),
   MagickSetImageOption(MagickWand *,const char *,const char *,const char *),
+  MagickSetImagePixels(MagickWand *,const long,const long,const unsigned long,
+    const unsigned long,const char *,const StorageType,const void *),
   MagickTransparentImage(MagickWand *,const PixelWand *,const double,
     const double);
 
@@ -87,9 +93,6 @@ extern WandExport PixelWand
 extern WandExport unsigned char
   *MagickWriteImageBlob(MagickWand *,size_t *);
 
-extern WandExport VirtualPixelMethod
-  MagickSetImageVirtualPixelMethod(MagickWand *,const VirtualPixelMethod);
-
 extern WandExport void
   DrawPopGraphicContext(DrawingWand *),
   DrawPushGraphicContext(DrawingWand *),
