@@ -1260,6 +1260,24 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
               ThrowDisplayInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("list",option+1) == 0)
+          {
+            long
+              list;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowDisplayException(OptionError,"MissingArgument",option);
+            list=ParseMagickOption(MagickListOptions,MagickFalse,argv[i]);
+            if (list < 0)
+              ThrowDisplayException(OptionError,"UnrecognizedListType",argv[i]);
+            (void) MogrifyImageInfo(image_info,(int) (i-j+1),(const char **)
+              argv+j,exception);
+            DestroyDisplay();
+            return(MagickTrue);
+          }
         if (LocaleCompare("log",option+1) == 0)
           {
             if (*option == '+')
