@@ -10,14 +10,14 @@
 %                 IIIII  M   M  P       OOO   R  R     T                      %
 %                                                                             %
 %                                                                             %
-%               Import image to a machine independent format.                 %
+%                       Import Image from X11 Screen                          %
 %                                                                             %
 %                           Software Design                                   %
 %                             John Cristy                                     %
 %                              July 1992                                      %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -91,11 +91,11 @@
 %
 %    o metadata: any metadata is returned here.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
-static void ImportUsage(void)
+static MagickBooleanType ImportUsage(void)
 {
   const char
     **p;
@@ -209,7 +209,7 @@ static void ImportUsage(void)
   (void) printf(
     "the filename suffix (i.e. image.ps).  Specify 'file' as '-' for\n");
   (void) printf("standard input or output.\n");
-  exit(0);
+  return(MagickTrue);
 }
 
 static inline long MagickMax(const long x,const long y)
@@ -232,6 +232,8 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
       display=(Display *) NULL; \
     } \
   DestroyImageStack(); \
+  if (target_window != (char *) NULL) \
+    target_window=DestroyString(target_window); \
   for (i=0; i < (long) argc; i++) \
     argv[i]=DestroyString(argv[i]); \
   argv=(char **) RelinquishMagickMemory(argv); \
@@ -246,7 +248,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
 #define ThrowImportInvalidArgumentException(option,argument) \
 { \
   (void) ThrowMagickException(exception,GetMagickModule(),OptionError, \
-    "InvalidArgument","`%s': %s",argument,option); \
+    "InvalidArgument","`%s': %s",option,argument); \
   DestroyImport(); \
   return(MagickFalse); \
 }
@@ -325,6 +327,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
   server_name=(char *) NULL;
   status=MagickTrue;
   SetNotifyHandlers;
+  target_window=(char *) NULL;
   /*
     Check for server name specified on the command line.
   */
@@ -353,7 +356,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
       }
     if ((LocaleCompare("help",option+1) == 0) ||
         (LocaleCompare("-help",option+1) == 0))
-      ImportUsage();
+      return(ImportUsage());
   }
   /*
     Get user defaults from X resource database.
@@ -419,7 +422,6 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
   snapshots=1;
   status=MagickTrue;
   filename=(char *) NULL;
-  target_window=(char *) NULL;
   /*
     Check command syntax.
   */
@@ -910,6 +912,9 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
             char
               *p;
 
+            double
+              value;
+
             long
               resource;
 
@@ -926,11 +931,29 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowImportException(OptionError,"MissingArgument",option);
-            (void) strtod(argv[i],&p);
+            value=strtod(argv[i],&p);
             if ((p == argv[i]) && (LocaleCompare("unlimited",argv[i]) != 0))
               ThrowImportInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("list",option+1) == 0)
+          {
+            long
+              list;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowImportException(OptionError,"MissingArgument",option);
+            list=ParseMagickOption(MagickListOptions,MagickFalse,argv[i]);
+            if (list < 0)
+              ThrowImportException(OptionError,"UnrecognizedListType",argv[i]);
+            (void) MogrifyImageInfo(image_info,(int) (i-j+1),(const char **)
+              argv+j,exception);
+            DestroyImport();
+            return(MagickTrue);
+          }
         if (LocaleCompare("log",option+1) == 0)
           {
             if (*option == '+')
@@ -1265,7 +1288,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
 #else
   (void) ThrowMagickException(exception,GetMagickModule(),MissingDelegateError,
     "DelegateLibrarySupportNotBuiltIn","`%s' (X11)",image_info->filename);
-  ImportUsage();
+  (void) ImportUsage();
   return(MagickFalse);
 #endif
 }
