@@ -1,12 +1,12 @@
 /*
   Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
-  
+
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
-  
+
     http://www.imagemagick.org/script/license.php
-  
+
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -143,6 +143,10 @@ extern WandExport MagickBooleanType
   MagickFlopImage(MagickWand *),
   MagickFrameImage(MagickWand *,const PixelWand *,const unsigned long,
     const unsigned long,const long,const long),
+  MagickFunctionImage(MagickWand *,const MagickFunction,const unsigned long,
+    const double *),
+  MagickFunctionImageChannel(MagickWand *,const ChannelType,
+    const MagickFunction,const unsigned long,const double *),
   MagickGammaImage(MagickWand *,const double),
   MagickGammaImageChannel(MagickWand *,const ChannelType,const double),
   MagickGaussianBlurImage(MagickWand *,const double,const double),
@@ -153,12 +157,14 @@ extern WandExport MagickBooleanType
   MagickGetImageBluePrimary(MagickWand *,double *,double *),
   MagickGetImageBorderColor(MagickWand *,PixelWand *),
   MagickGetImageChannelDistortion(MagickWand *,const MagickWand *,
-    const ChannelType, const MetricType,double *),
-  MagickGetImageDistortion(MagickWand *,const MagickWand *,const MetricType,
+    const ChannelType,const MetricType,double *),
+  MagickGetImageChannelKurtosis(MagickWand *,const ChannelType,double *,
     double *),
   MagickGetImageChannelMean(MagickWand *,const ChannelType,double *,double *),
   MagickGetImageChannelRange(MagickWand *,const ChannelType,double *,double *),
   MagickGetImageColormapColor(MagickWand *,const unsigned long,PixelWand *),
+  MagickGetImageDistortion(MagickWand *,const MagickWand *,const MetricType,
+    double *),
   MagickGetImageGreenPrimary(MagickWand *,double *,double *),
   MagickGetImageMatteColor(MagickWand *,PixelWand *),
   MagickGetImageLength(MagickWand *,MagickSizeType *),
