@@ -16,14 +16,14 @@
 %                        W   W  A   A  N   N  DDDD                            %
 %                                                                             %
 %                                                                             %
-%                 ImageMagick MagickWand Programming Interface                %
+%                           MagickWand Wand Methods                           %
 %                                                                             %
 %                               Software Design                               %
 %                                 John Cristy                                 %
 %                                 August 2003                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -88,7 +88,6 @@ static unsigned long
 %
 %    o wand: the magick wand.
 %
-%
 */
 WandExport void ClearMagickWand(MagickWand *wand)
 {
@@ -177,7 +176,6 @@ WandExport MagickWand *CloneMagickWand(const MagickWand *wand)
 %
 %    o wand: the magick wand.
 %
-%
 */
 WandExport MagickWand *DestroyMagickWand(MagickWand *wand)
 {
@@ -969,9 +967,9 @@ WandExport void MagickSetLastIterator(MagickWand *wand)
 %
 %  MagickWandGenesis() initializes the MagickWand environment.
 %
-%  The format of the MaickWandGenesis method is:
+%  The format of the MagickWandGenesis method is:
 %
-%      void MaickWandGenesis(void)
+%      void MagickWandGenesis(void)
 %
 */
 WandExport void MagickWandGenesis(void)
