@@ -10,14 +10,14 @@
 %               M   M   OOO   N   N    T    A   A   GGG   EEEEE               %
 %                                                                             %
 %                                                                             %
-%                ImageMagick Methods to Create Image Thumbnails               %
+%                MagickWand Methods to Create Image Thumbnails                %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -74,11 +74,11 @@
 %
 %    o metadata: any metadata is returned here.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
-static void MontageUsage(void)
+static MagickBooleanType MontageUsage(void)
 {
   const char
     **p;
@@ -235,7 +235,7 @@ static void MontageUsage(void)
   (void) printf(
     "image type as the filename suffix (i.e. image.ps).  Specify 'file' as\n");
   (void) printf("'-' for standard input or output.\n");
-  exit(0);
+  return(MagickTrue);
 }
 
 WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
@@ -260,7 +260,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
 #define ThrowMontageInvalidArgumentException(option,argument) \
 { \
   (void) ThrowMagickException(exception,GetMagickModule(),OptionError, \
-    "InvalidArgument","`%s': %s",argument,option); \
+    "InvalidArgument","`%s': %s",option,argument); \
   DestroyMontage(); \
   return(MagickFalse); \
 }
@@ -320,7 +320,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
         }
     }
   if (argc < 3)
-   MontageUsage();
+    return(MontageUsage());
   format="%w,%h,%m";
   first_scene=0;
   j=1;
@@ -388,8 +388,8 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               /*
                 Form filename for multi-part images.
               */
-              (void) InterpretImageFilename(filename,MaxTextExtent,
-                image_info->filename,(int) scene);
+              (void) InterpretImageFilename(image_info,(Image *) NULL,
+                image_info->filename,(int) scene,filename);
               if (LocaleCompare(filename,image_info->filename) == 0)
                 (void) FormatMagickString(filename,MaxTextExtent,"%s.%lu",
                   image_info->filename,scene);
@@ -397,7 +397,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
                 MaxTextExtent);
             }
           (void) CloneString(&image_info->font,montage_info->font);
-          images=ReadImage(image_info,exception);
+          images=ReadImages(image_info,exception);
           status&=(images != (Image *) NULL) &&
             (exception->severity < ErrorException);
           if (images == (Image *) NULL)
@@ -587,6 +587,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               clone_images=image_stack[k-1].image;
             if (clone_images == (Image *) NULL)
               ThrowMontageException(ImageError,"ImageSequenceRequired",option);
+            FireImageStack(MagickTrue,MagickTrue,MagickTrue);
             if (*option == '+')
               clone_images=CloneImages(clone_images,"-1",exception);
             else
@@ -600,7 +601,6 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               }
             if (clone_images == (Image *) NULL)
               ThrowMontageException(OptionError,"NoSuchImage",option);
-            FireImageStack(MagickTrue,MagickTrue,MagickTrue);
             AppendImageStack(clone_images);
             break;
           }
@@ -961,7 +961,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
       {
         if ((LocaleCompare("help",option+1) == 0) ||
             (LocaleCompare("-help",option+1) == 0))
-          MontageUsage();
+          return(MontageUsage());
         ThrowMontageException(OptionError,"UnrecognizedOption",option)
       }
       case 'i':
@@ -1020,6 +1020,9 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             char
               *p;
 
+            double
+              value;
+
             long
               resource;
 
@@ -1036,11 +1039,29 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowMontageException(OptionError,"MissingArgument",option);
-            (void) strtod(argv[i],&p);
+            value=strtod(argv[i],&p);
             if ((p == argv[i]) && (LocaleCompare("unlimited",argv[i]) != 0))
               ThrowMontageInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("list",option+1) == 0)
+          {
+            long
+              list;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            list=ParseMagickOption(MagickListOptions,MagickFalse,argv[i]);
+            if (list < 0)
+              ThrowMontageException(OptionError,"UnrecognizedListType",argv[i]);
+            (void) MogrifyImageInfo(image_info,(int) (i-j+1),(const char **)
+              argv+j,exception);
+            DestroyMontage();
+            return(MagickTrue);
+          }
         if (LocaleCompare("log",option+1) == 0)
           {
             if (*option == '+')
