@@ -10,14 +10,14 @@
 %                 SSSSS    T    R  R   EEEEE  A   A  M   M                    %
 %                                                                             %
 %                                                                             %
-%                     Stream image to a raw image format.                     %
+%                     Stream Image to a Raw Image Format                      %
 %                                                                             %
 %                           Software Design                                   %
 %                             John Cristy                                     %
 %                              July 1992                                      %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -78,12 +78,12 @@
 %
 %    o metadata: any metadata is returned here.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 %
 */
 
-static void StreamUsage(void)
+static MagickBooleanType StreamUsage(void)
 {
   const char
     **p;
@@ -153,7 +153,7 @@ static void StreamUsage(void)
   (void) printf(
     "image type as the filename suffix (i.e. image.ps).  Specify 'file' as\n");
   (void) printf("'-' for standard input or output.\n");
-  exit(0);
+  return(MagickTrue);
 }
 
 WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
@@ -177,7 +177,7 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
 #define ThrowStreamInvalidArgumentException(option,argument) \
 { \
   (void) ThrowMagickException(exception,GetMagickModule(),OptionError, \
-    "InvalidArgument","`%s': %s",argument,option); \
+    "InvalidArgument","`%s': %s",option,argument); \
   DestroyStream(); \
   return(MagickFalse); \
 }
@@ -234,7 +234,7 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
         }
     }
   if (argc < 3)
-    StreamUsage();
+    return(StreamUsage());
   format="%w,%h,%m";
   j=1;
   k=0;
@@ -457,7 +457,7 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
       {
         if ((LocaleCompare("help",option+1) == 0) ||
             (LocaleCompare("-help",option+1) == 0))
-          StreamUsage();
+          return(StreamUsage());
         ThrowStreamException(OptionError,"UnrecognizedOption",option)
       }
       case 'i':
@@ -507,6 +507,9 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
             char
               *p;
 
+            double
+              value;
+
             long
               resource;
 
@@ -523,11 +526,29 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowStreamException(OptionError,"MissingArgument",option);
-            (void) strtod(argv[i],&p);
+            value=strtod(argv[i],&p);
             if ((p == argv[i]) && (LocaleCompare("unlimited",argv[i]) != 0))
               ThrowStreamInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("list",option+1) == 0)
+          {
+            long
+              list;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowStreamException(OptionError,"MissingArgument",option);
+            list=ParseMagickOption(MagickListOptions,MagickFalse,argv[i]);
+            if (list < 0)
+              ThrowStreamException(OptionError,"UnrecognizedListType",argv[i]);
+            (void) MogrifyImageInfo(image_info,(int) (i-j+1),(const char **)
+              argv+j,exception);
+            DestroyStream();
+            return(MagickTrue);
+          }
         if (LocaleCompare("log",option+1) == 0)
           {
             if (*option == '+')
